#
# spec file for package aws-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%define pythons python311
%endif
%global _sitelibdir %{%{pythons}_sitelib}

Name:           aws-cli
Version:        1.36.1
Release:        1.1
Summary:        Amazon Web Services Command Line Interface
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/aws/aws-cli
Source0:        https://github.com/aws/%{name}/archive/refs/tags/%{version}.tar.gz
Patch0:         ac_update-docutils.patch
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       groff
Provides:       awscli = %{version}
BuildArch:      noarch
BuildRequires:  %{pythons}-devel
BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-setuptools
BuildRequires:  %{pythons}-wheel
Requires:       %{pythons}
Requires:       %{pythons}-botocore >= 1.35.60
Requires:       %{pythons}-six
Requires:       (%{pythons}-PyYAML >= 3.10 with %{pythons}-PyYAML <= 6.1)
Requires:       (%{pythons}-colorama >= 0.2.5 with %{pythons}-colorama <= 0.5.0)
Requires:       (%{pythons}-docutils >= 0.10 with %{pythons}-docutils < 0.30)
Requires:       (%{pythons}-rsa >= 3.1.2 with %{pythons}-rsa < 5.0.0)
Requires:       (%{pythons}-s3transfer >= 0.10.0 with %{pythons}-s3transfer < 0.11.0)

%description
The AWS Command Line Interface (CLI) is a unified tool to manage AWS
services. With this tool, multiple AWS services can be controlled
from the command line and automated through scripts.

%prep
%autosetup -p1
sed -i 's/from botocore\.vendored //' awscli/customizations/awslambda.py
sed -i 's/botocore\.vendored\.//' awscli/customizations/configure/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
find %{buildroot}%{_sitelibdir}/awscli/examples -type f -exec chmod 644 {} \;
# No DOS crap
rm %{buildroot}/%{_bindir}/aws.cmd
# Shell completion
install -DTm644 %{buildroot}%{_bindir}/aws_bash_completer %{buildroot}%{_datadir}/bash-completion/completions/aws
install -DTm644 %{buildroot}%{_bindir}/aws_zsh_completer.sh %{buildroot}%{_sysconfdir}/zsh_completion.d/_aws

%files
%defattr(-, root, root)
%doc CHANGELOG.rst README.rst
%license LICENSE.txt
%dir %{_sitelibdir}/awscli
%dir %{_sitelibdir}/awscli-%{version}*-info
%{_sitelibdir}/awscli/*
%{_sitelibdir}/awscli-%{version}*-info/*
%{_bindir}/aws
%{_bindir}/aws_completer
%exclude %{_bindir}/aws_bash_completer
%exclude %{_bindir}/aws_zsh_completer.sh
%{_datadir}/bash-completion/completions/aws
%dir %{_sysconfdir}/zsh_completion.d
%config %attr(644,root,root) %{_sysconfdir}/zsh_completion.d/_aws

%changelog
* Thu Nov 14 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.36.1
  * api-change:``accessanalyzer``: This release adds support for policy validation and external
    access findings for resource control policies (RCP). IAM Access Analyzer helps you author
    functional and secure RCPs and awareness that a RCP may restrict external access. Updated service
    API, documentation, and paginators.
  * api-change:``application-signals``: Amazon CloudWatch Application Signals now supports creating
    Service Level Objectives with burn rates. Users can now create or update SLOs with burn rate
    configurations to meet their specific business requirements.
  * api-change:``b2bi``: This release adds a GenerateMapping API to allow generation of JSONata or
    XSLT transformer code based on input and output samples.
  * api-change:``billing``: Today, AWS announces the general availability of ListBillingViews API in
    the AWS SDKs, to enable AWS Billing Conductor (ABC) users to create proforma Cost and Usage Reports
    (CUR) programmatically.
  * api-change:``cloudtrail``: This release adds a new API GenerateQuery that generates a query from
    a natural language prompt about the event data in your event data store. This operation uses
    generative artificial intelligence (generative AI) to produce a ready-to-use SQL query from the
    prompt.
  * api-change:``dynamodb``: This release includes supports the new WarmThroughput feature for
    DynamoDB. You can now provide an optional WarmThroughput attribute for CreateTable or UpdateTable
    APIs to pre-warm your table or global secondary index. You can also use DescribeTable to see the
    latest WarmThroughput value.
  * api-change:``ec2``: This release adds the source AMI details in DescribeImages API
  * api-change:``internetmonitor``: Add new query type Routing_Suggestions regarding querying
    interface
  * api-change:``mediaconvert``: This release adds support for ARN inputs in the Kantar credentials
    secrets name field and the MSPR field to the manifests for PlayReady DRM protected outputs.
  * api-change:``organizations``: Add support for policy operations on the Resource Control Polices.
- from version 1.36.0
  * api-change:``codebuild``: AWS CodeBuild now supports non-containerized Linux and Windows builds
    on Reserved Capacity.
  * api-change:``controltower``: Added ResetEnabledControl API.
  * api-change:``fis``: This release adds support for generating experiment reports with the
    experiment report configuration
  * api-change:``gamelift``: Amazon GameLift releases container fleets support for general
    availability. Deploy Linux-based containerized game server software for hosting on Amazon GameLift.
  * api-change:``payment-cryptography``: Updated ListAliases API with KeyArn filter.
  * api-change:``rds``: Updates Amazon RDS documentation for Amazon RDS Extended Support for Amazon
    Aurora MySQL.
  * feature:shorthand: Adds support to shorthand syntax for loading parameters from files via the
    ``@=`` assignment operator.
- from version 1.35.24
  * api-change:``cloudfront``: No API changes from previous release. This release migrated the model
    to Smithy keeping all features unchanged.
  * api-change:``inspector2``: Adds support for filePath filter.
  * api-change:``lambda``: Add Python 3.13 (python3.13) support to AWS Lambda
  * api-change:``opensearch``: Adds Support for new AssociatePackages and DissociatePackages API in
    Amazon OpenSearch Service that allows association and dissociation operations to be carried out on
    multiple packages at the same time.
  * api-change:``outposts``: This release updates StartCapacityTask to allow an active Outpost to be
    modified. It also adds a new API to list all running EC2 instances on the Outpost.
- from version 1.35.23
  * api-change:``batch``: This feature allows override LaunchTemplates to be specified in an AWS
    Batch Compute Environment.
  * api-change:``bedrock-agent-runtime``: This release adds trace functionality to Bedrock Prompt
    Flows
  * api-change:``chime-sdk-media-pipelines``: Added support for Media Capture Pipeline and Media
    Concatenation Pipeline for customer managed server side encryption. Now Media Capture Pipeline can
    use IAM sink role to get access to KMS key and encrypt/decrypt recorded artifacts. KMS key ID can
    also be supplied with encryption context.
  * api-change:``controlcatalog``: AWS Control Catalog GetControl public API returns additional data
    in output, including Implementation and Parameters
  * api-change:``eks``: Adds new error code `Ec2InstanceTypeDoesNotExist` for Amazon EKS managed node
    groups
  * api-change:``firehose``: Amazon Data Firehose / Features : Adds support for a new
    DeliveryStreamType, DatabaseAsSource. DatabaseAsSource hoses allow customers to stream CDC events
    from their RDS and Amazon EC2 hosted databases, running MySQL and PostgreSQL database engines, to
    Iceberg Table destinations.
  * api-change:``lambda``: This release adds support for using AWS KMS customer managed keys to
    encrypt AWS Lambda .zip deployment packages.
  * api-change:``pinpoint-sms-voice-v2``: Added the RequiresAuthenticationTimestamp field to the
    RegistrationVersionStatusHistory data type.
  * api-change:``qbusiness``: Adds S3 path option to pass group member list for PutGroup API.
- from version 1.35.22
  * api-change:``autoscaling``: Auto Scaling groups now support the ability to strictly balance
    instances across Availability Zones by configuring the AvailabilityZoneDistribution parameter. If
    balanced-only is configured for a group, launches will always be attempted in the under scaled
    Availability Zone even if it is unhealthy.
  * api-change:``bedrock-agent``: Add prompt support for chat template configuration and agent
    generative AI resource. Add support for configuring an optional guardrail in Prompt and Knowledge
    Base nodes in Prompt Flows. Add API to validate flow definition
  * api-change:``bedrock-runtime``: Add Prompt management support to Bedrock runtime APIs: Converse,
    ConverseStream, InvokeModel, InvokeModelWithStreamingResponse
  * api-change:``cleanrooms``: This release introduces support for Custom Models in AWS Clean Rooms
    ML.
  * api-change:``cleanroomsml``: This release introduces support for Custom Models in AWS Clean Rooms
    ML.
  * api-change:``quicksight``: Add Client Credentials based OAuth support for Snowflake and Starburst
  * api-change:``resource-explorer-2``: Add GetManagedView, ListManagedViews APIs.
  * api-change:``synthetics``: Add support to toggle if a canary will automatically delete
    provisioned canary resources such as Lambda functions and layers when a canary is deleted.  This
    behavior can be controlled via the new ProvisionedResourceCleanup property exposed in the
    CreateCanary and UpdateCanary APIs.
- from version 1.35.21
  * api-change:``codebuild``: AWS CodeBuild now adds additional compute types for reserved capacity
    fleet.
  * api-change:``guardduty``: GuardDuty RDS Protection expands support for Amazon Aurora PostgreSQL
    Limitless Databases.
  * api-change:``lakeformation``: API changes for new named tag expressions feature.
  * api-change:``qapps``: Introduces category apis in AmazonQApps. Web experience users use
    Categories to tag and filter library items.
  * api-change:``s3control``: Fix ListStorageLensConfigurations and ListStorageLensGroups
    deserialization for Smithy SDKs.
  * api-change:``verifiedpermissions``: Adding BatchGetPolicy API which supports the retrieval of
    multiple policies across multiple policy stores within a single request.
- from version 1.35.20
  * api-change:``bedrock-agent``: Amazon Bedrock Knowledge Bases now supports using application
    inference profiles to increase throughput and improve resilience.
  * api-change:``docdb-elastic``: Amazon DocumentDB Elastic Clusters adds support for pending
    maintenance actions feature with APIs GetPendingMaintenanceAction, ListPendingMaintenanceActions
    and ApplyPendingMaintenanceAction
  * api-change:``logs``: This release introduces an improvement in PutLogEvents
  * api-change:``taxsettings``: Add support for supplemental tax registrations via these new APIs:
    PutSupplementalTaxRegistration, ListSupplementalTaxRegistrations, and
    DeleteSupplementalTaxRegistration.
- from version 1.35.19
  * api-change:``amp``: Added support for UpdateScraper API, to enable updating collector
    configuration in-place
  * api-change:``autoscaling``: Adds bake time for Auto Scaling group Instance Refresh
  * api-change:``batch``: Add `podNamespace` to `EksAttemptDetail` and `containerID` to
    `EksAttemptContainerDetail`.
  * api-change:``elbv2``: Add UDP support for AWS PrivateLink and dual-stack Network Load Balancers
  * api-change:``glue``: Add schedule support for AWS Glue column statistics
  * api-change:``sagemaker``: SageMaker HyperPod adds scale-down at instance level via
    BatchDeleteClusterNodes API and group level via UpdateCluster API. SageMaker Training exposes
    secondary job status in TrainingJobSummary from ListTrainingJobs API. SageMaker now supports G6,
    G6e, P5e instances for HyperPod and Training.
  * api-change:``sesv2``: This release enables customers to provide the email template content in the
    SESv2 SendEmail and SendBulkEmail APIs instead of the name or the ARN of a stored email template.
- from version 1.35.18
  * api-change:``appsync``: This release adds support for AppSync Event APIs.
  * api-change:``connect``: Updated the public documentation for the UserIdentityInfo object to
    accurately reflect the character limits for the FirstName and LastName fields, which were
    previously listed as 1-100 characters.
  * api-change:``datasync``: AWS DataSync now supports Enhanced mode tasks. This task mode supports
    transfer of virtually unlimited numbers of objects with enhanced metrics, more detailed logs, and
    higher performance than Basic mode. This mode currently supports transfers between Amazon S3
    locations.
  * api-change:``ec2``: This release adds two new capabilities to VPC Security Groups: Security Group
    VPC Associations and Shared Security Groups.
  * api-change:``ecs``: This release supports service deployments and service revisions which provide
    a comprehensive view of your Amazon ECS service history.
  * api-change:``geo-maps``: Release of Amazon Location Maps API. Maps enables you to build digital
    maps that showcase your locations, visualize your data, and unlock insights to drive your business
  * api-change:``geo-places``: Release of Amazon Location Places API. Places enables you to quickly
    search, display, and filter places, businesses, and locations based on proximity, category, and name
  * api-change:``geo-routes``: Release of Amazon Location Routes API. Routes enables you to plan
    efficient routes and streamline deliveries by leveraging real-time traffic, vehicle restrictions,
    and turn-by-turn directions.
  * api-change:``keyspaces``: Adds support for interacting with user-defined types (UDTs) through the
    following new operations: Create-Type, Delete-Type, List-Types, Get-Type.
  * api-change:``network-firewall``: AWS Network Firewall now supports configuring TCP idle timeout
  * api-change:``opensearch``: This release introduces the new OpenSearch user interface
    (Dashboards), a new web-based application that can be associated with multiple data sources across
    OpenSearch managed clusters, serverless collections, and Amazon S3, so that users can gain a
    comprehensive insights in an unified interface.
  * api-change:``opensearchserverless``: Neo Integration via IAM Identity Center (IdC)
  * api-change:``redshift``: This release launches S3 event integrations to create and manage
    integrations from an Amazon S3 source into an Amazon Redshift database.
  * api-change:``redshift-serverless``: Adds and updates API members for the Redshift Serverless
    AI-driven scaling and optimization feature using the price-performance target setting.
  * api-change:``route53``: This release adds support for TLSA, SSHFP, SVCB, and HTTPS record types.
  * api-change:``sagemaker``: Added support for Model Registry Staging construct. Users can define
    series of stages that models can progress through for model workflows and lifecycle. This
    simplifies tracking and managing models as they transition through development, testing, and
    production stages.
  * api-change:``workmail``: This release adds support for Multi-Factor Authentication (MFA) and
    Personal Access Tokens through integration with AWS IAM Identity Center.
- from version 1.35.17
  * api-change:``bedrock``: Update Application Inference Profile
  * api-change:``bedrock-runtime``: Update Application Inference Profile
  * api-change:``cleanrooms``: This release adds the option for customers to configure analytics
    engine when creating a collaboration, and introduces the new SPARK analytics engine type in
    addition to maintaining the legacy CLEAN_ROOMS_SQL engine type.
  * api-change:``iotfleetwise``: Updated BatchCreateVehicle and BatchUpdateVehicle APIs:
    LimitExceededException has been added and the maximum number of vehicles in a batch has been set to
    10 explicitly
  * api-change:``logs``: Added support for new optional baseline parameter in the UpdateAnomaly API.
    For UpdateAnomaly requests with baseline set to True, The anomaly behavior is then treated as
    baseline behavior. However, more severe occurrences of this behavior will still be reported as
    anomalies.
  * api-change:``redshift-data``: Adding a new API GetStatementResultV2 that supports CSV formatted
    results from ExecuteStatement and BatchExecuteStatement calls.
  * api-change:``sagemaker``: Adding `notebook-al2-v3` as allowed value to SageMaker NotebookInstance
    PlatformIdentifier attribute
- from version 1.35.16
  * api-change:``mediapackagev2``: MediaPackage V2 Live to VOD Harvester is a MediaPackage V2
    feature, which is used to export content from an origin endpoint to a S3 bucket.
  * api-change:``opensearch``: Adds support for provisioning dedicated coordinator nodes. Coordinator
    nodes can be specified using the new NodeOptions parameter in ClusterConfig.
  * api-change:``rds``: This release adds support for Enhanced Monitoring and Performance Insights
    when restoring Aurora Limitless Database DB clusters. It also adds support for the os-upgrade
    pending maintenance action.
  * api-change:``storagegateway``: Documentation update: Amazon FSx File Gateway will no longer be
    available to new customers.
- from version 1.35.15
  * api-change:``bedrock-agent``: Add support of new model types for Bedrock Agents, Adding inference
    profile support for Flows and Prompt Management, Adding new field to configure additional inference
    configurations for Flows and Prompt Management
  * api-change:``codebuild``: AWS CodeBuild now supports automatically retrying failed builds
  * api-change:``lambda``: Add TagsError field in Lambda GetFunctionResponse. The TagsError field
    contains details related to errors retrieving tags.
  * api-change:``logs``: Adding inferred token name for dynamic tokens in Anomalies.
  * api-change:``supplychain``: API doc updates, and also support showing error message on a failed
    instance
- from version 1.35.14
  * api-change:``appconfig``: This release improves deployment safety by granting customers the
    ability to REVERT completed deployments, to the last known good state.In the StopDeployment API
    revert case the status of a COMPLETE deployment will be REVERTED. AppConfig only allows a revert
    within 72 hours of deployment completion.
  * api-change:``ec2``: This release includes a new API to describe some details of the Amazon
    Machine Images (AMIs) that were used to launch EC2 instances, even if those AMIs are no longer
    available for use.
  * api-change:``ecs``: This release adds support for EBS volumes attached to Amazon ECS Windows
    tasks running on EC2 instances.
  * api-change:``pcs``: Documentation update: added the default value of the Slurm configuration
    parameter scaleDownIdleTimeInSeconds to its description.
  * api-change:``qbusiness``: Add a new field in chat response. This field can be used to support
    nested schemas in array fields
  * bugfix:shorthand: Improve performance when parsing invalid shorthand syntax.
- Refresh patches for new version
  * ac_update-docutils.patch
- Relax upper version dependency for python-docutils in Requires
- Update Requires from setup.py
* Thu Oct 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.35.13
  * api-change:``bedrock``: Doc updates for supporting converse
  * api-change:``connect``: Amazon Connect Service Feature: Add support to start screen sharing for a
    web calling contact.
  * api-change:``ec2``: Amazon EC2 X8g, C8g and M8g instances are powered by AWS Graviton4
    processors. X8g provide the lowest cost per GiB of memory among Graviton4 instances. C8g provide
    the best price performance for compute-intensive workloads. M8g provide the best price performance
    in for general purpose workloads.
  * api-change:``mwaa``: Introducing InvokeRestApi which allows users to invoke the Apache Airflow
    REST API on the webserver with the specified inputs.
  * api-change:``payment-cryptography``: Add support for ECC P-256 and P-384 Keys.
  * api-change:``payment-cryptography-data``: Add ECDH support on PIN operations.
- from version 1.35.12
  * api-change:``bedrock-runtime``: Updating invoke regex to support imported models for converse API
  * api-change:``imagebuilder``: Add macOS platform and instance placement options
  * api-change:``m2``: Add AuthSecretsManagerArn optional parameter to batch job APIs, expand batch
    parameter limits, and introduce clientToken constraints.
  * api-change:``rds``: Global clusters now expose the Endpoint attribute as one of its fields. It is
    a Read/Write endpoint for the global cluster which resolves to the Global Cluster writer instance.
  * api-change:``repostspace``: Adds the BatchAddRole and BatchRemoveRole APIs.
  * api-change:``timestream-query``: This release adds support for Query Insights, a feature that
    provides details of query execution, enabling users to identify areas for improvement to optimize
    their queries, resulting in improved query performance and lower query costs.
- from version 1.35.11
  * api-change:``application-insights``: This feature enables customers to specify SNS Topic ARN.
    CloudWatch Application Insights (CWAI) will utilize this ARN to send problem notifications.
  * api-change:``autoscaling``: Adds support for removing the PlacementGroup setting on an Auto
    Scaling Group through the UpdateAutoScalingGroup API.
  * api-change:``bedrock-agent-runtime``: Knowledge Bases for Amazon Bedrock now supports custom
    prompts and model parameters in the orchestrationConfiguration of the RetrieveAndGenerate API. The
    modelArn field accepts Custom Models and Imported Models ARNs.
  * api-change:``dms``: Added support for tagging in StartReplicationTaskAssessmentRun API and
    introduced IsLatestTaskAssessmentRun and ResultStatistic fields for enhanced tracking and
    assessment result statistics.
  * api-change:``ec2``: Amazon EC2 now allows you to create network interfaces with just the EFA
    driver and no ENA driver by specifying the network interface type as efa-only.
  * api-change:``eks``: This release adds support for Amazon Application Recovery Controller (ARC)
    zonal shift and zonal autoshift with EKS that enhances the resiliency of multi-AZ cluster
    environments
  * api-change:``fms``: Update AWS WAF policy - add the option to retrofit existing web ACLs instead
    of creating all new web ACLs.
  * api-change:``payment-cryptography-data``: Adding new API to generate authenticated scripts for
    EMV pin change use cases.
  * api-change:``wafv2``: Add a property to WebACL to indicate whether it's been retrofitted by
    Firewall Manager.
- from version 1.35.10
  * api-change:``athena``: Removing FEDERATED from Create/List/Delete/GetDataCatalog API
  * api-change:``bedrock``: Adding converse support to CMI API's
  * api-change:``bedrock-runtime``: Added converse support for custom imported models
  * api-change:``datazone``: Adding the following project member designations:
    PROJECT_CATALOG_VIEWER, PROJECT_CATALOG_CONSUMER and PROJECT_CATALOG_STEWARD in the
    CreateProjectMembership API and PROJECT_CATALOG_STEWARD designation in the AddPolicyGrant API.
  * api-change:``ec2``: RequestSpotInstances and RequestSpotFleet feature release.
- from version 1.35.9
  * api-change:``bedrock-agent``: Removing support for topK property in
    PromptModelInferenceConfiguration object, Making PromptTemplateConfiguration property as required,
    Limiting the maximum PromptVariant to 1
  * api-change:``dataexchange``: This release adds Data Grant support, through which customers can
    programmatically create data grants to share with other AWS accounts and accept data grants from
    other AWS accounts.
  * api-change:``ecs``: This is an Amazon ECS documentation only update to address tickets.
  * api-change:``pinpoint-sms-voice-v2``: Added the registrations status of REQUIRES_AUTHENTICATION
  * api-change:``pipes``: This release adds validation to require specifying a SecurityGroup and
    Subnets in the Vpc object under PipesSourceSelfManagedKafkaParameters. It also adds support for
    iso-e, iso-f, and other non-commercial partitions in ARN parameters.
  * api-change:``quicksight``: Add StartDashboardSnapshotJobSchedule API. RestoreAnalysis now
    supports restoring analysis to folders.
  * api-change:``rds``: Updates Amazon RDS documentation for TAZ IAM support
  * api-change:``workspaces``: Updated the DomainName pattern for Active Directory
- from version 1.35.8
  * api-change:``s3``: Add support for the new optional bucket-region and prefix query parameters in
    the ListBuckets API. For ListBuckets requests that express pagination, Amazon S3 will now return
    both the bucket names and associated AWS regions in the response.
- from version 1.35.7
  * api-change:``amplify``: Added sourceUrlType field to StartDeployment request
  * api-change:``cloudformation``: Documentation update for AWS CloudFormation API Reference.
  * api-change:``codebuild``: Enable proxy for reserved capacity fleet.
  * api-change:``ivs``: On a channel that you own, you can now replace an ongoing stream with a new
    stream by streaming up with the priority parameter appended to the stream key.
  * api-change:``qbusiness``: Amazon Q Business now supports embedding the Amazon Q Business web
    experience on third-party websites.
  * api-change:``redshift``: This release launches the CreateIntegration, DeleteIntegration,
    DescribeIntegrations and ModifyIntegration APIs to create and manage Amazon Redshift Zero-ETL
    Integrations.
  * api-change:``resiliencehub``: AWS Resilience Hub now integrates with the myApplications platform,
    enabling customers to easily assess the resilience of applications defined in myApplications. The
    new Resiliency widget provides visibility into application resilience and actionable
    recommendations for improvement.
  * api-change:``sesv2``: This release adds support for email maximum delivery seconds that allows
    senders to control the time within which their emails are attempted for delivery.
- from version 1.35.6
  * api-change:``codepipeline``: AWS CodePipeline V2 type pipelines now support automatically
    retrying failed stages and skipping stage for failed entry conditions.
  * api-change:``mailmanager``: Mail Manager support for viewing and exporting metadata of archived
    messages.
  * api-change:``securitylake``: This release updates request validation regex for resource ARNs.
  * api-change:``supplychain``: This release adds AWS Supply Chain instance management functionality.
    Specifically adding CreateInstance, DeleteInstance, GetInstance, ListInstances, and UpdateInstance
    APIs.
  * api-change:``transfer``: This release enables customers using SFTP connectors to query the
    transfer status of their files to meet their monitoring needs as well as orchestrate post transfer
    actions.
- from version 1.35.5
  * api-change:``appflow``: Doc only updates for clarification around OAuth2GrantType for Salesforce.
  * api-change:``elbv2``: Add zonal_shift.config.enabled attribute. Add new AdministrativeOverride
    construct in the describe-target-health API response to include information about the override
    status applied to a target.
  * api-change:``emr``: This release provides new parameter "Context" in instance fleet clusters.
  * api-change:``guardduty``: Added a new field for network connection details.
  * api-change:``robomaker``: Documentation update: added support notices to each API action.
- from version 1.35.4
  * api-change:``acm-pca``: Documentation updates for AWS Private CA.
  * api-change:``dms``: Introduces DescribeDataMigrations, CreateDataMigration, ModifyDataMigration,
    DeleteDataMigration, StartDataMigration, StopDataMigration operations to SDK. Provides
    FailedDependencyFault error message.
  * api-change:``ec2``: This release adds support for assigning the billing of shared Amazon EC2
    On-Demand Capacity Reservations.
  * api-change:``ecs``: This is a documentation only release that updates to documentation to let
    customers know that Amazon Elastic Inference is no longer available.
  * api-change:``elastic-inference``: Elastic Inference - Documentation update to add service
    shutdown notice.
  * api-change:``iotfleetwise``: Refine campaign related API validations
  * api-change:``neptune-graph``: Support for 16 m-NCU graphs available through account allowlisting
  * api-change:``outposts``: Adding new "DELIVERED" enum value for Outposts Order status
  * api-change:``route53resolver``: Route 53 Resolver Forwarding Rules can now include a server name
    indication (SNI) in the target address for rules that use the DNS-over-HTTPS (DoH) protocol. When a
    DoH-enabled Outbound Resolver Endpoint forwards a request to a DoH server, it will provide the SNI
    in the TLS handshake.
  * api-change:``socialmessaging``: This release for AWS End User Messaging includes a public SDK,
    providing a suite of APIs that enable sending WhatsApp messages to end users.
  * api-change:``timestream-influxdb``: This release updates our regex based validation rules in
    regards to valid DbInstance and DbParameterGroup name.
- from version 1.35.3
  * api-change:``codepipeline``: AWS CodePipeline introduces a Compute category
- from version 1.35.2
  * api-change:``elasticache``: AWS ElastiCache SDK now supports using APIs with newly launched
    Valkey engine. Please refer to updated AWS ElastiCache public documentation for detailed
    information on API usage.
  * api-change:``memorydb``: Amazon MemoryDB SDK now supports all APIs for newly launched Valkey
    engine. Please refer to the updated Amazon MemoryDB public documentation for detailed information
    on API usage.
  * enhancement:``s3``: Adds logic to gracefully handle invalid timestamps returned in the Expires
    header.
- from version 1.35.1
  * api-change:``deadline``: Add support for using the template from a previous job during job
    creation and listing parameter definitions for a job.
  * api-change:``marketplace-reporting``: Documentation-only update for AWS Marketplace Reporting API.
  * api-change:``qconnect``: This release adds support for the following capabilities: Configuration
    of the Gen AI system via AIAgent and AIPrompts. Integration support for Bedrock Knowledge Base.
  * api-change:``redshift``: Add validation pattern to S3KeyPrefix on the EnableLogging API
- from version 1.35.0
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``iot-data``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * feature:s3: Adds ``--checksum-mode`` and ``--checksum-algorithm`` parameters to high-level ``s3``
    commands.
- from version 1.34.33
  * api-change:``codepipeline``: AWS CodePipeline introduces Commands action that enables you to
    easily run shell commands as part of your pipeline execution.
  * api-change:``connect``: Public GetMetricDataV2 Grouping increase from 3 to 4
  * api-change:``ec2``: This release includes a new API for modifying instance cpu-options after
    launch.
  * api-change:``iot``: This release adds support for Custom Authentication with X.509 Client
    Certificates, support for Custom Client Certificate validation, and support for selecting
    application protocol and authentication type without requiring TLS ALPN for customer's AWS IoT
    Domain Configurations.
  * api-change:``marketplace-reporting``: The AWS Marketplace Reporting service introduces the
    GetBuyerDashboard API. This API returns a dashboard that provides visibility into your
    organization's AWS Marketplace agreements and associated spend across the AWS accounts in your
    organization.
  * api-change:``mediapackagev2``: Added support for ClipStartTime on the FilterConfiguration object
    on OriginEndpoint manifest settings objects. Added support for EXT-X-START tags on produced HLS
    child playlists.
  * api-change:``quicksight``: QuickSight: Add support for exporting and importing folders in
    AssetBundle APIs
- from version 1.34.32
  * api-change:``appstream``: Added support for Automatic Time Zone Redirection on Amazon AppStream
    2.0
  * api-change:``b2bi``: Added and updated APIs to support outbound EDI transformations
  * api-change:``bedrock-agent-runtime``: Added raw model response and usage metrics to PreProcessing
    and PostProcessing Trace
  * api-change:``bedrock-runtime``: Added new fields to Amazon Bedrock Guardrails trace
  * api-change:``iotdeviceadvisor``: Add clientToken attribute and implement idempotency for
    CreateSuiteDefinition.
  * api-change:``ivs-realtime``: Adds new Stage Health EventErrorCodes applicable to RTMP(S)
    broadcasts. Bug Fix: Enforces that EncoderConfiguration Video height and width must be even-number
    values.
  * api-change:``s3``: This release introduces a header representing the minimum object size limit
    for Lifecycle transitions.
  * api-change:``sagemaker``: releasing builtinlcc to public
  * api-change:``workspaces``: WSP is being rebranded to become DCV.
- from version 1.34.31
  * api-change:``bedrock-agent``: This release adds support to stop an ongoing ingestion job using
    the StopIngestionJob API in Agents for Amazon Bedrock.
  * api-change:``codeartifact``: Add support for the dual stack endpoints.
  * api-change:``rds``: This release provides additional support for enabling Aurora Limitless
    Database DB clusters.
- from version 1.34.30
  * api-change:``bedrock``: Add support for custom models via provisioned throughput for Bedrock
    Model Evaluation
  * api-change:``clouddirectory``: Add examples for API operations in model.
  * api-change:``connect``: Amazon Connect introduces StartOutboundChatContact API allowing customers
    to initiate outbound chat contacts
  * api-change:``pricing``: Add examples for API operations in model.
  * api-change:``resource-groups``: This update includes new APIs to support application groups and
    to allow users to manage resource tag-sync tasks in applications.
  * api-change:``supplychain``: Release DataLakeDataset, DataIntegrationFlow and ResourceTagging APIs
    for AWS Supply Chain
  * api-change:``timestream-influxdb``: Timestream for InfluxDB now supports port configuration and
    additional customer-modifiable InfluxDB v2 parameters. This release adds Port to the
    CreateDbInstance and UpdateDbInstance API, and additional InfluxDB v2 parameters to the
    CreateDbParameterGroup API.
  * api-change:``verifiedpermissions``: Add examples for API operations in model.
- from version 1.34.29
  * api-change:``customer-profiles``: Introduces optional RoleArn parameter for PutIntegration
    request and includes RoleArn in the response of PutIntegration, GetIntegration and ListIntegrations
  * api-change:``quicksight``: Adding personalization in QuickSight data stories. Admins can enable
    or disable personalization through QuickSight settings.
  * api-change:``securityhub``: Documentation updates for AWS Security Hub
  * api-change:``sesv2``: This release adds support for engagement tracking over Https using custom
    domains.
- from version 1.34.28
  * api-change:``chatbot``: Return State and StateReason fields for Chatbot Channel Configurations.
  * api-change:``lambda``: Reverting Lambda resource-based policy and block public access APIs.
  * api-change:``organizations``: Add support for policy operations on the CHATBOT_POLICY policy type.
  * api-change:``pcs``: AWS PCS API documentation - Edited the description of the
    iamInstanceProfileArn parameter of the CreateComputeNodeGroup and UpdateComputeNodeGroup actions;
    edited the description of the SlurmCustomSetting data type to list the supported parameters for
    clusters and compute node groups.
  * api-change:``rds-data``: Documentation update for RDS Data API to reflect support for Aurora
    MySQL Serverless v2 and Provisioned DB clusters.
  * api-change:``sagemaker``: Adding `TagPropagation` attribute to Sagemaker API
- from version 1.34.27
  * api-change:``cloudtrail``: Doc-only update for CloudTrail network activity events release (in
    preview)
  * api-change:``ec2``: Updates to documentation for the transit gateway security group referencing
    feature.
  * api-change:``fsx``: Doc-only update to address Lustre S3 hard-coded names.
- from version 1.34.26
  * api-change:``bedrock``: Add support for Cross Region Inference in Bedrock Model Evaluations.
  * api-change:``budgets``: Releasing minor partitional endpoint updates
  * api-change:``kinesis``: This release includes support to add tags when creating a stream
  * api-change:``pinpoint-sms-voice-v2``: AWS End User Messaging SMS-Voice V2 has added support for
    resource policies. Use the three new APIs to create, view, edit, and delete resource policies.
  * api-change:``sagemaker``: Adding `HiddenInstanceTypes` and `HiddenSageMakerImageVersionAliases`
    attribute to SageMaker API
- from version 1.34.25
  * api-change:``apigateway``: Documentation updates for Amazon API Gateway
  * api-change:``athena``: List/Get/Update/Delete/CreateDataCatalog now integrate with AWS Glue
    connections. Users can create a Glue connection through Athena or use a Glue connection to define
    their Athena federated parameters.
  * api-change:``bedrock-agent``: Amazon Bedrock Prompt Flows and Prompt Management now supports
    using inference profiles to increase throughput and improve resilience.
  * api-change:``ec2``: Amazon EC2 G6e instances powered by NVIDIA L40S Tensor Core GPUs are the most
    cost-efficient GPU instances for deploying generative AI models and the highest performance GPU
    instances for spatial computing workloads.
  * api-change:``emr-serverless``: This release adds support for job concurrency and queuing
    configuration at Application level.
  * api-change:``glue``: Added AthenaProperties parameter to Glue Connections, allowing Athena to
    store service specific properties on Glue Connections.
  * api-change:``rds``: Support ComputeRedundancy parameter in ModifyDBShardGroup API. Add
    DBShardGroupArn in DBShardGroup API response. Remove InvalidMaxAcuFault from CreateDBShardGroup and
    ModifyDBShardGroup API. Both API will throw InvalidParameterValueException for invalid ACU
    configuration.
  * api-change:``resource-explorer-2``: AWS Resource Explorer released ListResources feature which
    allows customers to list all indexed AWS resources within a view.
- from version 1.34.24
  * api-change:``dynamodb``: Generate account endpoint for DynamoDB requests when the account ID is
    available
  * api-change:``neptune``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``sagemaker``: Amazon SageMaker now supports using manifest files to specify the
    location of uncompressed model artifacts within Model Packages
  * api-change:``sagemaker-metrics``: This release introduces support for the SageMaker Metrics
    BatchGetMetrics API.
  * api-change:``workspaces``: Releasing new ErrorCodes for SysPrep failures during ImageImport and
    CreateImage process
  * enhancement:paginator: Add warning when a non-positive value is provided for the max-items
    pagination parameter.
- from version 1.34.23
  * api-change:``codeconnections``: This release adds the PullRequestComment field to
    CreateSyncConfiguration API input, UpdateSyncConfiguration API input, GetSyncConfiguration API
    output and ListSyncConfiguration API output
  * api-change:``glue``: This change is for releasing TestConnection api SDK model
  * api-change:``lambda``: Tagging support for Lambda event source mapping, and code signing
    configuration resources.
  * api-change:``mediaconvert``: This release provides support for additional DRM configurations per
    SPEKE Version 2.0.
  * api-change:``medialive``: Adds Bandwidth Reduction Filtering for HD AVC and HEVC encodes,
    multiplex container settings.
  * api-change:``quicksight``: QuickSight: 1. Add new API - ListFoldersForResource. 2. Commit mode
    adds visibility configuration of Apply button on multi-select controls for authors.
  * api-change:``sagemaker``: Introduced support for G6e instance types on SageMaker Studio for
    JupyterLab and CodeEditor applications.
  * api-change:``workspaces-web``: WorkSpaces Secure Browser now enables Administrators to view and
    manage end-user browsing sessions via Session Management APIs.
- from version 1.34.22
  * api-change:``ce``: This release extends the GetReservationPurchaseRecommendation API to support
    recommendations for Amazon DynamoDB reservations.
  * api-change:``ds``: Added new APIs for enabling, disabling, and describing access to the AWS
    Directory Service Data API
  * api-change:``ds-data``: Added new AWS Directory Service Data API, enabling you to manage data
    stored in AWS Directory Service directories. This includes APIs for creating, reading, updating,
    and deleting directory users, groups, and group memberships.
  * api-change:``guardduty``: Add `launchType` and `sourceIPs` fields to GuardDuty findings.
  * api-change:``mailmanager``: Introduce a new RuleSet condition evaluation, where customers can set
    up a StringExpression with a MimeHeader condition. This condition will perform the necessary
    validation based on the X-header provided by customers.
  * api-change:``rds``: Updates Amazon RDS documentation with information upgrading snapshots with
    unsupported engine versions for RDS for MySQL and RDS for PostgreSQL.
  * api-change:``s3``: Added SSE-KMS support for directory buckets.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Fri Sep 20 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.34.21
  * api-change:``codebuild``: GitLab Enhancements - Add support for Self-Hosted GitLab runners in
    CodeBuild. Add group webhooks
  * api-change:``ecr``: The `DescribeImageScanning` API now includes `fixAvailable`,
    `exploitAvailable`, and `fixedInVersion` fields to provide more detailed information about the
    availability of fixes, exploits, and fixed versions for identified image vulnerabilities.
  * api-change:``ecs``: This is a documentation only release to address various tickets.
  * api-change:``lambda``: Support for JSON resource-based policies and block public access
  * api-change:``rds``: Updates Amazon RDS documentation with configuration information about the
    BYOL model for RDS for Db2.
  * api-change:``ssm``: Support for additional levels of cross-account, cross-Region organizational
    units in Automation. Various documentation updates.
- from version 1.34.20
  * api-change:``bedrock``: This feature adds cross account s3 bucket and VPC support to
    ModelInvocation jobs. To use a cross account bucket, pass in the accountId of the bucket to
    s3BucketOwner in the ModelInvocationJobInputDataConfig or ModelInvocationJobOutputDataConfig.
  * api-change:``iot``: This release adds additional enhancements to AWS IoT Device Management
    Software Package Catalog and Jobs. It also adds SBOM support in Software Package Version.
  * api-change:``medialive``: Removing the ON_PREMISE enum from the input settings field.
  * api-change:``organizations``: Doc only update for AWS Organizations that fixes several
    customer-reported issues
  * api-change:``pca-connector-scep``: This is a general availability (GA) release of Connector for
    SCEP, a feature of AWS Private CA. Connector for SCEP links your SCEP-enabled and mobile device
    management systems to AWS Private CA for digital signature installation and certificate management.
  * api-change:``rds``: Launching Global Cluster tagging.
- from version 1.34.19
  * api-change:``amplify``: Doc only update to Amplify to explain platform setting for Next.js 14 SSG
    only applications
  * api-change:``ivs``: Updates to all tags descriptions.
  * api-change:``ivschat``: Updates to all tags descriptions.
- from version 1.34.18
  * api-change:``cognito-idp``: Added email MFA option to user pools with advanced security features.
  * api-change:``elbv2``: Correct incorrectly mapped error in ELBv2 waiters
  * api-change:``emr``: Update APIs to allow modification of ODCR options, allocation strategy, and
    InstanceTypeConfigs on running InstanceFleet clusters.
  * api-change:``glue``: AWS Glue is introducing two new optimizers for Apache Iceberg tables:
    snapshot retention and orphan file deletion. Customers can enable these optimizers and customize
    their configurations to perform daily maintenance tasks on their Iceberg tables based on their
    specific requirements.
  * api-change:``mediaconvert``: This release includes support for dynamic video overlay workflows,
    including picture-in-picture and squeezeback
  * api-change:``rds``: This release adds support for the os-upgrade pending maintenance action for
    Amazon Aurora DB clusters.
  * api-change:``storagegateway``: The S3 File Gateway now supports DSSE-KMS encryption. A new
    parameter EncryptionType is added to these APIs: CreateSmbFileShare, CreateNfsFileShare,
    UpdateSmbFileShare, UpdateNfsFileShare, DescribeSmbFileShares, DescribeNfsFileShares. Also, in
    favor of EncryptionType, KmsEncrypted is deprecated.
  * api-change:``synthetics``: This release introduces two features. The first is tag replication,
    which allows for the propagation of canary tags onto Synthetics related resources, such as Lambda
    functions. The second is a limit increase in canary name length, which has now been increased from
    21 to 255 characters.
- from version 1.34.17
  * api-change:``bedrock-agent``: Amazon Bedrock Knowledge Bases now supports using inference
    profiles to increase throughput and improve resilience.
  * api-change:``bedrock-agent-runtime``: Amazon Bedrock Knowledge Bases now supports using inference
    profiles to increase throughput and improve resilience.
  * api-change:``ecr``: Added KMS_DSSE to EncryptionType
  * api-change:``guardduty``: Add support for new statistic types in GetFindingsStatistics.
  * api-change:``lexv2-models``: Support new Polly voice engines in VoiceSettings: long-form and
    generative
  * api-change:``medialive``: Adds AV1 Codec support, SRT ouputs, and MediaLive Anywhere support.
- from version 1.34.16
  * api-change:``chime-sdk-voice``: Documentation-only update that clarifies the ValidateE911Address
    action of the Amazon Chime SDK Voice APIs.
  * api-change:``cognito-identity``: This release adds sensitive trait to some required shapes.
  * api-change:``pipes``: This release adds support for customer managed KMS keys in Amazon
    EventBridge Pipe
  * api-change:``securityhub``: Documentation update for Security Hub
- from version 1.34.15
  * api-change:``dynamodb``: Doc-only update for DynamoDB. Added information about async behavior for
    TagResource and UntagResource APIs and updated the description of ResourceInUseException.
  * api-change:``elbv2``: Add paginators for the ELBv2 DescribeListenerCertificates and DescribeRules
    APIs. Fix broken waiter for the ELBv2 DescribeLoadBalancers API.
  * api-change:``ivs-realtime``: IVS Real-Time now offers customers the ability to broadcast to
    Stages using RTMP(S).
  * api-change:``kafka``: Amazon MSK Replicator can now replicate data to identically named topics
    between MSK clusters within the same AWS Region or across different AWS Regions.
  * api-change:``sagemaker``: Amazon Sagemaker supports orchestrating SageMaker HyperPod clusters
    with Amazon EKS
  * api-change:``sagemaker-runtime``: AWS SageMaker Runtime feature: Add sticky routing to support
    stateful inference models.
- from version 1.34.14
  * api-change:``qapps``: Adds UpdateLibraryItemMetadata api to change status of app for admin
    verification feature and returns isVerified field in any api returning the app or library item.
- from version 1.34.13
  * api-change:``application-signals``: Amazon CloudWatch Application Signals now supports creating
    Service Level Objectives using a new calculation type. Users can now create SLOs which are
    configured with request-based SLIs to help meet their specific business requirements.
  * api-change:``codepipeline``: Updates to add recent notes to APIs and to replace example S3 bucket
    names globally.
  * api-change:``connect``: Amazon Connect Custom Vocabulary now supports Catalan (Spain), Danish
    (Denmark), Dutch (Netherlands), Finnish (Finland), Indonesian (Indonesia), Malay (Malaysia),
    Norwegian Bokmal (Norway), Polish (Poland), Swedish (Sweden), and Tagalog/Filipino (Philippines).
  * api-change:``gamelift``: Amazon GameLift provides additional events for tracking the fleet
    creation process.
  * api-change:``kinesisanalyticsv2``: Support for Flink 1.20 in Managed Service for Apache Flink
  * api-change:``sagemaker``: Amazon SageMaker now supports idle shutdown of JupyterLab and
    CodeEditor applications on SageMaker Studio.
- from version 1.34.12
  * api-change:``appsync``: Adds new logging levels (INFO and DEBUG) for additional log output control
  * api-change:``bedrock-agent``: Add support for user metadata inside PromptVariant.
  * api-change:``finspace``: Updates Finspace documentation for smaller instances.
  * api-change:``fis``: This release adds safety levers, a new mechanism to stop all running
    experiments and prevent new experiments from starting.
  * api-change:``logs``: Update to support new APIs for delivery of logs from AWS services.
  * api-change:``s3control``: Amazon Simple Storage Service /S3 Access Grants / Features : This
    release launches new Access Grants API - ListCallerAccessGrants.
- from version 1.34.11
  * api-change:``connect``: Release ReplicaConfiguration as part of DescribeInstance
  * api-change:``datazone``: Add support to let data publisher specify a subset of the data asset
    that a subscriber will have access to based on the asset filters provided, when accepting a
    subscription request.
  * api-change:``elbv2``: This release adds support for configuring TCP idle timeout on NLB and GWLB
    listeners.
  * api-change:``mediaconnect``: AWS Elemental MediaConnect introduces thumbnails for Flow source
    monitoring. Thumbnails provide still image previews of the live content feeding your MediaConnect
    Flow allowing you to easily verify that your source is operating as expected.
  * api-change:``medialive``: Added MinQP as a Rate Control option for H264 and H265 encodes.
  * api-change:``sagemaker``: Amazon SageMaker now supports automatic mounting of a user's home
    folder in the Amazon Elastic File System (EFS) associated with the SageMaker Studio domain to their
    Studio Spaces to enable users to share data between their own private spaces.
  * api-change:``timestream-influxdb``: Timestream for InfluxDB now supports compute scaling and
    deployment type conversion. This release adds the DbInstanceType and DeploymentType parameters to
    the UpdateDbInstance API.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Wed Sep  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.34.10
  * api-change:``backup``: The latest update introduces two new attributes, VaultType and VaultState,
    to the DescribeBackupVault and ListBackupVaults APIs. The VaultState attribute reflects the current
    status of the vault, while the VaultType attribute indicates the specific category of the vault.
  * api-change:``datazone``: Amazon DataZone now adds new governance capabilities of Domain Units for
    organization within your Data Domains, and Authorization Policies for tighter controls.
  * api-change:``logs``: This release introduces a new optional parameter: Entity, in PutLogEvents
    request
  * api-change:``redshift-data``: The release include the new Redshift DataAPI feature for session
    use, customer execute query with --session-keep-alive-seconds parameter and can submit follow-up
    queries to same sessions with returned`session-id`
- from version 1.34.9
  * api-change:``bedrock-agent-runtime``: Lifting the maximum length on Bedrock KnowledgeBase
    RetrievalFilter array
  * api-change:``bedrock-runtime``: Add support for imported-model in invokeModel and
    InvokeModelWithResponseStream.
  * api-change:``personalize``: This releases ability to update automatic training scheduler for
    customer solutions
  * api-change:``quicksight``: Increased Character Limit for Dataset Calculation Field expressions
  * api-change:``stepfunctions``: This release adds support for static analysis to
    ValidateStateMachineDefinition API, which can now return optional WARNING diagnostics for semantic
    errors on the definition of an Amazon States Language (ASL) state machine.
  * api-change:``wafv2``: The minimum request rate for a rate-based rule is now 10. Before this, it
    was 100.
- from version 1.34.8
  * api-change:``appconfig``: This release adds support for deletion protection, which is a safety
    guardrail to prevent the unintentional deletion of a recently used AWS AppConfig Configuration
    Profile or Environment. This also includes a change to increase the maximum length of the Name
    parameter in UpdateConfigurationProfile.
  * api-change:``datazone``: Update regex to include dot character to be consistent with IAM role
    creation in the authorized principal field for create and update subscription target.
  * api-change:``devicefarm``: This release removed support for Calabash, UI Automation, Built-in
    Explorer, remote access record, remote access replay, and web performance profile framework in
    ScheduleRun API.
  * api-change:``ec2``: Amazon VPC IP Address Manager (IPAM) now allows customers to provision IPv4
    CIDR blocks and allocate Elastic IP Addresses directly from IPAM pools with public IPv4 space
  * api-change:``internetmonitor``: Adds new querying types to show overall traffic suggestion
    information for monitors
  * api-change:``pcs``: Introducing AWS Parallel Computing Service (AWS PCS), a new service makes it
    easy to setup and manage high performance computing (HPC) clusters, and build scientific and
    engineering models at virtually any scale on AWS.
  * api-change:``workspaces``: Documentation-only update that clarifies the StartWorkspaces and
    StopWorkspaces actions, and a few other minor edits.
- from version 1.34.7
  * api-change:``bedrock``: Amazon Bedrock SDK updates for Inference Profile.
  * api-change:``bedrock-runtime``: Amazon Bedrock SDK updates for Inference Profile.
  * api-change:``chatbot``: Update documentation to be consistent with the API docs
  * api-change:``omics``: Adds data provenance to import jobs from read sets and references
  * api-change:``polly``: Amazon Polly adds 2 new voices: Jitka (cs-CZ) and Sabrina (de-CH).
- from version 1.34.6
  * api-change:``iotsitewise``: AWS IoT SiteWise now supports versioning for asset models. It enables
    users to retrieve active version of their asset model and perform asset model writes with
    optimistic lock.
  * api-change:``workspaces``: This release adds support for creating and managing directories that
    use AWS IAM Identity Center as user identity source. Such directories can be used to create
    non-Active Directory domain joined WorkSpaces Personal.Updated RegisterWorkspaceDirectory and
    DescribeWorkspaceDirectories APIs.
- from version 1.34.5
  * api-change:``bedrock-agent``: Releasing the support for Action User Confirmation.
  * api-change:``bedrock-agent-runtime``: Releasing the support for Action User Confirmation.
  * api-change:``codebuild``: Added support for the MAC_ARM environment type for CodeBuild fleets.
  * api-change:``organizations``: Releasing minor partitional endpoint updates.
  * api-change:``qbusiness``: Amazon QBusiness: Enable support for SAML and OIDC federation through
    AWS IAM Identity Provider integration.
  * api-change:``supplychain``: Update API documentation to clarify the event SLA as well as the data
    model expectations
- from version 1.34.4
  * api-change:``autoscaling``: Amazon EC2 Auto Scaling now provides EBS health check to manage EC2
    instance replacement
  * api-change:``bedrock``: Amazon Bedrock Evaluation BatchDeleteEvaluationJob API allows customers
    to delete evaluation jobs under terminated evaluation job statuses - Stopped, Failed, or Completed.
    Customers can submit a batch of 25 evaluation jobs to be deleted at once.
  * api-change:``emr-containers``: Correct endpoint for FIPS is configured for US Gov Regions.
  * api-change:``inspector2``: Add enums for Agentless scan statuses and EC2 enablement error states
  * api-change:``quicksight``: Explicit query for authors and dashboard viewing sharing for embedded
    users
  * api-change:``route53``: Amazon Route 53 now supports the Asia Pacific (Malaysia) Region
    (ap-southeast-5) for latency records, geoproximity records, and private DNS for Amazon VPCs in that
    region.
- from version 1.34.3
  * api-change:``ec2``: DescribeInstanceStatus now returns health information on EBS volumes attached
    to Nitro instances
  * api-change:``entityresolution``: Increase the mapping attributes in Schema to 35.
  * api-change:``glue``: Add optional field JobRunQueuingEnabled to CreateJob and UpdateJob APIs.
  * api-change:``lambda``: Release FilterCriteria encryption for Lambda EventSourceMapping,  enabling
    customers to encrypt their filter criteria using a customer-owned KMS key.
  * api-change:``securityhub``: Security Hub documentation and definition updates
  * api-change:``ses``: Enable email receiving customers to provide SES with access to their S3
    buckets via an IAM role for "Deliver to S3 Action"
- from version 1.34.2
  * api-change:``ecs``: Documentation only release to address various tickets
  * api-change:``opensearchserverless``: Added FailureCode and FailureMessage to
    BatchGetCollectionResponse for BatchGetVPCEResponse for non-Active Collection and VPCE.
  * api-change:``s3``: Amazon Simple Storage Service / Features : Add support for conditional writes
    for PutObject and CompleteMultipartUpload APIs.
- from version 1.34.1
  * api-change:``bedrock``: Amazon Bedrock Batch Inference/ Model Invocation is a feature which
    allows customers to asynchronously run inference on a large set of records/files stored in S3.
  * api-change:``codebuild``: AWS CodeBuild now supports creating fleets with macOS platform for
    running builds.
  * api-change:``deadline``: This release adds additional search fields and provides sorting by
    multiple fields.
  * api-change:``lambda``: Release Lambda FunctionRecursiveConfig, enabling customers to turn
    recursive loop detection on or off on individual functions. This release adds two new APIs,
    GetFunctionRecursionConfig and PutFunctionRecursionConfig.
  * api-change:``ssm-sap``: Add new attributes to the outputs of GetApplication and GetDatabase APIs.
- from version 1.34.0
  * api-change:``batch``: Improvements of integration between AWS Batch and EC2.
  * api-change:``inspector2``: Update the correct format of key and values for resource tags
  * api-change:``quicksight``: Amazon QuickSight launches Customer Managed Key (CMK) encryption for
    Data Source metadata
  * api-change:``sagemaker``: Introduce Endpoint and EndpointConfig Arns in
    sagemaker:ListPipelineExecutionSteps API response
  * api-change:``sesv2``: Marking use case description field of account details as deprecated.
  * enhancement:``codeartifact``: Update login command error message.
- from version 1.33.44
  * api-change:``docdb``: This release adds Global Cluster Failover capability which enables you to
    change your global cluster's primary AWS region, the region that serves writes, during a regional
    outage. Performing a failover action preserves your Global Cluster setup.
  * api-change:``ecs``: This release introduces a new ContainerDefinition configuration to support
    the customer-managed keys for ECS container restart feature.
  * api-change:``iam``: Make the LastUsedDate field in the GetAccessKeyLastUsed response optional.
    This may break customers who only call the API for access keys with a valid LastUsedDate. This
    fixes a deserialization issue for access keys without a LastUsedDate, because the field was marked
    as required but could be null.
  * api-change:``s3``: Amazon Simple Storage Service / Features  : Adds support for pagination in the
    S3 ListBuckets API.
- from version 1.33.43
  * api-change:``codebuild``: AWS CodeBuild now supports using Secrets Manager to store git
    credentials and using multiple source credentials in a single project.
- from version 1.33.42
  * api-change:``amplify``: Add a new field "cacheConfig" that enables users to configure the CDN
    cache settings for an App
  * api-change:``appstream``: This release includes following new APIs: CreateThemeForStack,
    DescribeThemeForStack, UpdateThemeForStack, DeleteThemeForStack to support custom branding
    programmatically.
  * api-change:``fis``: This release adds support for additional error information on experiment
    failure. It adds the error code, location, and account id on relevant failures to the GetExperiment
    and ListExperiment API responses.
  * api-change:``glue``: Add AttributesToGet parameter support for Glue GetTables
  * api-change:``neptune-graph``: Amazon Neptune Analytics provides a new option for customers to
    load data into a graph using the RDF (Resource Description Framework) NTRIPLES format. When loading
    NTRIPLES files, use the value `convertToIri` for the `blankNodeHandling` parameter.
- from version 1.33.41
  * api-change:``compute-optimizer``: Doc only update for Compute Optimizer that fixes several
    customer-reported issues relating to ECS finding classifications
  * api-change:``config``: Documentation update for the OrganizationConfigRuleName regex pattern.
  * api-change:``ec2``: This release adds new capabilities to manage On-Demand Capacity Reservations
    including the ability to split your reservation, move capacity between reservations, and modify the
    instance eligibility of your reservation.
  * api-change:``eks``: Added support for new AL2023 GPU AMIs to the supported AMITypes.
  * api-change:``groundstation``: Updating documentation for OEMEphemeris to link to AWS Ground
    Station User Guide
  * api-change:``medialive``: AWS Elemental MediaLive now supports now supports editing the PID
    values for a Multiplex.
  * api-change:``sagemaker``: Releasing large data support as part of CreateAutoMLJobV2 in SageMaker
    Autopilot and CreateDomain API for SageMaker Canvas.
- from version 1.33.40
  * api-change:``cognito-idp``: Fixed a description of AdvancedSecurityAdditionalFlows in Amazon
    Cognito user pool configuration.
  * api-change:``connect``: This release supports adding RoutingCriteria via UpdateContactRoutingData
    public API.
  * api-change:``ssm``: Systems Manager doc-only updates for August 2024.
- from version 1.33.39
  * api-change:``cognito-idp``: Added support for threat protection for custom authentication in
    Amazon Cognito user pools.
  * api-change:``connect``: This release fixes a regression in number of access control tags that are
    allowed to be added to a security profile in Amazon Connect. You can now add up to four access
    control tags on a single security profile.
  * api-change:``ec2``: Launch of private IPv6 addressing for VPCs and Subnets. VPC IPAM supports the
    planning and monitoring of private IPv6 usage.
  * api-change:``glue``: This release adds support to retrieve the validation status when creating or
    updating Glue Data Catalog Views. Also added is support for BasicCatalogTarget partition keys.
- from version 1.33.38
  * api-change:``appintegrations``: Updated CreateDataIntegration and
    CreateDataIntegrationAssociation API to support bulk data export from Amazon Connect Customer
    Profiles to the customer S3 bucket.
  * api-change:``glue``: Introducing AWS Glue Data Quality anomaly detection, a new functionality
    that uses ML-based solutions to detect data anomalies users have not explicitly defined rules for.
- from version 1.33.37
  * api-change:``bedrock-agent-runtime``: Introduce model invocation output traces for orchestration
    traces, which contain the model's raw response and usage.
  * api-change:``cognito-idp``: Advanced security feature updates to include password history and log
    export for Cognito user pools.
  * api-change:``cost-optimization-hub``: This release adds savings percentage support to the
    ListRecommendationSummaries API.
  * api-change:``workspaces``: Added support for BYOL_GRAPHICS_G4DN_WSP IngestionProcess
- from version 1.33.36
  * api-change:``datazone``: This releases Data Product feature. Data Products allow grouping data
    assets into cohesive, self-contained units for ease of publishing for data producers, and ease of
    finding and accessing for data consumers.
  * api-change:``ecr``: Released two new APIs along with documentation updates. The GetAccountSetting
    API is used to view the current basic scan type version setting for your registry, while the
    PutAccountSetting API is used to update the basic scan type version for your registry.
  * api-change:``kinesis-video-webrtc-storage``: Add JoinStorageSessionAsViewer API
  * api-change:``pi``: Added a description for the Dimension db.sql.tokenized_id on the
    DimensionGroup data type page.
- from version 1.33.35
  * api-change:``cloudwatch``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``kinesis``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``resiliencehub``: Customers are presented with the grouping recommendations and can
    determine if the recommendations are accurate and apply to their case. This feature simplifies
    onboarding by organizing resources into appropriate AppComponents.
  * api-change:``route53``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``waf-regional``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
- from version 1.33.34
  * api-change:``bedrock``: API and Documentation for Bedrock Model Copy feature. This feature lets
    you share and copy a custom model from one region to another or one account to another.
  * api-change:``controlcatalog``: AWS Control Tower provides two new public APIs
    controlcatalog:ListControls and controlcatalog:GetControl under controlcatalog service namespace,
    which enable customers to programmatically retrieve control metadata of available controls.
  * api-change:``controltower``: Updated Control Tower service documentation for controlcatalog
    control ARN support with existing Control Tower public APIs
  * api-change:``iam``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``memorydb``: Doc only update for changes to deletion API.
  * api-change:``rds``: This release adds support for specifying optional MinACU parameter in
    CreateDBShardGroup and ModifyDBShardGroup API. DBShardGroup response will contain MinACU if
    specified.
  * api-change:``sagemaker``: This release adds support for Amazon EMR Serverless applications in
    SageMaker Studio for running data processing jobs.
  * api-change:``ssm-quicksetup``: This release adds API support for the QuickSetup feature of AWS
    Systems Manager
  * api-change:``support``: Doc only updates to CaseDetails
- from version 1.33.33
  * api-change:``appstream``: Added support for Red Hat Enterprise Linux 8 on Amazon AppStream 2.0
  * api-change:``autoscaling``: Increase the length limit for VPCZoneIdentifier from 2047 to 5000
  * api-change:``codepipeline``: AWS CodePipeline V2 type pipelines now support stage level
    conditions to enable development teams to safely release changes that meet quality and compliance
    requirements.
  * api-change:``elasticache``: Doc only update for changes to deletion API.
  * api-change:``elb``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``events``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``lexv2-models``: This release adds new capabilities to the AMAZON.QnAIntent: Custom
    prompting, Guardrails integration and ExactResponse support for Bedrock Knowledge Base.
  * api-change:``logs``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``rolesanywhere``: IAM RolesAnywhere now supports custom role session name on the
    CreateSession. This release adds the acceptRoleSessionName option to a profile to control whether a
    role session name will be accepted in a session request with a given profile.
  * api-change:``tnb``: This release adds Network Service Update, through which customers will be
    able to update their instantiated networks to a new network package. See the documentation for
    limitations. The release also enhances the Get network operation API to return parameter overrides
    used during the operation.
  * api-change:``workspaces``: Removing multi-session as it isn't supported for pools
  * bugfix:``s3``: Disable usage of mb command with S3 Express directory buckets.
- from version 1.33.32
  * api-change:``elasticache``: Renaming full service name as it appears in developer documentation.
  * api-change:``memorydb``: Renaming full service name as it appears in developer documentation.
- from version 1.33.31
  * api-change:``application-autoscaling``: Application Auto Scaling is now more responsive to the
    changes in demand of your SageMaker Inference endpoints. To get started, create or update a Target
    Tracking policy based on High Resolution CloudWatch metrics.
  * api-change:``application-signals``: CloudWatch Application Signals now supports application logs
    correlation with traces and operational health metrics of applications running on EC2 instances.
    Users can view the most relevant telemetry to troubleshoot application health anomalies such as
    spikes in latency, errors, and availability.
  * api-change:``bedrock-runtime``: Provides ServiceUnavailableException error message
  * api-change:``codecommit``: CreateRepository API now throws OperationNotAllowedException when the
    account has been restricted from creating a repository.
  * api-change:``datazone``: Introduces GetEnvironmentCredentials operation to SDK
  * api-change:``ec2``: EC2 Fleet now supports using custom identifiers to reference Amazon Machine
    Images (AMI) in launch requests that are configured to choose from a diversified list of instance
    types.
  * api-change:``ecr``: API and documentation updates for Amazon ECR, adding support for creating,
    updating, describing and deleting ECR Repository Creation Template.
  * api-change:``eks``: This release adds support for EKS cluster to manage extended support.
  * api-change:``elbv2``: This release adds support for sharing trust stores across accounts and
    organizations through integration with AWS Resource Access Manager.
  * api-change:``network-firewall``: You can now log events that are related to TLS inspection, in
    addition to the existing alert and flow logging.
  * api-change:``outposts``: Adding default vCPU information to GetOutpostSupportedInstanceTypes and
    GetOutpostInstanceTypes responses
  * api-change:``stepfunctions``: This release adds support to customer managed KMS key encryption in
    AWS Step Functions.
- from version 1.33.30
  * api-change:``cleanrooms``: Three enhancements to the AWS Clean Rooms: Disallowed Output Columns,
    Flexible Result Receivers, SQL as a Seed
  * api-change:``dynamodb``: DynamoDB doc only update for July
  * api-change:``iotsitewise``: Adds support for creating SiteWise Edge gateways that run on a
    Siemens Industrial Edge Device.
  * api-change:``mediapackagev2``: This release adds support for Irdeto DRM encryption in DASH
    manifests.
  * api-change:``medical-imaging``: CopyImageSet API adds copying selected instances between image
    sets, and overriding inconsistent metadata with a force parameter. UpdateImageSetMetadata API
    enables reverting to prior versions; updates to Study, Series, and SOP Instance UIDs; and updates
    to private elements, with a force parameter.
  * api-change:``pinpoint-sms-voice-v2``: Update for rebrand to AWS End User Messaging SMS and Voice.
- from version 1.33.29
  * api-change:``appsync``: Adding support for paginators in AppSync list APIs
  * api-change:``cleanrooms``: This release adds AWS Entity Resolution integration to associate ID
    namespaces & ID mapping workflow resources as part of ID namespace association and  ID mapping
    table  in AWS Clean Rooms. It also introduces a new ID_MAPPING_TABLE analysis rule to manage the
    protection on ID mapping table.
  * api-change:``cleanroomsml``: Adds SQL query as the source of seed audience for audience
    generation job.
  * api-change:``connect``: Added PostContactSummary segment type on
    ListRealTimeContactAnalysisSegmentsV2 API
  * api-change:``connect-contact-lens``: Added PostContactSummary segment type on
    ListRealTimeContactAnalysisSegments API
  * api-change:``datazone``: This release removes the deprecated dataProductItem field from Search
    API output.
  * api-change:``entityresolution``: Support First Party ID Mapping
- from version 1.33.28
  * api-change:``datazone``: This release adds 1/ support of register S3 locations of assets in AWS
    Lake Formation hybrid access mode for DefaultDataLake blueprint. 2/ support of CRUD operations for
    Asset Filters.
  * api-change:``ivs``: Documentation update for IVS Low Latency API Reference.
  * api-change:``neptune-graph``: Amazon Neptune Analytics provides new options for customers to
    start with smaller graphs at a lower cost. CreateGraph, CreaateGraphImportTask, UpdateGraph and
    StartImportTask APIs will now allow 32 and 64 for `provisioned-memory`
  * api-change:``redshift-serverless``: Adds dualstack support for Redshift Serverless workgroup.
- from version 1.33.27
  * api-change:``acm-pca``: Fix broken waiters for the acm-pca client.  Waiters broke in version
- from version 1.13.144 of the Boto3 SDK.
  * api-change:``connect``: Amazon Connect expands search API coverage for additional resources.
    Search for hierarchy groups by name, ID, tag, or other criteria (new endpoint). Search for agent
    statuses by name, ID, tag, or other criteria (new endpoint). Search for users by their assigned
    proficiencies (enhanced endpoint)
  * api-change:``ec2``: Amazon VPC IP Address Manager (IPAM) now supports Bring-Your-Own-IP (BYOIP)
    for IP addresses registered with any Internet Registry. This feature uses DNS TXT records to
    validate ownership of a public IP address range.
  * api-change:``firehose``: This release 1) Add configurable buffering hints for Snowflake as
    destination. 2) Add ReadFromTimestamp for MSK As Source. Firehose will start reading data from MSK
    Cluster using offset associated with this timestamp. 3) Gated public beta release to add Apache
    Iceberg tables as destination.
  * api-change:``ivschat``: Documentation update for IVS Chat API Reference.
  * api-change:``medialive``: AWS Elemental MediaLive now supports the SRT protocol via the new SRT
    Caller input type.
  * api-change:``rds``: Updates Amazon RDS documentation to specify an eventual consistency model for
    DescribePendingMaintenanceActions.
  * api-change:``sagemaker``: SageMaker Training supports R5, T3 and R5D instances family. And
    SageMaker Processing supports G5 and R5D instances family.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``taxsettings``: Set default endpoint for aws partition. Requests from all regions in
    aws partition will be forward to us-east-1 endpoint.
  * api-change:``timestream-query``: Doc-only update for TimestreamQuery. Added guidance about the
    accepted valid value for the QueryPricingModel parameter.
  * api-change:``workspaces-thin-client``: Documentation update for WorkSpaces Thin Client.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Tue Jul 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.33.26
  * api-change:``acm-pca``: Minor refactoring of C2J model for AWS Private CA
  * api-change:``arc-zonal-shift``: Adds the option to subscribe to get notifications when a zonal
    autoshift occurs in a region.
  * api-change:``globalaccelerator``: This feature adds exceptions to the Customer API to avoid
    throwing Internal Service errors
  * api-change:``pinpoint``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``quicksight``: Vega ally control options and Support for Reviewed Answers in Topics
- from version 1.33.25
  * api-change:``batch``: This feature allows AWS Batch Jobs with EKS container orchestration type to
    be run as Multi-Node Parallel Jobs.
  * api-change:``bedrock``: Add support for contextual grounding check for Guardrails for Amazon
    Bedrock.
  * api-change:``bedrock-agent``: Introduces new data sources and chunking strategies for Knowledge
    bases, advanced parsing logic using FMs, session summary generation, and code interpretation
    (preview) for Claude V3 Sonnet and Haiku models. Also introduces Prompt Flows (preview) to link
    prompts, foundational models, and resources.
  * api-change:``bedrock-agent-runtime``: Introduces query decomposition, enhanced Agents integration
    with Knowledge bases, session summary generation, and code interpretation (preview) for Claude V3
    Sonnet and Haiku models. Also introduces Prompt Flows (preview) to link prompts, foundational
    models, and resources for end-to-end solutions.
  * api-change:``bedrock-runtime``: Add support for contextual grounding check and ApplyGuardrail API
    for Guardrails for Amazon Bedrock.
  * api-change:``ec2``: Add parameters to enable provisioning IPAM BYOIPv4 space at a Local Zone
    Network Border Group level
  * api-change:``glue``: Add recipe step support for recipe node
  * api-change:``groundstation``: Documentation update specifying OEM ephemeris units of measurement
  * api-change:``license-manager-linux-subscriptions``: Add support for third party subscription
    providers, starting with RHEL subscriptions through Red Hat Subscription Manager (RHSM).
    Additionally, add support for tagging subscription provider resources, and detect when an instance
    has more than one Linux subscription and notify the customer.
  * api-change:``mediaconnect``: AWS Elemental MediaConnect introduces the ability to disable
    outputs. Disabling an output allows you to keep the output attached to the flow, but stop streaming
    to the output destination. A disabled output does not incur data transfer costs.
- from version 1.33.24
  * api-change:``datazone``: This release deprecates dataProductItem field from
    SearchInventoryResultItem, along with some unused DataProduct shapes
  * api-change:``fsx``: Adds support for FSx for NetApp ONTAP 2nd Generation file systems, and FSx
    for OpenZFS Single AZ HA file systems.
  * api-change:``opensearch``: This release adds support for enabling or disabling Natural Language
    Query Processing feature for Amazon OpenSearch Service domains, and provides visibility into the
    current state of the setup or tear-down.
  * api-change:``sagemaker``: This release 1/ enables optimization jobs that allows customers to
    perform Ahead-of-time compilation and quantization. 2/ allows customers to control access to Amazon
    Q integration in SageMaker Studio. 3/ enables AdditionalModelDataSources for CreateModel action.
- from version 1.33.23
  * api-change:``codedeploy``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``devicefarm``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``dms``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``elasticbeanstalk``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``es``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``firehose``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``gamelift``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``qapps``: This is a general availability (GA) release of Amazon Q Apps, a capability
    of Amazon Q Business. Q Apps leverages data sources your company has provided to enable users to
    build, share, and customize apps within your organization.
  * api-change:``route53resolver``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``ses``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
- from version 1.33.22
  * api-change:``acm``: Documentation updates, including fixes for xml formatting, broken links, and
    ListCertificates description.
  * api-change:``ecr``: This release for Amazon ECR makes change to bring the SDK into sync with the
    API.
  * api-change:``payment-cryptography-data``: Added further restrictions on logging of potentially
    sensitive inputs and outputs.
  * api-change:``qbusiness``: Add personalization to Q Applications. Customers can enable or disable
    personalization when creating or updating a Q application with the personalization configuration.
- from version 1.33.21
  * api-change:``application-autoscaling``: Doc only update for Application Auto Scaling that fixes
    resource name.
  * api-change:``directconnect``: This update includes documentation for support of new native 400
    GBps ports for Direct Connect.
  * api-change:``organizations``: Added a new reason under ConstraintViolationException in
    RegisterDelegatedAdministrator API to prevent registering suspended accounts as delegated
    administrator of a service.
  * api-change:``rekognition``: This release adds support for tagging projects and datasets with the
    CreateProject and CreateDataset APIs.
  * api-change:``workspaces``: Fix create workspace bundle RootStorage/UserStorage to accept non null
    values
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Wed Jul  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.33.20
  * api-change:``ec2``: Documentation updates for Elastic Compute Cloud (EC2).
  * api-change:``fms``: Increases Customer API's ManagedServiceData length
  * api-change:``s3``: Added response overrides to Head Object requests.
- from version 1.33.19
  * api-change:``apigateway``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``cognito-identity``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``connect``: Authentication profiles are Amazon Connect resources (in gated preview)
    that allow you to configure authentication settings for users in your contact center. This release
    adds support for new ListAuthenticationProfiles, DescribeAuthenticationProfile and
    UpdateAuthenticationProfile APIs.
  * api-change:``docdb``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``eks``: Updates EKS managed node groups to support EC2 Capacity Blocks for ML
  * api-change:``payment-cryptography``: Added further restrictions on logging of potentially
    sensitive inputs and outputs.
  * api-change:``payment-cryptography-data``: Adding support for dynamic keys for encrypt, decrypt,
    re-encrypt and translate pin functions.  With this change, customers can use one-time TR-31 keys
    directly in dataplane operations without the need to first import them into the service.
  * api-change:``stepfunctions``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``swf``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``wafv2``: JSON body inspection: Update documentation to clarify that JSON parsing
    doesn't include full validation.
- from version 1.33.18
  * api-change:``acm-pca``: Added CCPC_LEVEL_1_OR_HIGHER KeyStorageSecurityStandard and SM2
    KeyAlgorithm and SM3WITHSM2 SigningAlgorithm for China regions.
  * api-change:``cloudhsmv2``: Added 3 new APIs to support backup sharing: GetResourcePolicy,
    PutResourcePolicy, and DeleteResourcePolicy. Added BackupArn to the output of the DescribeBackups
    API. Added support for BackupArn in the CreateCluster API.
  * api-change:``connect``: This release supports showing PreferredAgentRouting step via
    DescribeContact API.
  * api-change:``emr``: This release provides the support for new allocation strategies i.e.
    CAPACITY_OPTIMIZED_PRIORITIZED for Spot and PRIORITIZED for On-Demand by taking input of priority
    value for each instance type for instance fleet clusters.
  * api-change:``glue``: Added AttributesToGet parameter to Glue GetDatabases, allowing caller to
    limit output to include only the database name.
  * api-change:``kinesisanalyticsv2``: Support for Flink 1.19 in Managed Service for Apache Flink
  * api-change:``opensearch``: This release removes support for enabling or disabling Natural
    Language Query Processing feature for Amazon OpenSearch Service domains.
  * api-change:``pi``: Noting that the filter db.sql.db_id isn't available for RDS for SQL Server DB
    instances.
  * api-change:``workspaces``: Added support for Red Hat Enterprise Linux 8 on Amazon WorkSpaces
    Personal.
- from version 1.33.17
  * api-change:``application-autoscaling``: Amazon WorkSpaces customers can now use Application Auto
    Scaling to automatically scale the number of virtual desktops in a WorkSpaces pool.
  * api-change:``chime-sdk-media-pipelines``: Added Amazon Transcribe multi language identification
    to Chime SDK call analytics. Enabling customers sending single stream audio to generate call
    recordings using Chime SDK call analytics
  * api-change:``cloudfront``: Doc only update for CloudFront that fixes customer-reported issue
  * api-change:``datazone``: This release supports the data lineage feature of business data catalog
    in Amazon DataZone.
  * api-change:``elasticache``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``mq``: This release makes the EngineVersion field optional for both broker and
    configuration and uses the latest available version by default. The AutoMinorVersionUpgrade field
    is also now optional for broker creation and defaults to 'true'.
  * api-change:``qconnect``: Adds CreateContentAssociation, ListContentAssociations,
    GetContentAssociation, and DeleteContentAssociation APIs.
  * api-change:``quicksight``: Adding support for Repeating Sections, Nested Filters
  * api-change:``rds``: Updates Amazon RDS documentation for TAZ export to S3.
  * api-change:``sagemaker``: Add capability for Admins to customize Studio experience for the user
    by showing or hiding Apps and MLTools.
  * api-change:``workspaces``: Added support for WorkSpaces Pools.
- from version 1.33.16
  * api-change:``controltower``: Added ListLandingZoneOperations API.
  * api-change:``eks``: Added support for disabling unmanaged addons during cluster creation.
  * api-change:``ivs-realtime``: IVS Real-Time now offers customers the ability to upload public keys
    for customer vended participant tokens.
  * api-change:``kinesisanalyticsv2``: This release adds support for new ListApplicationOperations
    and DescribeApplicationOperation APIs. It adds a new configuration to enable system rollbacks, adds
    field ApplicationVersionCreateTimestamp for clarity and improves support for pagination for APIs.
  * api-change:``opensearch``: This release adds support for enabling or disabling Natural Language
    Query Processing feature for Amazon OpenSearch Service domains, and provides visibility into the
    current state of the setup or tear-down.
- from version 1.33.15
  * api-change:``autoscaling``: Doc only update for Auto Scaling's TargetTrackingMetricDataQuery
  * api-change:``ec2``: This release is for the launch of the new u7ib-12tb.224xlarge, R8g,
    c7gn.metal and mac2-m1ultra.metal instance types
  * api-change:``networkmanager``: This is model changes & documentation update for the Asynchronous
    Error Reporting feature for AWS Cloud WAN. This feature allows customers to view errors that occur
    while their resources are being provisioned, enabling customers to fix their resources without
    needing external support.
  * api-change:``workspaces-thin-client``: This release adds the deviceCreationTags field to
    CreateEnvironment API input, UpdateEnvironment API input and GetEnvironment API output.
- from version 1.33.14
  * api-change:``bedrock-runtime``: Increases Converse API's document name length
  * api-change:``customer-profiles``: This release includes changes to ProfileObjectType APIs, adds
    functionality top set and get capacity for profile object types.
  * api-change:``ec2``: Fix EC2 multi-protocol info in models.
  * api-change:``qbusiness``: Allow enable/disable Q Apps when creating/updating a Q application;
    Return the Q Apps enablement information when getting a Q application.
  * api-change:``ssm``: Add sensitive trait to SSM IPAddress property for CloudTrail redaction
  * api-change:``workspaces-web``: Added ability to enable DeepLinking functionality on a Portal via
    UserSettings as well as added support for IdentityProvider resource tagging.
- from version 1.33.13
  * api-change:``bedrock-runtime``: This release adds document support to Converse and ConverseStream
    APIs
  * api-change:``codeartifact``: Add support for the Cargo package format.
  * api-change:``compute-optimizer``: This release enables AWS Compute Optimizer to analyze and
    generate optimization recommendations for Amazon RDS MySQL and RDS PostgreSQL.
  * api-change:``cost-optimization-hub``: This release enables AWS Cost Optimization Hub to show cost
    optimization recommendations for Amazon RDS MySQL and RDS PostgreSQL.
  * api-change:``dynamodb``: Doc-only update for DynamoDB. Fixed Important note in 6 Global table
    APIs - CreateGlobalTable, DescribeGlobalTable, DescribeGlobalTableSettings, ListGlobalTables,
    UpdateGlobalTable, and UpdateGlobalTableSettings.
  * api-change:``glue``: Fix Glue paginators for Jobs, JobRuns, Triggers, Blueprints and Workflows.
  * api-change:``ivs-realtime``: IVS Real-Time now offers customers the ability to record individual
    stage participants to S3.
  * api-change:``sagemaker``: Adds support for model references in Hub service, and adds support for
    cross-account access of Hubs
  * api-change:``securityhub``: Documentation updates for Security Hub
- from version 1.33.12
  * api-change:``artifact``: This release adds an acceptanceType field to the ReportSummary structure
    (used in the ListReports API response).
  * api-change:``athena``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``cur``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``directconnect``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``elastictranscoder``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``opensearch``: This release enables customers to use JSON Web Tokens (JWT) for
    authentication on their Amazon OpenSearch Service domains.
- from version 1.33.11
  * api-change:``bedrock-runtime``: This release adds support for using Guardrails with the Converse
    and ConverseStream APIs.
  * api-change:``cloudtrail``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``config``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``eks``: This release adds support to surface async fargate customer errors from async
    path to customer through describe-fargate-profile API response.
  * api-change:``lightsail``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``polly``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``rekognition``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``sagemaker``: Launched a new feature in SageMaker to provide managed MLflow Tracking
    Servers for customers to track ML experiments. This release also adds a new capability of attaching
    additional storage to SageMaker HyperPod cluster instances.
  * api-change:``shield``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``snowball``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
- from version 1.33.10
  * api-change:``acm-pca``: Doc-only update that adds name constraints as an allowed extension for
    ImportCertificateAuthorityCertificate.
  * api-change:``batch``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``codebuild``: AWS CodeBuild now supports global and organization GitHub webhooks
  * api-change:``cognito-idp``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``ds``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``efs``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``glue``: This release introduces a new feature, Usage profiles. Usage profiles allow
    the AWS Glue admin to create different profiles for various classes of users within the account,
    enforcing limits and defaults for jobs and sessions.
  * api-change:``mediaconvert``: This release includes support for creating I-frame only video
    segments for DASH trick play.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``waf``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
- from version 1.33.9
  * api-change:``datazone``: This release introduces a new default service blueprint for custom
    environment creation.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``macie2``: This release adds support for managing the status of automated sensitive
    data discovery for individual accounts in an organization, and determining whether individual S3
    buckets are included in the scope of the analyses.
  * api-change:``mediaconvert``: This release adds the ability to search for historical job records
    within the management console using a search box and/or via the SDK/CLI with partial string
    matching search on input file name.
  * api-change:``route53domains``: Add v2 smoke tests and smithy smokeTests trait for SDK testing.
- from version 1.33.8
  * api-change:``cloudhsmv2``: Added support for hsm type hsm2m.medium. Added supported for creating
    a cluster in FIPS or NON_FIPS mode.
  * api-change:``glue``: This release adds support for configuration of evaluation method for
    composite rules in Glue Data Quality rulesets.
  * api-change:``iotwireless``: Add RoamingDeviceSNR and RoamingDeviceRSSI to Customer Metrics.
  * api-change:``kms``: This feature allows customers to use their keys stored in KMS to derive a
    shared secret which can then be used to establish a secured channel for communication, provide
    proof of possession, or establish trust with other parties.
  * api-change:``mediapackagev2``: This release adds support for CMAF ingest (DASH-IF live media
    ingest protocol interface 1)
- from version 1.33.7
  * api-change:``apptest``: AWS Mainframe Modernization Application Testing is an AWS Mainframe
    Modernization service feature that automates functional equivalence testing for mainframe
    application modernization and migration to AWS, and regression testing.
  * api-change:``ec2``: Tagging support for Traffic Mirroring FilterRule resource
  * api-change:``osis``: SDK changes for self-managed vpc endpoint to OpenSearch ingestion pipelines.
  * api-change:``redshift``: Updates to remove DC1 and DS2 node types.
  * api-change:``secretsmanager``: Introducing RotationToken parameter for PutSecretValue API
  * api-change:``securitylake``: This release updates request validation regex to account for
    non-commercial aws partitions.
  * api-change:``sesv2``: This release adds support for Amazon EventBridge as an email sending events
    destination.
- from version 1.33.6
  * api-change:``accessanalyzer``: IAM Access Analyzer now provides policy recommendations to help
    resolve unused permissions for IAM roles and users. Additionally, IAM Access Analyzer now extends
    its custom policy checks to detect when IAM policies grant public access or access to critical
    resources ahead of deployments.
  * api-change:``guardduty``: Added API support for GuardDuty Malware Protection for S3.
  * api-change:``networkmanager``: This is model changes & documentation update for Service Insertion
    feature for AWS Cloud WAN. This feature allows insertion of AWS/3rd party security services on
    Cloud WAN. This allows to steer inter/intra segment traffic via security appliances and provide
    visibility to the route updates.
  * api-change:``pca-connector-scep``: Connector for SCEP allows you to use a managed, cloud CA to
    enroll mobile devices and networking gear. SCEP is a widely-adopted protocol used by mobile device
    management (MDM) solutions for enrolling mobile devices. With the connector, you can use AWS
    Private CA with popular MDM solutions.
  * api-change:``sagemaker``: Introduced Scope and AuthenticationRequestExtraParams to SageMaker
    Workforce OIDC configuration; this allows customers to modify these options for their private
    Workforce IdP integration. Model Registry Cross-account model package groups are discoverable.
- from version 1.33.5
  * api-change:``application-signals``: This is the initial SDK release for Amazon CloudWatch
    Application Signals. Amazon CloudWatch Application Signals provides curated application performance
    monitoring for developers to monitor and troubleshoot application health using pre-built dashboards
    and Service Level Objectives.
  * api-change:``ecs``: This release introduces a new cluster configuration to support the
    customer-managed keys for ECS managed storage encryption.
  * api-change:``imagebuilder``: This release updates the regex pattern for Image Builder ARNs.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Mon Jun 10 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.33.4
  * api-change:``auditmanager``: New feature: common controls. When creating custom controls, you can
    now use pre-grouped AWS data sources based on common compliance themes. Also, the awsServices
    parameter is deprecated because we now manage services in scope for you. If used, the input is
    ignored and an empty list is returned.
  * api-change:``b2bi``: Added exceptions to B2Bi List operations and ConflictException to B2Bi
    StartTransformerJob operation. Also made capabilities field explicitly required when creating a
    Partnership.
  * api-change:``codepipeline``: CodePipeline now supports overriding S3 Source Object Key during
    StartPipelineExecution, as part of Source Overrides.
  * api-change:``sagemaker``: This release introduces a new optional parameter: InferenceAmiVersion,
    in ProductionVariant.
  * api-change:``verifiedpermissions``: This release adds OpenIdConnect (OIDC) configuration support
    for IdentitySources, allowing for external IDPs to be used in authorization requests.
- from version 1.33.3
  * api-change:``account``: This release adds 3 new APIs (AcceptPrimaryEmailUpdate, GetPrimaryEmail,
    and StartPrimaryEmailUpdate) used to centrally manage the root user email address of member
    accounts within an AWS organization.
  * api-change:``firehose``: Adds integration with Secrets Manager for Redshift, Splunk,
    HttpEndpoint, and Snowflake destinations
  * api-change:``fsx``: This release adds support to increase metadata performance on FSx for Lustre
    file systems beyond the default level provisioned when a file system is created. This can be done
    by specifying MetadataConfiguration during the creation of Persistent_2 file systems or by updating
    it on demand.
  * api-change:``glue``: This release adds support for creating and updating Glue Data Catalog Views.
  * api-change:``iotwireless``: Adds support for wireless device to be in Conflict FUOTA Device
    Status due to a FUOTA Task, so it couldn't be attached to a new one.
  * api-change:``location``: Added two new APIs, VerifyDevicePosition and ForecastGeofenceEvents.
    Added support for putting larger geofences up to 100,000 vertices with Geobuf fields.
  * api-change:``sns``: Doc-only update for SNS. These changes include customer-reported issues and
    TXC3 updates.
  * api-change:``sqs``: Doc only updates for SQS. These updates include customer-reported issues and
    TCX3 modifications.
  * api-change:``storagegateway``: Adds SoftwareUpdatePreferences to DescribeMaintenanceStartTime and
    UpdateMaintenanceStartTime, a structure which contains AutomaticUpdatePolicy.
- from version 1.33.2
  * api-change:``globalaccelerator``: This release contains a new optional ip-addresses input field
    for the update accelerator and update custom routing accelerator apis. This input enables consumers
    to replace IPv4 addresses on existing accelerators with addresses provided in the input.
  * api-change:``glue``: AWS Glue now supports native SaaS connectivity: Salesforce connector
    available now
  * api-change:``s3``: Added new params copySource and key to copyObject API for supporting S3 Access
    Grants plugin. These changes will not change any of the existing S3 API functionality.
  * bugfix:emr customization: Update the EC2 service principal when creating the trust policy for EMR
    default roles to always be ec2.amazonaws.com.
- from version 1.33.1
  * api-change:``ec2``: U7i instances with up to 32 TiB of DDR5 memory and 896 vCPUs are now
    available. C7i-flex instances are launched and are lower-priced variants of the Amazon EC2 C7i
    instances that offer a baseline level of CPU performance with the ability to scale up to the full
    compute performance 95%% of the time.
  * api-change:``pipes``: This release adds Timestream for LiveAnalytics as a supported target in
    EventBridge Pipes
  * api-change:``sagemaker``: Extend DescribeClusterNode response with private DNS hostname and IP
    address, and placement information about availability zone and availability zone ID.
  * api-change:``taxsettings``: Initial release of AWS Tax Settings API
- from version 1.33.0
  * api-change:``amplify``: This doc-only update identifies fields that are specific to Gen 1 and Gen
    2 applications.
  * api-change:``batch``: This release adds support for the AWS Batch GetJobQueueSnapshot API
    operation.
  * api-change:``eks``: Adds support for EKS add-ons pod identity associations integration
  * api-change:``iottwinmaker``: Support RESET_VALUE UpdateType for PropertyUpdates to reset property
    value to default or null
  * feature:logs start-live-tail: Adds support for starting a live tail streaming session for one or
    more log groups.
- from version 1.32.117
  * api-change:``codebuild``: AWS CodeBuild now supports Self-hosted GitHub Actions runners for
    Github Enterprise
  * api-change:``codeguru-security``: This release includes minor model updates and documentation
    updates.
  * api-change:``elasticache``: Update to attributes of TestFailover and minor revisions.
  * api-change:``launch-wizard``: This release adds support for describing workload deployment
    specifications, deploying additional workload types, and managing tags for Launch Wizard resources
    with API operations.
- from version 1.32.116
  * api-change:``acm``: add v2 smoke tests and smithy smokeTests trait for SDK testing.
  * api-change:``bedrock-agent``: With this release, Knowledge bases for Bedrock adds support for
    Titan Text Embedding v2.
  * api-change:``bedrock-runtime``: This release adds Converse and ConverseStream APIs to Bedrock
    Runtime
  * api-change:``cloudtrail``: CloudTrail Lake returns PartitionKeys in the GetEventDataStore API
    response. Events are grouped into partitions based on these keys for better query performance. For
    example, the calendarday key groups events by day, while combining the calendarday key with the
    hour key groups them by day and hour.
  * api-change:``connect``: Adding associatedQueueIds as a SearchCriteria and response field to the
    SearchRoutingProfiles API
  * api-change:``emr-serverless``: The release adds support for spark structured streaming.
  * api-change:``rds``: Updates Amazon RDS documentation for Aurora Postgres DBname.
  * api-change:``sagemaker``: Adds Model Card information as a new component to Model Package.
    Autopilot launches algorithm selection for TimeSeries modality to generate AutoML candidates per
    algorithm.
  * bugfix:``ssm start-session``: Only provide profile name to session-manager-plugin if provided
    using --profile flag
- from version 1.32.115
  * api-change:``athena``: Throwing validation errors on CreateNotebook with Name containing
    `/`,`:`,`\`
  * api-change:``codebuild``: AWS CodeBuild now supports manually creating GitHub webhooks
  * api-change:``connect``: This release includes changes to DescribeContact API's response by
    including ConnectedToSystemTimestamp, RoutingCriteria, Customer, Campaign,
    AnsweringMachineDetectionStatus, CustomerVoiceActivity, QualityMetrics, DisconnectDetails, and
    SegmentAttributes information from a contact in Amazon Connect.
  * api-change:``glue``: Add optional field JobMode to CreateJob and UpdateJob APIs.
  * api-change:``securityhub``: Add ROOT type for TargetType model
- from version 1.32.114
  * api-change:``dynamodb``: Doc-only update for DynamoDB. Specified the IAM actions needed to
    authorize a user to create a table with a resource-based policy.
  * api-change:``ec2``: Providing support to accept BgpAsnExtended attribute
  * api-change:``kafka``: Adds ControllerNodeInfo in ListNodes response to support Raft mode for MSK
  * api-change:``swf``: This release adds new APIs for deleting activity type and workflow type
    resources.
- from version 1.32.113
  * api-change:``dynamodb``: Documentation only updates for DynamoDB.
  * api-change:``iotfleetwise``: AWS IoT FleetWise now supports listing vehicles with attributes
    filter, ListVehicles API is updated to support additional attributes filter.
  * api-change:``managedblockchain``: This is a minor documentation update to address the impact of
    the shut down of the Goerli and Polygon networks.
- from version 1.32.112
  * api-change:``emr-serverless``: This release adds the capability to run interactive workloads
    using Apache Livy Endpoint.
  * api-change:``opsworks``: Documentation-only update for OpsWorks Stacks.
- from version 1.32.111
  * api-change:``chatbot``: This change adds support for tagging Chatbot configurations.
  * api-change:``cloudformation``: Added DeletionMode FORCE_DELETE_STACK for deleting a stack that is
    stuck in DELETE_FAILED state due to resource deletion failure.
  * api-change:``kms``: This release includes feature to import customer's asymmetric (RSA, ECC and
    SM2) and HMAC keys into KMS in China.
  * api-change:``opensearch``: This release adds support for enabling or disabling a data source
    configured as part of Zero-ETL integration with Amazon S3, by setting its status.
  * api-change:``wafv2``: You can now use Security Lake to collect web ACL traffic data.
- from version 1.32.110
  * api-change:``cloudfront``: Model update; no change to SDK functionality.
  * api-change:``glue``: Add Maintenance window to CreateJob and UpdateJob APIs and JobRun response.
    Add a new Job Run State for EXPIRED.
  * api-change:``lightsail``: This release adds support for Amazon Lightsail instances to switch
    between dual-stack or IPv4 only and IPv6-only public IP address types.
  * api-change:``mailmanager``: This release includes a new Amazon SES feature called Mail Manager,
    which is a set of email gateway capabilities designed to help customers strengthen their
    organization's email infrastructure, simplify email workflow management, and streamline email
    compliance control.
  * api-change:``pi``: Performance Insights added a new input parameter called AuthorizedActions to
    support the fine-grained access feature. Performance Insights also restricted the acceptable input
    characters.
  * api-change:``rds``: Updates Amazon RDS documentation for Db2 license through AWS Marketplace.
  * api-change:``storagegateway``: Added new SMBSecurityStrategy enum named
    MandatoryEncryptionNoAes128, new mode enforces encryption and disables AES 128-bit algorithums.
- from version 1.32.109
  * api-change:``bedrock-agent``: This release adds support for using Guardrails with Bedrock Agents.
  * api-change:``bedrock-agent-runtime``: This release adds support for using Guardrails with Bedrock
    Agents.
  * api-change:``controltower``: Added ListControlOperations API and filtering support for
    ListEnabledControls API. Updates also includes added metadata for enabled controls and control
    operations.
  * api-change:``osis``: Add support for creating an OpenSearch Ingestion pipeline that is attached
    to a provided VPC. Add information about the destinations of an OpenSearch Ingestion pipeline to
    the GetPipeline and ListPipelines APIs.
  * api-change:``rds``: This release adds support for EngineLifecycleSupport on DBInstances,
    DBClusters, and GlobalClusters.
  * api-change:``secretsmanager``: add v2 smoke tests and smithy smokeTests trait for SDK testing
- from version 1.32.108
  * api-change:``application-autoscaling``: add v2 smoke tests and smithy smokeTests trait for SDK
    testing.
  * api-change:``codebuild``: Aws CodeBuild now supports 36 hours build timeout
  * api-change:``elbv2``: This release adds dualstack-without-public-ipv4 IP address type for ALB.
  * api-change:``lakeformation``: Introduces a new API, GetDataLakePrincipal, that returns the
    identity of the invoking principal
  * api-change:``transfer``: Enable use of CloudFormation traits in Smithy model to improve generated
    CloudFormation schema from the Smithy API model.
- from version 1.32.107
  * api-change:``acm-pca``: This release adds support for waiters to fail on AccessDeniedException
    when having insufficient permissions
  * api-change:``connect``: Adding Contact Flow metrics to the GetMetricDataV2 API
  * api-change:``kafka``: AWS MSK support for Broker Removal.
  * api-change:``mwaa``: Amazon MWAA now supports Airflow web server auto scaling to automatically
    handle increased demand from REST APIs, Command Line Interface (CLI), or more Airflow User
    Interface (UI) users. Customers can specify maximum and minimum web server instances during
    environment creation and update workflow.
  * api-change:``quicksight``: This release adds DescribeKeyRegistration and UpdateKeyRegistration
    APIs to manage QuickSight Customer Managed Keys (CMK).
  * api-change:``sagemaker``: Introduced WorkerAccessConfiguration to SageMaker Workteam. This allows
    customers to configure resource access for workers in a workteam.
  * api-change:``secretsmanager``: Documentation updates for AWS Secrets Manager
- from version 1.32.106
  * api-change:``bedrock-agent-runtime``: Updating Bedrock Knowledge Base Metadata & Filters feature
    with two new filters listContains and stringContains
  * api-change:``codebuild``: CodeBuild Reserved Capacity VPC Support
  * api-change:``datasync``: Task executions now display a CANCELLING status when an execution is in
    the process of being cancelled.
  * api-change:``grafana``: This release adds new ServiceAccount and ServiceAccountToken APIs.
  * api-change:``medical-imaging``: Added support for importing medical imaging data from Amazon S3
    buckets across accounts and regions.
  * api-change:``securityhub``: Documentation-only update for AWS Security Hub
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Thu May 16 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.32.105
  * api-change:``connect``: Amazon Connect provides enhanced search capabilities for flows & flow
    modules on the Connect admin website and programmatically using APIs. You can search for flows and
    flow modules by name, description, type, status, and tags, to filter and identify a specific flow
    in your Connect instances.
  * api-change:``s3``: Updated a few x-id in the http uri traits
- from version 1.32.104
  * api-change:``events``: Amazon EventBridge introduces KMS customer-managed key (CMK) encryption
    support for custom and partner events published on EventBridge Event Bus (including default bus)
    and UpdateEventBus API.
  * api-change:``vpc-lattice``: This release adds TLS Passthrough support. It also increases max
    number of target group per rule to 10.
- from version 1.32.103
  * api-change:``discovery``: add v2 smoke tests and smithy smokeTests trait for SDK testing
  * api-change:``greengrassv2``: Mark ComponentVersion in ComponentDeploymentSpecification as
    required.
  * api-change:``sagemaker``: Introduced support for G6 instance types on Sagemaker Notebook
    Instances and on SageMaker Studio for JupyterLab and CodeEditor applications.
  * api-change:``sso-oidc``: Updated request parameters for PKCE support.
- from version 1.32.102
  * api-change:``bedrock-agent-runtime``: This release adds support to provide guardrail
    configuration and modify inference parameters that are then used in RetrieveAndGenerate API in
    Agents for Amazon Bedrock.
  * api-change:``pinpoint``: This release adds support for specifying email message headers for Email
    Templates, Campaigns, Journeys and Send Messages.
  * api-change:``route53resolver``: Update the DNS Firewall settings to correct a spelling issue.
  * api-change:``ssm-sap``: Added support for application-aware start/stop of SAP applications
    running on EC2 instances, with SSM for SAP
  * api-change:``verifiedpermissions``: Adds policy effect and actions fields to Policy API's.
- from version 1.32.101
  * api-change:``cognito-idp``: Add EXTERNAL_PROVIDER enum value to UserStatusType.
  * api-change:``ec2``: Adding Precision Hardware Clock (PHC) to public API DescribeInstanceTypes
  * api-change:``ecr``: This release adds pull through cache rules support for GitLab container
    registry in Amazon ECR.
  * api-change:``fms``: The policy scope resource tag is always a string value, either a non-empty
    string or an empty string.
  * api-change:``polly``: Add new engine - generative - that builds the most expressive
    conversational voices.
  * api-change:``sqs``: This release adds MessageSystemAttributeNames to ReceiveMessageRequest to
    replace AttributeNames.
- from version 1.32.100
  * api-change:``b2bi``: Documentation update to clarify the MappingTemplate definition.
  * api-change:``budgets``: This release adds tag support for budgets and budget actions.
  * api-change:``resiliencehub``: AWS Resilience Hub has expanded its drift detection capabilities by
    introducing a new type of drift detection - application resource drift. This new enhancement
    detects changes, such as the addition or deletion of resources within the application's input
    sources.
  * api-change:``route53profiles``: Doc only update for Route 53 profiles that fixes some link  issues
- from version 1.32.99
  * api-change:``medialive``: AWS Elemental MediaLive now supports configuring how SCTE 35
    passthrough triggers segment breaks in HLS and MediaPackage output groups. Previously, messages
    triggered breaks in all these output groups. The new option is to trigger segment breaks only in
    groups that have SCTE 35 passthrough enabled.
- from version 1.32.98
  * api-change:``bedrock-agent``: This release adds support for using Provisioned Throughput with
    Bedrock Agents.
  * api-change:``connect``: This release adds 5 new APIs for managing attachments:
    StartAttachedFileUpload, CompleteAttachedFileUpload, GetAttachedFile, BatchGetAttachedFileMetadata,
    DeleteAttachedFile. These APIs can be used to programmatically upload and download attachments to
    Connect resources, like cases.
  * api-change:``connectcases``: This feature supports the release of Files related items
  * api-change:``datasync``: Updated guidance on using private or self-signed certificate authorities
    (CAs) with AWS DataSync object storage locations.
  * api-change:``inspector2``: This release adds CSV format to GetCisScanReport for Inspector v2
  * api-change:``sagemaker``: Amazon SageMaker Inference now supports m6i, c6i, r6i, m7i, c7i, r7i
    and g5 instance types for Batch Transform Jobs
  * api-change:``sesv2``: Adds support for specifying replacement headers per BulkEmailEntry in
    SendBulkEmail in SESv2.
- from version 1.32.97
  * api-change:``dynamodb``: This release adds support to specify an optional, maximum
    OnDemandThroughput for DynamoDB tables and global secondary indexes in the CreateTable or
    UpdateTable APIs. You can also override the OnDemandThroughput settings by calling the ImportTable,
    RestoreFromPointInTime, or RestoreFromBackup APIs.
  * api-change:``ec2``: This release includes a new API for retrieving the public endorsement key of
    the EC2 instance's Nitro Trusted Platform Module (NitroTPM).
  * api-change:``personalize``: This releases ability to delete users and their data, including their
    metadata and interactions data, from a dataset group.
  * api-change:``redshift-serverless``: Update Redshift Serverless List Scheduled Actions Output
    Response to include Namespace Name.
- from version 1.32.96
  * api-change:``bedrock-agent``: This release adds support for using MongoDB Atlas as a vector store
    when creating a knowledge base.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``personalize-runtime``: This release adds support for a Reason attribute for
    predicted items generated by User-Personalization-v2.
  * api-change:``securityhub``: Updated CreateMembers API request with limits.
  * api-change:``sesv2``: Fixes ListContacts and ListImportJobs APIs to use POST instead of GET.
- from version 1.32.95
  * api-change:``chime-sdk-voice``: Due to changes made by the Amazon Alexa service,
    GetSipMediaApplicationAlexaSkillConfiguration and PutSipMediaApplicationAlexaSkillConfiguration
    APIs are no longer available for use. For more information, refer to the Alexa Smart Properties
    page.
  * api-change:``codeartifact``: Add support for the Ruby package format.
  * api-change:``fms``: AWS Firewall Manager now supports the network firewall service stream
    exception policy feature for accounts within your organization.
  * api-change:``omics``: Add support for workflow sharing and dynamic run storage
  * api-change:``opensearch``: This release enables customers to create Route53 A and AAAA alias
    record types to point custom endpoint domain to OpenSearch domain's dualstack search endpoint.
  * api-change:``pinpoint-sms-voice-v2``: Amazon Pinpoint has added two new features Multimedia
    services (MMS) and protect configurations. Use the three new MMS APIs to send media messages to a
    mobile phone which includes image, audio, text, or video files. Use the ten new protect
    configurations APIs to block messages to specific countries.
  * api-change:``qbusiness``: This is a general availability (GA) release of Amazon Q Business. Q
    Business enables employees in an enterprise to get comprehensive answers to complex questions and
    take actions through a unified, intuitive web-based chat experience - using an enterprise's
    existing content, data, and systems.
  * api-change:``quicksight``: New Q embedding supporting Generative Q&A
  * api-change:``route53resolver``: Release of FirewallDomainRedirectionAction parameter on the Route
    53 DNS Firewall Rule.  This allows customers to configure a DNS Firewall rule to inspect all the
    domains in the DNS redirection chain (default) , such as CNAME, ALIAS, DNAME, etc., or just the
    first domain and trust the rest.
  * api-change:``sagemaker``: Amazon SageMaker Training now supports the use of attribute-based
    access control (ABAC) roles for training job execution roles. Amazon SageMaker Inference now
    supports G6 instance types.
  * api-change:``signer``: Documentation updates for AWS Signer. Adds cross-account signing
    constraint and definitions for cross-account actions.
- from version 1.32.94
  * api-change:``amplify``: Updating max results limit for listing any resources (Job, Artifacts,
    Branch, BackendResources, DomainAssociation) to 50 with the exception of list apps that where max
    results can be up to 100.
  * api-change:``connectcases``: This feature releases DeleteField, DeletedLayout, and DeleteTemplate
    API's
  * api-change:``inspector2``: Update Inspector2 to include new Agentless API parameters.
  * api-change:``timestream-query``: This change allows users to update and describe account settings
    associated with their accounts.
  * api-change:``transcribe``: This update provides error messaging for generative call summarization
    in Transcribe Call Analytics
  * api-change:``trustedadvisor``: This release adds the BatchUpdateRecommendationResourceExclusion
    API to support batch updates of Recommendation Resource exclusion statuses and introduces a new
    exclusion status filter to the ListRecommendationResources and
    ListOrganizationRecommendationResources APIs.
- from version 1.32.93
  * api-change:``codepipeline``: Add ability to manually and automatically roll back a pipeline stage
    to a previously successful execution.
  * api-change:``cognito-idp``: Add LimitExceededException to SignUp errors
  * api-change:``connectcampaigns``: This release adds support for specifying if Answering Machine
    should wait for prompt sound.
  * api-change:``marketplace-entitlement``: Releasing minor endpoint updates.
  * api-change:``oam``: This release introduces support for Source Accounts to define which Metrics
    and Logs to share with the Monitoring Account
  * api-change:``rds``: SupportsLimitlessDatabase field added to describe-db-engine-versions to
    indicate whether the DB engine version supports Aurora Limitless Database.
  * api-change:``support``: Releasing minor endpoint updates.
  * enhancement:dependency: Bump upper bound of colorama to <0.4.7; fixes `#7086
    <https://github.com/aws/aws-cli/issues/7086>`__
- from version 1.32.92
  * api-change:``appsync``: UpdateGraphQLAPI documentation update and datasource introspection secret
    arn update
  * api-change:``fms``: AWS Firewall Manager adds support for network ACL policies to manage Amazon
    Virtual Private Cloud (VPC) network access control lists (ACLs) for accounts in your organization.
  * api-change:``ivs``: Bug Fix: IVS does not support arns with the `svs` prefix
  * api-change:``ivs-realtime``: Bug Fix: IVS Real Time does not support ARNs using the `svs` prefix.
  * api-change:``rds``: Updates Amazon RDS documentation for setting local time zones for RDS for Db2
    DB instances.
  * api-change:``stepfunctions``: Add new ValidateStateMachineDefinition operation, which performs
    syntax checking on the definition of a Amazon States Language (ASL) state machine.
- from version 1.32.91
  * api-change:``datasync``: This change allows users to disable and enable the schedules associated
    with their tasks.
  * api-change:``ec2``: Launching capability for customers to enable or disable automatic assignment
    of public IPv4 addresses to their network interface
  * api-change:``emr-containers``: EMRonEKS Service support for SecurityConfiguration enforcement for
    Spark Jobs.
  * api-change:``entityresolution``: Support Batch Unique IDs Deletion.
  * api-change:``gamelift``: Amazon GameLift releases container fleets support for public preview.
    Deploy Linux-based containerized game server software for hosting on Amazon GameLift.
  * api-change:``ssm``: Add SSM DescribeInstanceProperties API to public AWS SDK.
- from version 1.32.90
  * api-change:``bedrock``: This release introduces Model Evaluation and Guardrails for Amazon
    Bedrock.
  * api-change:``bedrock-agent``: Introducing the ability to create multiple data sources per
    knowledge base, specify S3 buckets as data sources from external accounts, and exposing levers to
    define the deletion behavior of the underlying vector store data.
  * api-change:``bedrock-agent-runtime``: This release introduces zero-setup file upload support for
    the RetrieveAndGenerate API. This allows you to chat with your data without setting up a Knowledge
    Base.
  * api-change:``bedrock-runtime``: This release introduces Guardrails for Amazon Bedrock.
  * api-change:``ce``: Added additional metadata that might be applicable to your reservation
    recommendations.
  * api-change:``ec2``: This release introduces EC2 AMI Deregistration Protection, a new AMI property
    that can be enabled by customers to protect an AMI against an unintended deregistration. This
    release also enables the AMI owners to view the AMI 'LastLaunchedTime' in DescribeImages API.
  * api-change:``pi``: Clarifies how aggregation works for GetResourceMetrics in the Performance
    Insights API.
  * api-change:``rds``: Fix the example ARN for ModifyActivityStreamRequest
  * api-change:``workspaces-web``: Added InstanceType and MaxConcurrentSessions parameters on
    CreatePortal and UpdatePortal Operations as well as the ability to read Customer Managed Key &
    Additional Encryption Context parameters on supported resources (Portal, BrowserSettings,
    UserSettings, IPAccessSettings)
- from version 1.32.89
  * api-change:``bedrock-agent``: Releasing the support for simplified configuration and return of
    control
  * api-change:``bedrock-agent-runtime``: Releasing the support for simplified configuration and
    return of control
  * api-change:``payment-cryptography``: Adding support to TR-31/TR-34 exports for optional headers,
    allowing customers to add additional metadata (such as key version and KSN) when exporting keys
    from the service.
  * api-change:``redshift-serverless``: Updates description of schedule field for scheduled actions.
  * api-change:``route53profiles``: Route 53 Profiles allows you to apply a central DNS configuration
    across many VPCs regardless of account.
  * api-change:``sagemaker``: This release adds support for Real-Time Collaboration and Shared Space
    for JupyterLab App on SageMaker Studio.
  * api-change:``servicediscovery``: This release adds examples to several Cloud Map actions.
  * api-change:``transfer``: Adding new API to support remote directory listing using SFTP connector
- from version 1.32.88
  * api-change:``glue``: Adding RowFilter in the response for GetUnfilteredTableMetadata API
  * api-change:``internetmonitor``: This update introduces the GetInternetEvent and
    ListInternetEvents APIs, which provide access to internet events displayed on the Amazon CloudWatch
    Internet Weather Map.
  * api-change:``personalize``: This releases auto training capability while creating a solution and
    automatically syncing latest solution versions when creating/updating a campaign
- from version 1.32.87
  * api-change:``drs``: Outpost ARN added to Source Server and Recovery Instance
  * api-change:``emr-serverless``: This release adds the capability to publish detailed Spark engine
    metrics to Amazon Managed Service for Prometheus (AMP) for  enhanced monitoring for Spark jobs.
  * api-change:``guardduty``: Added IPv6Address fields for local and remote IP addresses
  * api-change:``quicksight``: This release adds support for the Cross Sheet Filter and Control
    features, and support for warnings in asset imports for any permitted errors encountered during
    execution
  * api-change:``rolesanywhere``: This release introduces the PutAttributeMapping and
    DeleteAttributeMapping APIs. IAM Roles Anywhere now provides the capability to define a set of
    mapping rules, allowing customers to specify which data is extracted from their X.509 end-entity
    certificates.
  * api-change:``sagemaker``: Removed deprecated enum values and updated API documentation.
  * api-change:``workspaces``: Adds new APIs for managing and sharing WorkSpaces BYOL configuration
    across accounts.
- from version 1.32.86
  * api-change:``ec2``: Documentation updates for Elastic Compute Cloud (EC2).
  * api-change:``qbusiness``: This release adds support for IAM Identity Center (IDC) as the identity
    gateway for Q Business. It also allows users to provide an explicit intent for Q Business to
    identify how the Chat request should be handled.
- from version 1.32.85
  * api-change:``bedrock-agent``: For Create Agent API, the agentResourceRoleArn parameter is no
    longer required.
  * api-change:``emr-serverless``: This release adds support for shuffle optimized disks that allow
    larger disk sizes and higher IOPS to efficiently run shuffle heavy workloads.
  * api-change:``entityresolution``: Cross Account Resource Support .
  * api-change:``iotwireless``: Add PublicGateways in the GetWirelessStatistics call response,
    indicating the LoRaWAN public network accessed by the device.
  * api-change:``lakeformation``: This release adds Lake Formation managed RAM support for the 4 APIs
  - "DescribeLakeFormationIdentityCenterConfiguration",
    "CreateLakeFormationIdentityCenterConfiguration",
    "DescribeLakeFormationIdentityCenterConfiguration", and
    "DeleteLakeFormationIdentityCenterConfiguration"
  * api-change:``m2``: Adding new ListBatchJobRestartPoints API and support for restart batch job.
  * api-change:``mediapackagev2``: Dash v2 is a MediaPackage V2 feature to support egressing on DASH
    manifest format.
  * api-change:``outposts``: This release adds new APIs to allow customers to configure their Outpost
    capacity at order-time.
  * api-change:``wellarchitected``: AWS Well-Architected now has a Connector for Jira to allow
    customers to efficiently track workload risks and improvement efforts and create closed-loop
    mechanisms.
- from version 1.32.84
  * api-change:``cloudformation``: Adding support for the new parameter "IncludePropertyValues" in
    the CloudFormation DescribeChangeSet API. When this parameter is included, the DescribeChangeSet
    response will include more detailed information such as before and after values for the resource
    properties that will change.
  * api-change:``config``: Updates documentation for AWS Config
  * api-change:``glue``: Modifying request for GetUnfilteredTableMetadata for view-related fields.
  * api-change:``healthlake``: Added new CREATE_FAILED status for data stores. Added new errorCause
    to DescribeFHIRDatastore API and ListFHIRDatastores API response for additional insights into data
    store creation and deletion workflows.
  * api-change:``iotfleethub``: Documentation updates for AWS IoT Fleet Hub to clarify that Fleet Hub
    supports organization instance of IAM Identity Center.
  * api-change:``kms``: This feature supports the ability to specify a custom rotation period for
    automatic key rotations, the ability to perform on-demand key rotations, and visibility into your
    key material rotations.
  * api-change:``mediatailor``: Added InsertionMode to PlaybackConfigurations. This setting controls
    whether players can use stitched or guided ad insertion. The default for players that do not
    specify an insertion mode is stitched.
  * api-change:``neptune-graph``: Update to API documentation to resolve customer reported issues.
  * api-change:``outposts``: This release adds EXPEDITORS as a valid shipment carrier.
  * api-change:``redshift``: Adds support for Amazon Redshift DescribeClusterSnapshots API to include
    Snapshot ARN response field.
  * api-change:``transfer``: This change releases support for importing self signed certificates to
    the Transfer Family for sending outbound file transfers over TLS/HTTPS.
- from version 1.32.83
  * api-change:``batch``: This release adds the task properties field to attempt details and the name
    field on EKS container detail.
  * api-change:``cloudfront``: CloudFront origin access control extends support to AWS Lambda
    function URLs and AWS Elemental MediaPackage v2 origins.
  * api-change:``cloudwatch``: This release adds support for Metric Characteristics for CloudWatch
    Anomaly Detection. Anomaly Detector now takes Metric Characteristics object with Periodic Spikes
    boolean field that tells Anomaly Detection that spikes that repeat at the same time every week are
    part of the expected pattern.
  * api-change:``codebuild``: Support access tokens for Bitbucket sources
  * api-change:``iam``: For CreateOpenIDConnectProvider API, the ThumbprintList parameter is no
    longer required.
  * api-change:``medialive``: AWS Elemental MediaLive introduces workflow monitor, a new feature that
    enables the visualization and monitoring of your media workflows. Create signal maps of your
    existing workflows and monitor them by creating notification and monitoring template groups.
  * api-change:``omics``: This release adds support for retrieval of S3 direct access metadata on
    sequence stores and read sets, and adds support for SHA256up and SHA512up HealthOmics ETags.
  * api-change:``pipes``: LogConfiguration ARN validation fixes
  * api-change:``rds``: Updates Amazon RDS documentation for Standard Edition 2 support in RDS Custom
    for Oracle.
  * api-change:``s3control``: Documentation updates for Amazon S3-control.
- from version 1.32.82
  * api-change:``cleanrooms``: AWS Clean Rooms Differential Privacy is now fully available.
    Differential privacy protects against user-identification attempts.
  * api-change:``connect``: This release adds new Submit Auto Evaluation Action for Amazon Connect
    Rules.
  * api-change:``networkmonitor``: Examples were added to CloudWatch Network Monitor commands.
  * api-change:``qconnect``: This release adds a new QiC public API updateSession and updates an
    existing QiC public API createSession
  * api-change:``rekognition``: Added support for ContentType to content moderation detections.
  * api-change:``supplychain``: This release includes API SendDataIntegrationEvent for AWS Supply
    Chain
  * api-change:``workspaces-thin-client``: Adding tags field to SoftwareSet. Removing tags fields
    from Summary objects. Changing the list of exceptions in tagging APIs. Fixing an issue where the
    SDK returns empty tags in Get APIs.
- from version 1.32.81
  * api-change:``codebuild``: Add new webhook filter types for GitHub webhooks
  * api-change:``mediaconvert``: This release includes support for bringing your own fonts to use for
    burn-in or DVB-Sub captioning workflows.
  * api-change:``pinpoint``: The OrchestrationSendingRoleArn has been added to the email channel and
    is used to send emails from campaigns or journeys.
  * api-change:``rds``: This release adds support for specifying the CA certificate to use for the
    new db instance when restoring from db snapshot, restoring from s3, restoring to point in time, and
    creating a db instance read replica.
- from version 1.32.80
  * api-change:``controlcatalog``: This is the initial SDK release for AWS Control Catalog, a central
    catalog for AWS managed controls. This release includes 3 new APIs - ListDomains, ListObjectives,
    and ListCommonControls - that vend high-level data to categorize controls across the AWS platform.
  * api-change:``mgn``: Added USE_SOURCE as default option to LaunchConfigurationTemplate bootMode
    parameter.
  * api-change:``networkmonitor``: Updated the allowed monitorName length for CloudWatch Network
    Monitor.
- from version 1.32.79
  * api-change:``quicksight``: Adding IAMIdentityCenterInstanceArn parameter to
    CreateAccountSubscription
  * api-change:``resource-groups``: Added a new QueryErrorCode RESOURCE_TYPE_NOT_SUPPORTED that is
    returned by the ListGroupResources operation if the group query contains unsupported resource types.
  * api-change:``verifiedpermissions``: Adding BatchIsAuthorizedWithToken API which supports multiple
    authorization requests against a PolicyStore given a bearer token.
- from version 1.32.78
  * api-change:``b2bi``: Adding support for X12 5010 HIPAA EDI version and associated transaction
    sets.
  * api-change:``cleanrooms``: Feature: New schemaStatusDetails field to the existing Schema object
    that displays a status on Schema API responses to show whether a schema is queryable or not. New
    BatchGetSchemaAnalysisRule API to retrieve multiple schemaAnalysisRules using a single API call.
  * api-change:``ec2``: Amazon EC2 G6 instances powered by NVIDIA L4 Tensor Core GPUs can be used for
    a wide range of graphics-intensive and machine learning use cases. Gr6 instances also feature
    NVIDIA L4 GPUs and can be used for graphics workloads with higher memory requirements.
  * api-change:``emr-containers``: This release adds support for integration with EKS AccessEntry
    APIs to enable automatic Cluster Access for EMR on EKS.
  * api-change:``ivs``: API update to include an SRT ingest endpoint and passphrase for all channels.
  * api-change:``verifiedpermissions``: Adds GroupConfiguration field to Identity Source API's
- from version 1.32.77
  * api-change:``cleanroomsml``: The release includes a public SDK for AWS Clean Rooms ML APIs,
    making them globally available to developers worldwide.
  * api-change:``cloudformation``: This release would return a new field - PolicyAction in
    cloudformation's existed DescribeChangeSetResponse, showing actions we are going to apply on the
    physical resource (e.g., Delete, Retain) according to the user's template
  * api-change:``datazone``: This release supports the feature of dataQuality to enrich asset with
    dataQualityResult in Amazon DataZone.
  * api-change:``docdb``: This release adds Global Cluster Switchover capability which enables you to
    change your global cluster's primary AWS Region, the region that serves writes, while preserving
    the replication between all regions in the global cluster.
  * api-change:``groundstation``: This release adds visibilityStartTime and visibilityEndTime to
    DescribeContact and ListContacts responses.
  * api-change:``lambda``: Add Ruby 3.3 (ruby3.3) support to AWS Lambda
  * api-change:``medialive``: Cmaf Ingest outputs are now supported in Media Live
  * api-change:``medical-imaging``: SearchImageSets API now supports following enhancements -
    Additional support for searching on UpdatedAt and SeriesInstanceUID - Support for searching
    existing filters between dates/times - Support for sorting the search result by
    Ascending/Descending - Additional parameters returned in the response
  * api-change:``transfer``: Add ability to specify Security Policies for SFTP Connectors
- from version 1.32.76
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``glue``: Adding View related fields to responses of read-only Table APIs.
  * api-change:``ivschat``: Doc-only update. Changed "Resources" to "Key Concepts" in docs and
    updated text.
  * api-change:``rolesanywhere``: This release increases the limit on the roleArns request parameter
    for the *Profile APIs that support it. This parameter can now take up to 250 role ARNs.
  * api-change:``securityhub``: Documentation updates for AWS Security Hub
- from version 1.32.75
  * api-change:``cloudwatch``: This release adds support for CloudWatch Anomaly Detection on
    cross-account metrics. SingleMetricAnomalyDetector and MetricDataQuery inputs to Anomaly Detection
    APIs now take an optional AccountId field.
  * api-change:``datazone``: This release supports the feature of AI recommendations for descriptions
    to enrich the business data catalog in Amazon DataZone.
  * api-change:``deadline``: AWS Deadline Cloud is a new fully managed service that helps customers
    set up, deploy, and scale rendering projects in minutes, so they can improve the efficiency of
    their rendering pipelines and take on more projects.
  * api-change:``emr``: This release fixes a broken link in the documentation.
  * api-change:``lightsail``: This release adds support to upgrade the TLS version of the
    distribution.
- from version 1.32.74
  * api-change:``b2bi``: Supporting new EDI X12 transaction sets for X12 versions 4010, 4030, and
    5010.
  * api-change:``codebuild``: Add new fleet status code for Reserved Capacity.
  * api-change:``codeconnections``: Duplicating the CodeStar Connections service into the new,
    rebranded AWS CodeConnections service.
  * api-change:``internetmonitor``: This release adds support to allow customers to track cross
    account monitors through ListMonitor, GetMonitor, ListHealthEvents, GetHealthEvent, StartQuery APIs.
  * api-change:``iotwireless``: Add support for retrieving key historical and live metrics for
    LoRaWAN devices and gateways
  * api-change:``marketplace-catalog``: This release enhances the ListEntities API to support
    ResaleAuthorizationId filter and sort for OfferEntity in the request and the addition of a
    ResaleAuthorizationId field in the response of OfferSummary.
  * api-change:``neptune-graph``: Add the new API Start-Import-Task for Amazon Neptune Analytics.
  * api-change:``sagemaker``: This release adds support for custom images for the CodeEditor App on
    SageMaker Studio
  * enhancement:``s3``: Add parameter to validate source and destination S3 URIs to the ``mv``
    command.
- from version 1.32.73
  * api-change:``codecatalyst``: This release adds support for understanding pending changes to
    subscriptions by including two new response parameters for the GetSubscription API for Amazon
    CodeCatalyst.
  * api-change:``compute-optimizer``: This release enables AWS Compute Optimizer to analyze and
    generate recommendations with a new customization preference, Memory Utilization.
  * api-change:``ec2``: Amazon EC2 C7gd, M7gd and R7gd metal instances with up to 3.8 TB of local
    NVMe-based SSD block-level storage have up to 45%% improved real-time NVMe storage performance than
    comparable Graviton2-based instances.
  * api-change:``eks``: Add multiple customer error code to handle customer caused failure when
    managing EKS node groups
  * api-change:``guardduty``: Add EC2 support for GuardDuty Runtime Monitoring auto management.
  * api-change:``neptune-graph``: Update ImportTaskCancelled waiter to evaluate task state correctly
    and minor documentation changes.
  * api-change:``oam``: This release adds support for sharing AWS::InternetMonitor::Monitor resources.
  * api-change:``quicksight``: Amazon QuickSight: Adds support for setting up VPC Endpoint
    restrictions for accessing QuickSight Website.
- from version 1.32.72
  * api-change:``batch``: This feature allows AWS Batch to support configuration of imagePullSecrets
    and allowPrivilegeEscalation for jobs running on EKS
  * api-change:``bedrock-agent``: This changes introduces metadata documents statistics and also
    updates the documentation for bedrock agent.
  * api-change:``bedrock-agent-runtime``: This release introduces filtering support on Retrieve and
    RetrieveAndGenerate APIs.
  * api-change:``elasticache``: Added minimum capacity to  Amazon ElastiCache Serverless. This
    feature allows customer to ensure minimum capacity even without current load
  * api-change:``secretsmanager``: Documentation updates for Secrets Manager
- from version 1.32.71
  * api-change:``bedrock-agent-runtime``: This release adds support to customize prompts sent through
    the RetrieveAndGenerate API in Agents for Amazon Bedrock.
  * api-change:``ce``: Adds support for backfill of cost allocation tags, with new
    StartCostAllocationTagBackfill and ListCostAllocationTagBackfillHistory API.
  * api-change:``ec2``: Documentation updates for Elastic Compute Cloud (EC2).
  * api-change:``ecs``: This is a documentation update for Amazon ECS.
  * api-change:``finspace``: Add new operation delete-kx-cluster-node and add status parameter to
    list-kx-cluster-node operation.
- from version 1.32.70
  * api-change:``codebuild``: Supporting GitLab and GitLab Self Managed as source types in AWS
    CodeBuild.
  * api-change:``ec2``: Added support for ModifyInstanceMetadataDefaults and
    GetInstanceMetadataDefaults to set Instance Metadata Service account defaults
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``emr-containers``: This release increases the number of supported job template
    parameters from 20 to 100.
  * api-change:``globalaccelerator``: AWS Global Accelerator now supports cross-account sharing for
    bring your own IP addresses.
  * api-change:``medialive``: Exposing TileMedia H265 options
  * api-change:``sagemaker``: Introduced support for the following new instance types on SageMaker
    Studio for JupyterLab and CodeEditor applications: m6i, m6id, m7i, c6i, c6id, c7i, r6i, r6id, r7i,
    and p5
- from version 1.32.69
  * api-change:``firehose``: Updates Amazon Firehose documentation for message regarding Enforcing
    Tags IAM Policy.
  * api-change:``kendra``: Documentation update, March 2024. Corrects some docs for Amazon Kendra.
  * api-change:``pricing``: Add ResourceNotFoundException to ListPriceLists and GetPriceListFileUrl
    APIs
  * api-change:``rolesanywhere``: This release relaxes constraints on the durationSeconds request
    parameter for the *Profile APIs that support it. This parameter can now take on values that go up
    to 43200.
  * api-change:``securityhub``: Added new resource detail object to ASFF, including resource for
    LastKnownExploitAt
- from version 1.32.68
  * api-change:``codeartifact``: This release adds Package groups to CodeArtifact so you can more
    conveniently configure package origin controls for multiple packages.
- from version 1.32.67
  * api-change:``accessanalyzer``: This release adds support for policy validation and external
    access findings for DynamoDB tables and streams. IAM Access Analyzer helps you author functional
    and secure resource-based policies and identify cross-account access. Updated service API,
    documentation, and paginators.
  * api-change:``codebuild``: This release adds support for new webhook events (RELEASED and
    PRERELEASED) and filter types (TAG_NAME and RELEASE_NAME).
  * api-change:``connect``: This release updates the *InstanceStorageConfig APIs to support a new
    ResourceType: REAL_TIME_CONTACT_ANALYSIS_CHAT_SEGMENTS. Use this resource type to enable streaming
    for real-time analysis of chat contacts and to associate a Kinesis stream where real-time analysis
    chat segments will be published.
  * api-change:``dynamodb``: This release introduces 3 new APIs ('GetResourcePolicy',
    'PutResourcePolicy' and 'DeleteResourcePolicy') and modifies the existing 'CreateTable' API for the
    resource-based policy support. It also modifies several APIs to accept a 'TableArn' for the
    'TableName' parameter.
  * api-change:``managedblockchain-query``: AMB Query: update GetTransaction to include transactionId
    as input
  * api-change:``savingsplans``: Introducing the Savings Plans Return feature enabling customers to
    return their Savings Plans within 7 days of purchase.
- from version 1.32.66
  * api-change:``cloudformation``: Documentation update, March 2024. Corrects some formatting.
  * api-change:``ec2``: This release adds the new DescribeMacHosts API operation for getting
    information about EC2 Mac Dedicated Hosts. Users can now see the latest macOS versions that their
    underlying Apple Mac can support without needing to be updated.
  * api-change:``finspace``: Adding new attributes readWrite and onDemand to dataview models for
    Database Maintenance operations.
  * api-change:``logs``: Update LogSamples field in Anomaly model to be a list of LogEvent
  * api-change:``managedblockchain-query``: Introduces a new API for Amazon Managed Blockchain Query:
    ListFilteredTransactionEvents.
- from version 1.32.65
  * api-change:``cloudformation``: This release supports for a new API
    ListStackSetAutoDeploymentTargets, which provider auto-deployment configuration as a describable
    resource. Customers can now view the specific combinations of regions and OUs that are being
    auto-deployed.
  * api-change:``kms``: Adds the ability to use the default policy name by omitting the policyName
    parameter in calls to PutKeyPolicy and GetKeyPolicy
  * api-change:``mediatailor``: This release adds support to allow customers to show different
    content within a channel depending on metadata associated with the viewer.
  * api-change:``rds``: This release launches the ModifyIntegration API and support for data
    filtering for zero-ETL Integrations.
  * api-change:``s3``: Fix two issues with response root node names.
  * api-change:``timestream-query``: Documentation updates, March 2024
- from version 1.32.64
  * api-change:``backup``: This release introduces a boolean attribute ManagedByAWSBackupOnly as part
    of ListRecoveryPointsByResource api to filter the recovery points based on ownership. This
    attribute can be used to filter out the recovery points protected by AWSBackup.
  * api-change:``codebuild``: AWS CodeBuild now supports overflow behavior on Reserved Capacity.
  * api-change:``connect``: This release adds Hierarchy based Access Control fields to Security
    Profile public APIs and adds support for UserAttributeFilter to SearchUsers API.
  * api-change:``ec2``: Add media accelerator and neuron device information on the describe instance
    types API.
  * api-change:``kinesisanalyticsv2``: Support for Flink 1.18 in Managed Service for Apache Flink
  * api-change:``s3``: Documentation updates for Amazon S3.
  * api-change:``sagemaker``: Adds m6i, m6id, m7i, c6i, c6id, c7i, r6i r6id, r7i, p5 instance type
    support to Sagemaker Notebook Instances and miscellaneous wording fixes for previous Sagemaker
    documentation.
  * api-change:``workspaces-thin-client``: Removed unused parameter kmsKeyArn from UpdateDeviceRequest
- from version 1.32.63
  * api-change:``amplify``: Documentation updates for Amplify. Identifies the APIs available only to
    apps created using Amplify Gen 1.
  * api-change:``ec2-instance-connect``: This release includes a new exception type
    "SerialConsoleSessionUnsupportedException" for SendSerialConsoleSSHPublicKey API.
  * api-change:``elbv2``: This release allows you to configure HTTP client keep-alive duration for
    communication between clients and Application Load Balancers.
  * api-change:``fis``: This release adds support for previewing target resources before running a
    FIS experiment. It also adds resource ARNs for actions, experiments, and experiment templates to
    API responses.
  * api-change:``rds``: Updates Amazon RDS documentation for EBCDIC collation for RDS for Db2.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``timestream-influxdb``: This is the initial SDK release for Amazon Timestream for
    InfluxDB. Amazon Timestream for InfluxDB is a new time-series database engine that makes it easy
    for application developers and DevOps teams to run InfluxDB databases on AWS for near real-time
    time-series applications using open source APIs.
- from version 1.32.62
  * api-change:``ivs-realtime``: adds support for multiple new composition layout configuration
    options (grid, pip)
  * api-change:``kinesisanalyticsv2``: Support new RuntimeEnvironmentUpdate parameter within
    UpdateApplication API allowing callers to change the Flink version upon which their application
    runs.
  * api-change:``s3``: This release makes the default option for S3 on Outposts request signing to
    use the SigV4A algorithm when using AWS Common Runtime (CRT).
- from version 1.32.61
  * api-change:``cloudformation``: CloudFormation documentation update for March, 2024
  * api-change:``connect``: This release increases MaxResults limit to 500 in request for
    SearchUsers, SearchQueues and SearchRoutingProfiles APIs of Amazon Connect.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``kafka``: Added support for specifying the starting position of topic replication in
    MSK-Replicator.
  * api-change:``ssm``: March 2024 doc-only updates for Systems Manager.
- from version 1.32.60
  * api-change:``codestar-connections``: Added a sync configuration enum to disable publishing of
    deployment status to source providers (PublishDeploymentStatus). Added a sync configuration enum
    (TriggerStackUpdateOn) to only trigger changes.
  * api-change:``elasticache``: Revisions to API text that are now to be carried over to SDK text,
    changing usages of "SFO" in code examples to "us-west-1", and some other typos.
  * api-change:``mediapackagev2``: This release enables customers to safely update their MediaPackage
    v2 channel groups, channels and origin endpoints using entity tags.
- from version 1.32.59
  * api-change:``batch``: This release adds JobStateTimeLimitActions setting to the Job Queue API. It
    allows you to configure an action Batch can take for a blocking job in front of the queue after the
    defined period of time. The new parameter applies for ECS, EKS, and FARGATE Job Queues.
  * api-change:``bedrock-agent-runtime``: Documentation update for Bedrock Runtime Agent
  * api-change:``cloudtrail``: Added exceptions to CreateTrail, DescribeTrails, and
    ListImportFailures APIs.
  * api-change:``codebuild``: This release adds support for a new webhook event: PULL_REQUEST_CLOSED.
  * api-change:``cognito-idp``: Add ConcurrentModificationException to SetUserPoolMfaConfig
  * api-change:``guardduty``: Add RDS Provisioned and Serverless Usage types
  * api-change:``transfer``: Added DES_EDE3_CBC to the list of supported encryption algorithms for
    messages sent with an AS2 connector.
- from version 1.32.58
  * api-change:``appconfig``: AWS AppConfig now supports dynamic parameters, which enhance the
    functionality of AppConfig Extensions by allowing you to provide parameter values to your
    Extensions at the time you deploy your configuration.
  * api-change:``ec2``: This release adds an optional parameter to RegisterImage and CopyImage APIs
    to support tagging AMIs at the time of creation.
  * api-change:``grafana``: Adds support for the new GrafanaToken as part of the Amazon Managed
    Grafana Enterprise plugins upgrade to associate your AWS account with a Grafana Labs account.
  * api-change:``lambda``: Documentation updates for AWS Lambda
  * api-change:``payment-cryptography-data``: AWS Payment Cryptography EMV Decrypt Feature  Release
  * api-change:``rds``: Updates Amazon RDS documentation for io2 storage for Multi-AZ DB clusters
  * api-change:``snowball``: Doc-only update for change to EKS-Anywhere ordering.
  * api-change:``wafv2``: You can increase the max request body inspection size for some regional
    resources. The size setting is in the web ACL association config. Also, the
    AWSManagedRulesBotControlRuleSet EnableMachineLearning setting now takes a Boolean instead of a
    primitive boolean type, for languages like Java.
  * api-change:``workspaces``: Added note for user decoupling
- from version 1.32.57
  * api-change:``dynamodb``: Doc only updates for DynamoDB documentation
  * api-change:``imagebuilder``: Add PENDING status to Lifecycle Execution resource status. Add
    StartTime and EndTime to ListLifecycleExecutionResource API response.
  * api-change:``mwaa``: Amazon MWAA adds support for Apache Airflow v2.8.1.
  * api-change:``rds``: Updated the input of CreateDBCluster and ModifyDBCluster to support setting
    CA certificates. Updated the output of DescribeDBCluster to show current CA certificate setting
    value.
  * api-change:``redshift``: Update for documentation only. Covers port ranges, definition updates
    for data sharing, and definition updates to cluster-snapshot documentation.
  * api-change:``verifiedpermissions``: Deprecating details in favor of configuration for
    GetIdentitySource and ListIdentitySources APIs.
- from version 1.32.56
  * api-change:``apigateway``: Documentation updates for Amazon API Gateway
  * api-change:``chatbot``: Minor update to documentation.
  * api-change:``organizations``: This release contains an endpoint addition
  * api-change:``sesv2``: Adds support for providing custom headers within SendEmail and
    SendBulkEmail for SESv2.
- from version 1.32.55
  * api-change:``cloudformation``: Add DetailedStatus field to DescribeStackEvents and DescribeStacks
    APIs
  * api-change:``fsx``: Added support for creating FSx for NetApp ONTAP file systems with up to 12 HA
    pairs, delivering up to 72 GB/s of read throughput and 12 GB/s of write throughput.
  * api-change:``organizations``: Documentation update for AWS Organizations
- from version 1.32.54
  * api-change:``accessanalyzer``: Fixed a typo in description field.
  * api-change:``autoscaling``: With this release, Amazon EC2 Auto Scaling groups, EC2 Fleet, and
    Spot Fleet improve the default price protection behavior of attribute-based instance type selection
    of Spot Instances, to consistently select from a wide range of instance types.
  * api-change:``ec2``: With this release, Amazon EC2 Auto Scaling groups, EC2 Fleet, and Spot Fleet
    improve the default price protection behavior of attribute-based instance type selection of Spot
    Instances, to consistently select from a wide range of instance types.
- from version 1.32.53
  * api-change:``docdb-elastic``: Launched Elastic Clusters Readable Secondaries, Start/Stop,
    Configurable Shard Instance count, Automatic Backups and Snapshot Copying
  * api-change:``eks``: Added support for new AL2023 AMIs to the supported AMITypes.
  * api-change:``lexv2-models``: This release makes AMAZON.QnAIntent generally available in Amazon
    Lex. This generative AI feature leverages large language models available through Amazon Bedrock to
    automate frequently asked questions (FAQ) experience for end-users.
  * api-change:``migrationhuborchestrator``: Adds new CreateTemplate, UpdateTemplate and
    DeleteTemplate APIs.
  * api-change:``quicksight``: TooltipTarget for Combo chart visuals; ColumnConfiguration limit
    increase to 2000; Documentation Update
  * api-change:``sagemaker``: Adds support for ModelDataSource in Model Packages to support unzipped
    models. Adds support to specify SourceUri for models which allows registration of models without
    mandating a container for hosting. Using SourceUri, customers can decouple the model from hosting
    information during registration.
  * api-change:``securitylake``: Add capability to update the Data Lake's MetaStoreManager Role in
    order to perform required data lake updates to use Iceberg table format in their data lake or
    update the role for any other reason.
- from version 1.32.52
  * api-change:``batch``: This release adds Batch support for configuration of multicontainer jobs in
    ECS, Fargate, and EKS. This support is available for all types of jobs, including both array jobs
    and multi-node parallel jobs.
  * api-change:``bedrock-agent-runtime``: This release adds support to override search strategy
    performed by the Retrieve and RetrieveAndGenerate APIs for Amazon Bedrock Agents
  * api-change:``ce``: This release introduces the new API 'GetApproximateUsageRecords', which
    retrieves estimated usage records for hourly granularity or resource-level data at daily
    granularity.
  * api-change:``ec2``: This release increases the range of MaxResults for
    GetNetworkInsightsAccessScopeAnalysisFindings to 1,000.
  * api-change:``iot``: This release reduces the maximum results returned per query invocation from
    500 to 100 for the SearchIndex API. This change has no implications as long as the API is invoked
    until the nextToken is NULL.
  * api-change:``wafv2``: AWS WAF now supports configurable time windows for request aggregation with
    rate-based rules. Customers can now select time windows of 1 minute, 2 minutes or 10 minutes, in
    addition to the previously supported 5 minutes.
- from version 1.32.51
  * api-change:``amplifyuibuilder``: We have added the ability to tag resources after they are created
- from version 1.32.50
  * api-change:``apigateway``: Documentation updates for Amazon API Gateway.
  * api-change:``drs``: Added volume status to DescribeSourceServer replicated volumes.
  * api-change:``kafkaconnect``: Adds support for tagging, with new TagResource, UntagResource and
    ListTagsForResource APIs to manage tags and updates to existing APIs to allow tag on create. This
    release also adds support for the new DeleteWorkerConfiguration API.
  * api-change:``rds``: This release adds support for gp3 data volumes for Multi-AZ DB Clusters.
- from version 1.32.49
  * api-change:``appsync``: Documentation only updates for AppSync
  * api-change:``qldb``: Clarify possible values for KmsKeyArn and EncryptionDescription.
  * api-change:``rds``: Add pattern and length based validations for DBShardGroupIdentifier
  * api-change:``rum``: Doc-only update for new RUM metrics that were added
- from version 1.32.48
  * api-change:``internetmonitor``: This release adds IPv4 prefixes to health events
  * api-change:``kinesisvideo``: Increasing NextToken parameter length restriction for List APIs from
    512 to 1024.
- from version 1.32.47
  * api-change:``iotevents``: Increase the maximum length of descriptions for Inputs, Detector
    Models, and Alarm Models
  * api-change:``lookoutequipment``: This release adds a field exposing model quality to read APIs
    for models. It also adds a model quality field to the API response when creating an inference
    scheduler.
  * api-change:``medialive``: MediaLive now supports the ability to restart pipelines in a running
    channel.
  * api-change:``ssm``: This release adds support for sharing Systems Manager parameters with other
    AWS accounts.
- from version 1.32.46
  * api-change:``dynamodb``: Publishing quick fix for doc only update.
  * api-change:``firehose``: This release updates a few Firehose related APIs.
  * api-change:``lambda``: Add .NET 8 (dotnet8) Runtime support to AWS Lambda.
- from version 1.32.45
  * api-change:``amplify``: This release contains API changes that enable users to configure their
    Amplify domains with their own custom SSL/TLS certificate.
  * api-change:``chatbot``: This release adds support for AWS Chatbot. You can now monitor, operate,
    and troubleshoot your AWS resources with interactive ChatOps using the AWS SDK.
  * api-change:``config``: Documentation updates for the AWS Config CLI
  * api-change:``ivs``: Changed description for latencyMode in Create/UpdateChannel and
    Channel/ChannelSummary.
  * api-change:``keyspaces``: Documentation updates for Amazon Keyspaces
  * api-change:``mediatailor``: MediaTailor: marking #AdBreak.OffsetMillis as required.
- from version 1.32.44
  * api-change:``connectparticipant``: Doc only update to GetTranscript API reference guide to inform
    users about presence of events in the chat transcript.
  * api-change:``emr``: adds fine grained control over Unhealthy Node Replacement to Amazon
    ElasticMapReduce
  * api-change:``firehose``: This release adds support for Data Message Extraction for decompressed
    CloudWatch logs, and to use a custom file extension or time zone for S3 destinations.
  * api-change:``lambda``: Documentation-only updates for Lambda to clarify a number of existing
    actions and properties.
  * api-change:``rds``: Doc only update for a valid option in DB parameter group
  * api-change:``sns``: This release marks phone numbers as sensitive inputs.
- from version 1.32.43
  * api-change:``artifact``: This is the initial SDK release for AWS Artifact. AWS Artifact provides
    on-demand access to compliance and third-party compliance reports. This release includes access to
    List and Get reports, along with their metadata. This release also includes access to AWS Artifact
    notifications settings.
  * api-change:``codepipeline``: Add ability to override timeout on action level.
  * api-change:``detective``: Doc only updates for content enhancement
  * api-change:``guardduty``: Marked fields IpAddressV4, PrivateIpAddress, Email as Sensitive.
  * api-change:``healthlake``: This release adds a new response parameter, JobProgressReport, to the
    DescribeFHIRImportJob and ListFHIRImportJobs API operation. JobProgressReport provides details on
    the progress of the import job on the server.
  * api-change:``opensearch``: Adds additional supported instance types.
  * api-change:``polly``: Amazon Polly adds 1 new voice - Burcu (tr-TR)
  * api-change:``sagemaker``: This release adds a new API UpdateClusterSoftware for SageMaker
    HyperPod. This API allows users to patch HyperPod clusters with latest platform softwares.
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.42
  * api-change:``controltower``: Adds support for new Baseline and EnabledBaseline APIs for
    automating multi-account governance.
  * api-change:``lookoutequipment``: This feature allows customers to see pointwise model diagnostics
    results for their models.
  * api-change:``qbusiness``: This release adds the metadata-boosting feature, which allows customers
    to easily fine-tune the underlying ranking of retrieved RAG passages in order to optimize Q&A
    answer relevance. It also adds new feedback reasons for the PutFeedback API.
- from version 1.32.41
  * api-change:``lightsail``: This release adds support to upgrade the major version of a database.
  * api-change:``marketplace-catalog``: AWS Marketplace Catalog API now supports setting intent on
    requests
  * api-change:``resource-explorer-2``: Resource Explorer now uses newly supported IPv4
    'amazonaws.com' endpoints by default.
  * api-change:``securitylake``: Documentation updates for Security Lake
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.40
  * api-change:``appsync``: Adds support for new options on GraphqlAPIs, Resolvers and  Data Sources
    for emitting Amazon CloudWatch metrics for enhanced monitoring of AppSync APIs.
  * api-change:``cloudwatch``: Update cloudwatch command to latest version
  * api-change:``neptune-graph``: Adding a new option "parameters" for data plane api ExecuteQuery to
    support running parameterized query via SDK.
  * api-change:``route53domains``: This release adds bill contact support for RegisterDomain,
    TransferDomain, UpdateDomainContact and GetDomainDetail API.
- from version 1.32.39
  * api-change:``amp``: Overall documentation updates.
  * api-change:``batch``: This feature allows Batch to support configuration of repository
    credentials for jobs running on ECS
  * api-change:``braket``: Creating a job will result in DeviceOfflineException when using an offline
    device, and DeviceRetiredException when using a retired device.
  * api-change:``cost-optimization-hub``: Adding includeMemberAccounts field to the response of
    ListEnrollmentStatuses API.
  * api-change:``ecs``: Documentation only update for Amazon ECS.
  * api-change:``iot``: This release allows AWS IoT Core users to enable Online Certificate Status
    Protocol (OCSP) Stapling for TLS X.509 Server Certificates when creating and updating AWS IoT
    Domain Configurations with Custom Domain.
  * api-change:``pricing``: Add Throttling Exception to all APIs.
- from version 1.32.38
  * api-change:``codepipeline``: Add ability to execute pipelines with new parallel & queued
    execution modes and add support for triggers with filtering on branches and file paths.
  * api-change:``quicksight``: General Interactions for Visuals; Waterfall Chart Color Configuration;
    Documentation Update
  * api-change:``workspaces``: This release introduces User-Decoupling feature. This feature allows
    Workspaces Core customers to provision workspaces without providing users. CreateWorkspaces and
    DescribeWorkspaces APIs will now take a new optional parameter "WorkspaceName".
- from version 1.32.37
  * api-change:``datasync``: AWS DataSync now supports manifests for specifying files or objects to
    transfer.
  * api-change:``lexv2-models``: Update lexv2-models command to latest version
  * api-change:``redshift``: LisRecommendations API to fetch Amazon Redshift Advisor recommendations.
- from version 1.32.36
  * api-change:``appsync``: Support for environment variables in AppSync GraphQL APIs
  * api-change:``ecs``: This release is a documentation only update to address customer issues.
  * api-change:``es``: This release adds clear visibility to the customers on the changes that they
    make on the domain.
  * api-change:``logs``: This release adds a new field, logGroupArn, to the response of the
    logs:DescribeLogGroups action.
  * api-change:``opensearch``: This release adds clear visibility to the customers on the changes
    that they make on the domain.
  * api-change:``wafv2``: You can now delete an API key that you've created for use with your CAPTCHA
    JavaScript integration API.
- from version 1.32.35
  * api-change:``glue``: Introduce Catalog Encryption Role within Glue Data Catalog Settings.
    Introduce SASL/PLAIN as an authentication method for Glue Kafka connections
  * api-change:``workspaces``: Added definitions of various WorkSpace states
- from version 1.32.34
  * api-change:``dynamodb``: Any number of users can execute up to 50 concurrent restores (any type
    of restore) in a given account.
  * api-change:``sagemaker``: Amazon SageMaker Canvas adds GenerativeAiSettings support for
    CanvasAppSettings.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest version
- from version 1.32.33
  * api-change:``cognito-idp``: Added CreateIdentityProvider and UpdateIdentityProvider details for
    new SAML IdP features
  * api-change:``ivs``: This release introduces a new resource Playback Restriction Policy which can
    be used to geo-restrict or domain-restrict channel stream playback when associated with a channel.
    New APIs to support this resource were introduced in the form of Create/Delete/Get/Update/List.
  * api-change:``managedblockchain-query``: This release adds support for transactions that have not
    reached finality. It also removes support for the status property from the response of the
    GetTransaction operation. You can use the confirmationStatus and executionStatus properties to
    determine the status of the transaction.
  * api-change:``mediaconvert``: This release includes support for broadcast-mixed audio description
    tracks.
  * api-change:``neptune-graph``: Adding new APIs in SDK for Amazon Neptune Analytics. These APIs
    include operations to execute, cancel, list queries and get the graph summary.
- from version 1.32.32
  * api-change:``cloudformation``: CloudFormation IaC generator allows you to scan existing resources
    in your account and select resources to generate a template for a new or existing CloudFormation
    stack.
  * api-change:``elbv2``: Update elbv2 command to latest version
  * api-change:``glue``: Update page size limits for GetJobRuns and GetTriggers APIs.
  * api-change:``ssm``: This release adds an optional Duration parameter to StateManager
    Associations. This allows customers to specify how long an apply-only-on-cron association execution
    should run. Once the specified Duration is out all the ongoing cancellable commands or automations
    are cancelled.
- Refresh patches for new version
  * ac_update-docutils.patch
- Update Requires from setup.py
* Wed Mar 13 2024 Robert Schweikert <rjschwei@suse.com>
- Reconfigure the spec file support builds better in Factory and SLE
  supporting different Python interpreter versions
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Jan 31 2024 Robert Schweikert <rjschwei@suse.com>
- Switch to Python 3.11 build in SLE 15 SP4 and openSUSE Leap 15.4 and
  later (jsc#PCT-371)
- Switch to wheel build
- Update to version 1.32.31
  * Forward port ac_update-docutils.patch
  * api-change:``datazone``: Add new skipDeletionCheck to DeleteDomain. Add
    new skipDeletionCheck to DeleteProject which also automatically deletes
    dependent objects
  * api-change:``route53``: Update the SDKs for text changes in the APIs.
- From 1.32.30
  * api-change:``autoscaling``: EC2 Auto Scaling customers who use attribute
    based instance-type selection can now intuitively define their Spot
    instances price protection limit as a percentage of the lowest priced
    On-Demand instance type.
  * api-change:``comprehend``: Comprehend PII analysis now supports Spanish
    input documents.
  * api-change:``ec2``: EC2 Fleet customers who use attribute based
    instance-type selection can now intuitively define their Spot instances
    price protection limit as a percentage of the lowest priced On-Demand
    instance type.
  * api-change:``mwaa``: This release adds MAINTENANCE environment status for
    Amazon MWAA environments.
  * api-change:``rds``: Introduced support for the
    InsufficientDBInstanceCapacityFault error in the RDS
    RestoreDBClusterFromSnapshot and RestoreDBClusterToPointInTime API methods.
    This provides enhanced error handling, ensuring a more robust experience.
  * api-change:``snowball``: Modified description of createaddress to include
    direction to add path when providing a JSON file.
- From 1.32.29
  * api-change:``connect``: Update list and string length limits for predefined
    attributes.
  * api-change:``inspector2``: This release adds ECR container image scanning
    based on their lastRecordedPullTime.
  * api-change:``sagemaker``: Amazon SageMaker Automatic Model Tuning now
    provides an API to programmatically delete tuning jobs.
- From 1.32.28
  * api-change:``acm-pca``: AWS Private CA now supports an option to omit the
    CDP extension from issued certificates, when CRL revocation is enabled.
  * api-change:``lightsail``: This release adds support for IPv6-only instance
    plans.
- From 1.32.27
  * api-change:``ec2``: Introduced a new clientToken request parameter on
    CreateNetworkAcl and CreateRouteTable APIs. The clientToken parameter
    allows idempotent operations on the APIs.
  * api-change:``ecs``: Documentation updates for Amazon ECS.
  * api-change:``outposts``: DeviceSerialNumber parameter is now optional in
    StartConnection API
  * api-change:``rds``: This release adds support for Aurora Limitless Database.
  * api-change:``storagegateway``: Add DeprecationDate and SoftwareVersion to
    response of ListGateways.
- From 1.32.26
  * api-change:``inspector2``: This release adds support for CIS scans on EC2
    instances.
- From 1.32.25
  * bugfix:``s3 sync``: Disable S3 Express support for s3 sync command
- From 1.32.24
  * api-change:``appconfigdata``: Fix FIPS Endpoints in aws-us-gov.
  * api-change:``cloud9``: Doc-only update around removing AL1 from list of
    available AMIs for Cloud9
  * api-change:``cloudfront-keyvaluestore``: This release improves upon the
    DescribeKeyValueStore API by returning two additional fields, Status of the
    KeyValueStore and the FailureReason in case of failures during creation of
    KeyValueStore.
  * api-change:``connectcases``: This release adds the ability to view audit
    history on a case and introduces a new parameter, performedBy, for
    CreateCase and UpdateCase API's.
  * api-change:``ec2``: Documentation updates for Amazon EC2.
  * api-change:``ecs``: This release adds support for Transport Layer Security
    (TLS) and Configurable Timeout to ECS Service Connect. TLS facilitates
    privacy and data security for inter-service communications, while
    Configurable Timeout allows customized per-request timeout and idle timeout
    for Service Connect services.
  * api-change:``finspace``: Allow customer to set zip default through command
    line arguments.
  * api-change:``organizations``: Doc only update for quota increase change
  * api-change:``rds``: Introduced support for the
    InsufficientDBInstanceCapacityFault error in the RDS CreateDBCluster API
    method. This provides enhanced error handling, ensuring a more robust
    experience when creating database clusters with insufficient instance
    capacity.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.23
  * api-change:``athena``: Introducing new NotebookS3LocationUri parameter to
    Athena ImportNotebook API. Payload is no longer required and either Payload
    or NotebookS3LocationUri needs to be provided (not both) for a successful
    ImportNotebook API call. If both are provided, an InvalidRequestException
    will be thrown.
  * api-change:``codebuild``: Release CodeBuild Reserved Capacity feature
  * api-change:``dynamodb``: This release adds support for including
    ApproximateCreationDateTimePrecision configurations in
    EnableKinesisStreamingDestination API, adds the same as an optional field
    in the response of DescribeKinesisStreamingDestination, and adds support
    for a new UpdateKinesisStreamingDestination API.
  * api-change:``qconnect``: Increased Quick Response name max length to 100
- From 1.32.22
  * api-change:``b2bi``: Increasing TestMapping inputFileContent file size
    limit to 5MB and adding file size limit 250KB for TestParsing input file.
    This release also includes exposing InternalServerException for Tag APIs.
  * api-change:``cloudtrail``: This release adds a new API
    ListInsightsMetricData to retrieve metric data from CloudTrail Insights.
  * api-change:``connect``: GetMetricDataV2 now supports 3 groupings
  * api-change:``drs``: Removed invalid and unnecessary default values.
  * api-change:``firehose``: Allow support for Snowflake as a Kinesis Data
    Firehose delivery destination.
  * api-change:``sagemaker-featurestore-runtime``: Increase BatchGetRecord
    limits from 10 items to 100 items
- From 1.32.21
  * api-change:``dynamodb``: Updating note for enabling streams for UpdateTable.
  * api-change:``keyspaces``: This release adds support for Multi-Region
    Replication with provisioned tables, and Keyspaces auto scaling APIs
- From 1.32.20
  * api-change:``iot``: Revert release of LogTargetTypes
  * api-change:``iotfleetwise``: Updated APIs: SignalNodeType query parameter
    has been added to ListSignalCatalogNodesRequest and ListVehiclesResponse
    has been extended with attributes field.
  * api-change:``macie2``: This release adds support for analyzing Amazon S3
    objects that are encrypted using dual-layer server-side encryption with
    AWS KMS keys (DSSE-KMS). It also adds support for reporting DSSE-KMS
    details in statistics and metadata about encryption settings for S3 buckets
    and objects.
  * api-change:``payment-cryptography``: Provide an additional option for key
    exchange using RSA wrap/unwrap in addition to tr-34/tr-31 in ImportKey and
    ExportKey operations. Added new key usage (type)
    TR31_M1_ISO_9797_1_MAC_KEY, for use with Generate/VerifyMac dataplane
    operations  with ISO9797 Algorithm 1 MAC calculations.
  * api-change:``personalize-runtime``: Documentation updates for Amazon
    Personalize
  * api-change:``personalize``: Documentation updates for Amazon Personalize.
  * api-change:``rekognition``: This release adds ContentType and TaxonomyLevel
    attributes to DetectModerationLabels and GetMediaAnalysisJob API responses.
  * api-change:``securityhub``: Documentation updates for AWS Security Hub
- From 1.32.19
  * api-change:``sagemaker``: This release will have ValidationException thrown
    if certain invalid app types are provided. The release will also throw
    ValidationException if more than 10 account ids are provided in
    VpcOnlyTrustedAccounts.
- From 1.32.18
  * api-change:``connect``: Supervisor Barge for Chat is now supported through
    the MonitorContact API.
  * api-change:``connectparticipant``: Introduce new Supervisor participant
    role
  * api-change:``location``: Location SDK documentation update. Added missing
    fonts to the MapConfiguration data type. Updated note for the
    SubMunicipality property in the place data type.
  * api-change:``mwaa``: This Amazon MWAA feature release includes new fields
    in CreateWebLoginToken response model. The new fields IamIdentity and
    AirflowIdentity will let you match identifications, as the Airflow identity
    length is currently hashed to 64 characters.
  * api-change:``s3control``: S3 On Outposts team adds dualstack endpoints
    support for S3Control and S3Outposts API calls.
  * api-change:``supplychain``: This release includes APIs
    CreateBillOfMaterialsImportJob and GetBillOfMaterialsImportJob.
  * api-change:``transfer``: AWS Transfer Family now supports static IP
    addresses for SFTP & AS2 connectors and for async MDNs on AS2 servers.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.17
  * api-change:``ec2``: This release adds support for adding an
    ElasticBlockStorage volume configurations in ECS
    RunTask/StartTask/CreateService/UpdateService APIs. The configuration
    allows for attaching EBS volumes to ECS Tasks.
  * api-change:``ecs``: This release adds support for adding an
    ElasticBlockStorage volume configurations in ECS
    RunTask/StartTask/CreateService/UpdateService APIs. The configuration
    allows for attaching EBS volumes to ECS Tasks.
  * api-change:``events``: Update events command to latest version
  * api-change:``iot``: Add ConflictException to Update APIs of AWS IoT
    Software Package Catalog
  * api-change:``iotfleetwise``: The following dataTypes have been removed:
    CUSTOMER_DECODED_INTERFACE in NetworkInterfaceType;
    CUSTOMER_DECODED_SIGNAL_INFO_IS_NULL in SignalDecoderFailureReason;
    CUSTOMER_DECODED_SIGNAL_NETWORK_INTERFACE_INFO_IS_NULL in
    NetworkInterfaceFailureReason; CUSTOMER_DECODED_SIGNAL in SignalDecoderType
  * api-change:``secretsmanager``: Doc only update for Secrets Manager
  * api-change:``workspaces``: Added AWS Workspaces RebootWorkspaces
    API - Extended Reboot documentation update
- From 1.32.16
  * api-change:``connectcampaigns``: Minor pattern updates for Campaign and
    Dial Request API fields.
  * api-change:``location``: This release adds API support for custom layers
    for the maps service APIs: CreateMap, UpdateMap, DescribeMap.
  * api-change:``logs``: Add support for account level subscription filter
    policies to PutAccountPolicy, DescribeAccountPolicies, and
    DeleteAccountPolicy APIs. Additionally, PutAccountPolicy has been modified
    with new optional "selectionCriteria" parameter for resource selection.
  * api-change:``qconnect``: QueryAssistant and GetRecommendations will be
    discontinued starting June 1, 2024. To receive generative responses after
    March 1, 2024 you will need to create a new Assistant in the Connect
    console and integrate the Amazon Q in Connect JavaScript library
    (amazon-q-connectjs) into your applications.
  * api-change:``redshift-serverless``: Updates to ConfigParameter for RSS
    workgroup, removal of use_fips_ssl
  * api-change:``route53``: Route53 now supports geoproximity routing in AWS
    regions
  * api-change:``wisdom``: QueryAssistant and GetRecommendations will be
    discontinued starting June 1, 2024. To receive generative responses after
    March 1, 2024 you will need to create a new Assistant in the Connect
    console and integrate the Amazon Q in Connect JavaScript library
    (amazon-q-connectjs) into your applications.
- From 1.32.15
  * api-change:``codebuild``: Aws CodeBuild now supports new compute type
    BUILD_GENERAL1_XLARGE
  * api-change:``ec2``: Amazon EC2 R7iz bare metal instances are powered by
    custom 4th generation Intel Xeon Scalable processors.
  * api-change:``route53resolver``: This release adds support for query type
    configuration on firewall rules that enables customers for granular action
    (ALLOW, ALERT, BLOCK) by DNS query type.
- From 1.32.14
  * api-change:``connect``: Minor trait updates for User APIs
  * api-change:``kms``: Documentation updates for AWS Key Management Service
    (KMS).
  * api-change:``redshift-serverless``: use_fips_ssl and require_ssl parameter
    support for Workgroup, UpdateWorkgroup, and CreateWorkgroup
- From 1.32.13
  * api-change:``config``: Updated ResourceType enum with new resource types onboarded by AWS Config in November and December 2023.
  * api-change:``docdb``: Adding PerformanceInsightsEnabled and
    PerformanceInsightsKMSKeyId fields to DescribeDBInstances Response.
  * api-change:``ecs``: This release adds support for managed instance
    draining which facilitates graceful termination of Amazon ECS instances.
  * api-change:``es``: This release adds support for new or existing Amazon
    OpenSearch domains to enable TLS 1.3 or TLS 1.2 with perfect forward
    secrecy cipher suites for domain endpoints.
  * api-change:``lightsail``: This release adds support to set up an HTTPS
    endpoint on an instance.
  * api-change:``opensearch``: This release adds support for new or existing
    Amazon OpenSearch domains to enable TLS 1.3 or TLS 1.2 with perfect forward
    secrecy cipher suites for domain endpoints.
  * api-change:``sagemaker``: Adding support for provisioned throughput mode
    for SageMaker Feature Groups
  * api-change:``servicecatalog``: Added Idempotency token support to Service
    Catalog  AssociateServiceActionWithProvisioningArtifact,
    DisassociateServiceActionFromProvisioningArtifact, DeleteServiceAction API
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.12
  * api-change:``connect``: Amazon Connect, Contact Lens Evaluation API
    increase evaluation notes max length to 3072.
  * api-change:``mediaconvert``: This release includes video engine updates
    including HEVC improvements, support for ingesting VP9 encoded video in
    MP4 containers, and support for user-specified 3D LUTs.
- From 1.32.11
  * api-change:``apprunner``: AWS App Runner adds Python 3.11 and Node.js 18
    runtimes.
  * api-change:``location``: This release introduces a new parameter to
    bypasses an API key's expiry conditions and delete the key.
  * api-change:``quicksight``: Add LinkEntityArn support for different
    partitions; Add UnsupportedUserEditionException in UpdateDashboardLinks
    API; Add support for New Reader Experience Topics
- From 1.32.10
  * api-change:``codestar-connections``: New integration with the GitLab
    self-managed provider type.
  * api-change:``kinesis-video-archived-media``: NoDataRetentionException
    thrown when GetImages requested for a Stream that does not retain data
    (that is, has a DataRetentionInHours of 0).
  * api-change:``sagemaker``: Amazon SageMaker Studio now supports Docker
    access from within app container
- From 1.32.9
  * api-change:``emr``: Update emr command to latest version
- From 1.32.8
  * api-change:``iam``: Documentation updates for AWS Identity and Access
    Management (IAM).
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.7
  * api-change:``bedrock-agent``: Adding Claude 2.1 support to Bedrock Agents
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
  * api-change:``glue``: This release adds additional configurations for Query
    Session Context on the following APIs: GetUnfilteredTableMetadata,
    GetUnfilteredPartitionMetadata, GetUnfilteredPartitionsMetadata.
  * api-change:``lakeformation``: This release adds additional configurations
    on GetTemporaryGlueTableCredentials for Query Session Context.
  * api-change:``mediaconnect``: This release adds the DescribeSourceMetadata
    API. This API can be used to view the stream information of the flow's
    source.
  * api-change:``networkmonitor``: CloudWatch Network Monitor is a new service
    within CloudWatch that will help network administrators and operators
    continuously monitor network performance metrics such as round-trip-time
    and packet loss between their AWS-hosted applications and their on-premises
    locations.
  * api-change:``omics``: Provides minor corrections and an updated description
    of APIs.
  * api-change:``secretsmanager``: Update endpoint rules and examples.
- From 1.32.6
  * api-change:``amp``: This release updates Amazon Managed Service for
    Prometheus APIs to support customer managed KMS keys.
  * api-change:``appintegrations``: The Amazon AppIntegrations service adds
    DeleteApplication API for deleting applications, and updates APIs to
    support third party applications reacting to workspace events and make
    data requests to Amazon Connect for agent and contact events.
  * api-change:``bedrock-agent``: This release introduces Amazon Aurora as a
    vector store on Knowledge Bases for Amazon Bedrock
  * api-change:``codecommit``: AWS CodeCommit now supports customer managed
    keys from AWS Key Management Service. UpdateRepositoryEncryptionKey is
    added for updating the key configuration. CreateRepository, GetRepository,
    BatchGetRepositories are updated with new input or output parameters.
  * api-change:``connect``: Adds APIs to manage User Proficiencies and
    Predefined Attributes. Enhances StartOutboundVoiceContact API input.
    Introduces SearchContacts API. Enhances DescribeContact API. Adds an API to
    update Routing Attributes in QueuePriority and QueueTimeAdjustmentSeconds.
  * api-change:``medialive``: MediaLive now supports the ability to configure
    the audio that an AWS Elemental Link UHD device produces, when the device
    is configured as the source for a flow in AWS Elemental MediaConnect.
  * api-change:``neptune-graph``: Adds Waiters for successful creation and
    deletion of Graph, Graph Snapshot, Import Task and Private Endpoints for
    Neptune Analytics
  * api-change:``rds-data``: This release adds support for using RDS Data API
    with Aurora PostgreSQL Serverless v2 and provisioned DB clusters.
  * api-change:``rds``: This release adds support for using RDS Data API with
    Aurora PostgreSQL Serverless v2 and provisioned DB clusters.
  * api-change:``sagemaker``: Amazon SageMaker Training now provides model
    training container access for debugging purposes. Amazon SageMaker Search
    now provides the ability to use visibility conditions to limit resource
    access to a single domain or multiple domains.
- From 1.32.5
  * api-change:``appstream``: This release introduces configurable clipboard,
    allowing admins to specify the maximum length of text that can be copied by
    the users from their device to the remote session and vice-versa.
  * api-change:``eks``: Add support for cluster insights, new EKS capability
    that surfaces potentially upgrade impacting issues.
  * api-change:``guardduty``: This release 1) introduces a new API:
    GetOrganizationStatistics , and 2) adds a new UsageStatisticType
    TOP_ACCOUNTS_BY_FEATURE for GetUsageStatistics API
  * api-change:``managedblockchain-query``: Adding Confirmation Status and
    Execution Status to GetTransaction Response.
  * api-change:``mediatailor``: Adds the ability to configure time shifting on
    MediaTailor channels using the TimeShiftConfiguration field
  * api-change:``route53``: Amazon Route 53 now supports the Canada West
    (Calgary) Region (ca-west-1) for latency records, geoproximity records,
    and private DNS for Amazon VPCs in that region.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.4
  * api-change:``appsync``: This release adds additional configurations on
    GraphQL APIs for limits on query depth, resolver count, and introspection
  * api-change:``chime-sdk-meetings``: Add meeting features to specify a
    maximum camera resolution, a maximum content sharing resolution, and a
    maximum number of attendees for a given meeting.
  * api-change:``ec2``: Provision BYOIPv4 address ranges and advertise them by
    specifying the network border groups option in Los Angeles, Phoenix and
    Dallas AWS Local Zones.
  * api-change:``fsx``: Added support for FSx for OpenZFS on-demand data
    replication across AWS accounts and/or regions.Added the IncludeShared
    attribute for DescribeSnapshots.Added the CopyStrategy attribute for
    OpenZFSVolumeConfiguration.
  * api-change:``marketplace-catalog``: AWS Marketplace now supports a new API,
    BatchDescribeEntities, which returns metadata and content for multiple
    entities.
  * api-change:``rds``: RDS - The release adds two new APIs:
    DescribeDBRecommendations and ModifyDBRecommendation
- From 1.32.3
  * api-change:``cognito-idp``: Amazon Cognito now supports trigger versions
    that define the fields in the request sent to pre token generation Lambda
    triggers.
  * api-change:``eks``: Add support for EKS Cluster Access Management.
  * api-change:``quicksight``: A docs-only release to add missing entities to
    the API reference.
  * api-change:``route53resolver``: Add DOH protocols in resolver endpoints.
- From 1.32.2
  * enhancement:``cloudformation package``: Add support for intrinsic
    Fn:ForEach (fixes `#8075 <https://github.com/aws/aws-cli/issues/8075>`__)
  * api-change:``cloud9``: Updated Cloud9 API documentation for AL2023 release
  * api-change:``connect``: Adds relatedContactId field to
    StartOutboundVoiceContact API input. Introduces PauseContact API and
    ResumeContact API for Task contacts. Adds pause duration, number of pauses,
    timestamps for last paused and resumed events to DescribeContact API
    response. Adds new Rule type and new Rule action.
  * api-change:``connectcases``: Increase number of fields that can be included
    in CaseEventIncludedData from 50 to 200
  * api-change:``kms``: Documentation updates for AWS Key Management Service
  * api-change:``rds``: Updates Amazon RDS documentation by adding code examples
  * api-change:``sagemaker``: This release 1) introduces a new API:
    DeleteCompilationJob , and 2) adds InfraCheckConfig for Create/Describe
    training job API
- From 1.32.1
  * api-change:``appstream``: This release includes support for images of
    Windows Server 2022 platform.
  * api-change:``b2bi``: Documentation updates for AWS B2B Data Interchange
  * api-change:``billingconductor``: Billing Conductor is releasing a new API,
    GetBillingGroupCostReport, which provides the ability to retrieve/view the
    Billing Group Cost Report broken down by attributes for a specific billing
    group.
  * api-change:``connect``: This release adds support for more granular
    billing using tags (key:value pairs)
  * api-change:``controltower``: Documentation updates for AWS Control Tower.
  * api-change:``firehose``: This release, 1) adds configurable buffering hints
    for the Splunk destination, and 2) reduces the minimum configurable
    buffering interval for supported destinations
  * api-change:``gamelift``: Amazon GameLift adds the ability to add and update
    the game properties of active game sessions.
  * api-change:``iot``: This release adds the ability to self-manage
    certificate signing in AWS IoT Core fleet provisioning using the new
    certificate provider resource.
  * api-change:``neptune-graph``: This is the initial SDK release for Amazon
    Neptune Analytics
  * api-change:``opensearch``: Updating documentation for Amazon OpenSearch
    Service support for new zero-ETL integration with Amazon S3.
  * api-change:``quicksight``: Update Dashboard Links support;
    SingleAxisOptions support; Scatterplot Query limit support.
  * api-change:``workspaces``: Updated note to ensure customers understand
    running modes.
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
- From 1.32.0
  * feature:Python: End of support for Python 3.7
  * api-change:``drs``: Adding AgentVersion to SourceServer and
    RecoveryInstance structures
  * feature:Python: End of support for Python 3.7
- From 1.31.13
  * api-change:``imagebuilder``: This release adds the Image Workflows feature
    to give more flexibility and control over the image building and testing
    process.
  * api-change:``location``: This release 1)  adds sub-municipality field in
    Places API for searching and getting places information, and 2) allows
    optimizing route calculation based on expected arrival time.
  * api-change:``logs``: This release introduces the StartLiveTail API to tail
    ingested logs in near real time.
- From 1.31.12
  * api-change:``neptune``: This release adds a new parameter configuration
    setting to the Neptune cluster related APIs that can be leveraged to
    switch between the underlying supported storage modes.
  * api-change:``pinpoint``: This release includes Amazon Pinpoint API
    documentation updates pertaining to campaign message sending rate limits.
  * api-change:``securityhub``: Added new resource detail objects to ASFF,
    including resources for AwsDynamoDbTable, AwsEc2ClientVpnEndpoint,
    AwsMskCluster, AwsS3AccessPoint, AwsS3Bucket
  * api-change:``endpoint-rules``: Update endpoint-rules command to latest
    version
* Mon Dec 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.31.11
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.31.11/CHANGELOG.rst
- Add patch to update docutils dependency (bsc#1217336)
  + ac_update-docutils.patch
- Update Requires in spec file from setup.py
* Fri Nov 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.30.6
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.30.6/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Oct  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.61
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.61/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.36
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.27/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Aug 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.27
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.27/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jul 11 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.29.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.29.2/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jun 29 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.163
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.163/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jun 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.153
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.153/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue May  9 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.130
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.130/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr 19 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.115
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.115/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr  5 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1209255, jsc#PED-3780)
* Mon Mar 13 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.89
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.89/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.78
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.78/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.71
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.71/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Feb  8 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.66
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.66/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Feb  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 27 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.58
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.58/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jan 20 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.52
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.52/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.41
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.41/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  9 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.26
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.26/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Dec  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.21
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.21/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.8
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.8/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Nov  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.27.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.27.2/CHANGELOG.rst
- Relax upper version constraint for python-colorama in
  BuildRequires and Requires to 0.5.0 (bsc#1204917)
- Update Requires in spec file from setup.py
* Thu Nov  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update in SLE-15 (bsc#1204537, jsc#PED-2333)
* Tue Oct 25 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.26.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.26.0/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.91
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.91/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Oct  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.85
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.85/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Sep 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.76/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Sep 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.72
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.72/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Sep  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.64
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.64/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.60
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.60/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Aug 19 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.55
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.55/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Aug  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.45
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.45/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jul 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.37
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.37/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jun 30 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.20
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.20/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Jun  3 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.25.2
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.25.2/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.24.4 (bsc#1199716)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.4/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue May 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.24.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.24.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu May 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.23.11
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.11/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Apr 27 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.23.1
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.23.1/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Apr  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.87
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.87/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Mar  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.65
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.65/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Feb  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.46
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.46/CHANGELOG.rst
- Add missing python-rpm-macros to BuildRequires
- Update Requires in spec file from setup.py
* Fri Jan 14 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.35/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Jan  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.28
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.28/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Dec 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.22.24
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.22.24/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri Oct 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.21.6
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.21.6/CHANGELOG.rst
- Relax upper version dependency for python-docutils in Requires
- Update Requires in spec file from setup.py
* Fri Sep 10 2021 Michal Vyskocil <mvyskocil@opensuse.org>
- Update to version 1.20.32
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.32/CHANGELOG.rst
- Fix rpmlint warnings
  + use defattr for default permissions
  + mark zsh completion file as a config file
- Use github download url as a Source0
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.20.7
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 28 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.20.7 (bsc#1189649)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.20.7/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jul 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.112
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.112/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Wed Jun 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.86
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.86/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Fri May 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.75
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.75/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Apr 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.50
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.50/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Thu Feb 18 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.19.9 (bsc#1182421, bsc#1182422, jsc#ECO-3352, jsc#PM-2485)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.19.9/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Tue Jan 12 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.212
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.212/CHANGELOG.rst
- Update Requires in spec file from setup.py
* Mon Nov 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.185
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.185/CHANGELOG.rst
- Rename README.md to README.rst in %%doc section
- Update Requires in spec file from setup.py
* Fri Oct  9 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.156
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.156/CHANGELOG.rst
- Drop patches no longer required
  + hide_py_pckgmgmt.patch
- Update Requires in spec file from setup.py
* Mon Sep  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.133
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.133/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Aug 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.117 (bsc#1175147, bsc#1175148, jsc#ECO-2362, jsc#PM-2069)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.117/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Rename README.rst to README.md in %%docs section
* Thu Jul 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.98
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Jun 15 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.79
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.79/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Apr  8 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.38 (bsc#1166924, bsc#1168943)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.38/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Apr  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add bash-completion to BuildRequires for suse_version <= 1315
* Fri Apr  3 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.35
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.35/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Mar 24 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.27
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.27/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Feb 17 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.18.0
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.18.0/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Install aws bash completetion script into system path
  + Install aws zsh completion script into /etc/zsh_completion.d
  + Update Requires in spec file from setup.py
* Fri Feb 14 2020 Dirk Mueller <dmueller@suse.com>
- make it possible to find the package under the name "awscli"
* Mon Feb 10 2020 Robert Schweikert <rjschwei@suse.com>
- Add bash command completion capability (boo#1117074)
* Thu Jan 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.17.9
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.17.9/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Dec  5 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.297
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.297/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Nov 14 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.281
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.281/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Mon Oct 14 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.258
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.258/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Sep 27 2019 Robert Schweikert <rjschwei@suse.com>
- Add groff as a dependency (boo# 1152258)
* Thu Aug 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.223 (bsc#1146853)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.223/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Jun 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.189
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.189/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jun 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.182
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.182/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Wed Jun 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.176
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.176/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version constraints for python-PyYAML and python-rsa
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Run recursive find with chmod to remove executable bit for
  REST files in example folder to fix rpmlint warning
* Wed Feb 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.103
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.103/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Jan 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.94
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.94/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Jan  6 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.84
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.84/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Dec  4 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.61 (bsc#1118021, bsc#1118024)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.61/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
- Relax version dependency on colorama to <= 0.4.1 (boo#1118099)
* Tue Nov  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.48
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.48/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Thu Sep 13 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.16.1 (bsc#1105988, bsc#1092493)
  + Fix CVE-2018-15869
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.16.1/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Replace vendored version of six from botocore with upstream version
  + Update Requires in spec file from setup.py
* Mon Aug 13 2018 adrian.glaubitz@suse.com
- Update to version 1.15.76
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.76/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Sun Aug 12 2018 rjschwei@suse.com
- Be less strict with the YAML version requirement
- Switch the license file to %%license
* Sun Jul 22 2018 adrian.glaubitz@suse.com
- Update to version 1.15.63
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.63/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Tue Jun 19 2018 adrian.glaubitz@suse.com
- Update to version 1.15.40 (boo#1088310)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.15.40/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Update Requires in spec file from setup.py
* Fri Nov 10 2017 jengelh@inai.de
- Do not have description assume any particular user.
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 1.11.185 (boo#1066528)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.185/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
* Tue Sep 12 2017 rjschwei@suse.com
- Update to version 1.11.151
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.151/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
- Remove build capability for SLE 11
- Set up for Python 3 build distro > SLE 12 openSUSE Leap 42.x
* Wed Jun 14 2017 rjschwei@suse.com
- Update to version 1.11.104 (bsc#1044370)
  + For detailed changes see
    https://github.com/aws/aws-cli/blob/1.11.104/CHANGELOG.rst
* Thu Dec 15 2016 rjschwei@suse.com
- Update to 1.11.29 (bsc#1015776)
  + forward port hide_py_pckgmgmt.patch
  + feature:batch: Update batch command to latest version
  + feature:logs: Update logs command to latest version
  + feature:rds: Update rds command to latest version
  + feature:dms: Update dms command to latest version
  + feature:marketplacecommerceanalytics: Update marketplacecommerceanalytics
    command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:sts: Update sts command to latest version
- From 1.11.28
  + feature:cloudfront: Add lambda function associations to cache behaviors.
  + feature:rds: Add cluster create data to DBCluster APIs.
  + bugfix:opsworks: This fixes an issue with opsworks register --local and
    python3 on some versions of linux.
  + feature:waf-regional: With this new feature, customers can use AWS WAF
    directly on Application Load Balancers in a VPC within available regions
    to protect their websites and web services from malicious attacks such
    as SQL injection, Cross Site Scripting, bad bots, etc.
- From 1.11.27
  + feature:config: Update config command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:s3: Update s3 command to latest version
- From 1.11.26
  + feature:sts: Update sts command to latest version
  + feature:config: Update config command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:pinpoint: Update pinpoint command to latest version
- From 1.11.25
  + bugfix:opsworks-cm: Rename opsworkscm to opsworks-cm, keeping support
    for opsworkscm.
- From 1.11.24
  + feature:pinpoint: Update pinpoint command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:alias: Add ability to alias commands in the CLI
  + feature:xray: Update xray command to latest version
  + feature:s3: Display transfer speed for s3 commands
  + feature:ssm: Update ssm command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:codebuild: Update codebuild command to latest version
  + feature:opsworkscm: Update opsworkscm command to latest version
  + feature:shield: Update shield command to latest version
  + feature:stepfunctions: Update stepfunctions command to latest version
  + feature:appstream: Update appstream command to latest version
  + feature:health: Update health command to latest version
  + feature:ec2: Update ec2 command to latest version
- From 1.11.23
  + feature:polly: Update polly command to latest version
  + feature:snowball: Update snowball command to latest version
  + feature:rekognition: Update rekognition command to latest version
  + feature:lightsail: Update lightsail command to latest version
  + feature:--generate-cli-skeleton output: Add support for generating
    sample output for command
- From 1.11.22
  + feature:s3: Update s3 command to latest version
- From 1.11.21
  + feature:s3: Update s3 command to latest version
  + feature:glacier: Update glacier command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:route53: Update route53 command to latest version
- From 1.11.20
  + feature:ecs: Update ecs command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.11.19
  + feature:cloudformation deploy: Add command to simplify deployments
    of cloudformation stack changes.
  + feature:emr: Update emr command to latest version
  + feature:lambda: Update lambda command to latest version
  + feature:elastictranscoder: Update elastictranscoder command to latest
    version
  + feature:cloudformation package: Add command to package source code for
    cloudfromation template.
  + feature:gamelift: Update gamelift command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.11.18
  + bugfix:Powershell: Properly set return code on Powershell.
  + feature:cloudwatch: Update cloudwatch command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:meteringmarketplace: Update meteringmarketplace command to
    latest version
- From 1.11.17
  + feature:route53: Update route53 command to latest version
  + feature:servicecatalog: Update servicecatalog command to latest version
- From 1.11.16
  + feature:kinesis: Update kinesis command to latest version
  + feature:ds: Update ds command to latest version
  + feature:elasticache: Update elasticache command to latest version
- From 1.11.15
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.14
  + feature:cloudformation: Update cloudformation command to latest version
  + feature:logs: Update logs command to latest version
- From 1.11.13
  + feature:directconnect: Update directconnect command to latest version
- From 1.11.12
  + feature:ses: Update ses command to latest version
- From 1.11.11
  + bugfix:cloudtrail: Use STS instead of IAM in CreateSubscription
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.11.10
  + feature:autoscaling: Update autoscaling command to latest version
  + feature:elbv2: Update elbv2 command to latest version
- From 1.11.9
  + feature:ecs: Update ecs command to latest version
  + feature:sms: Update sms command to latest version
- From 1.11.8
  + feature:waf: Update waf command to latest version
  + feature:s3: Port mv to s3transfer.
  + feature:budgets: Update budgets command to latest version
- From 1.11.7
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:iot: Update iot command to latest version
  + feature:config: Update config command to latest version
  + feature:kinesisanalytics: Update kinesisanalytics command to latest version
  + feature:rds: Update rds command to latest version
- From 1.11.6
  + feature:route53: Update route53 command to latest version
  + feature:--region: Add support for us-east-2
- From 1.11.5
  + bugfix:s3 sync --delete: Fix regression where --delete would not delete
    local files
- From 1.11.4
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:s3: Integrate sync command with s3transfer
  + feature:acm: Update acm command to latest version
  + feature:s3: Output progress even when discovering new files to transfer
- From 1.11.3
  + bugfix:Pagination: Fix validation error when providing --no-paginate
    with normalized paging argument.
  + feature:apigateway: Update apigateway command to latest version
  + feature:cloudfront: Update cloudfront command to latest version
  + feature:gamelift: Update gamelift command to latest version
  + feature:rds: Update rds command to latest version
  + feature:codedeploy: Update codedeploy command to latest version
  + feature:sns: Update sns command to latest version
  + feature:kms: Update kms command to latest version
  + feature:elasticache: Update elasticache command to latest version
  + feature:ecr: Update ecr command to latest version
- From 1.11.2
  + feature:s3: Update s3 command to latest version
  + feature:waf: Update waf command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:kms: Update kms command to latest version
  + feature:opsworks: Update opsworks command to latest version
  + bugfix:s3: Refactor rb into its own command. In addition, validate that
    no key is supplied regardless of whether or not the force argument is
    supplied.
  + bugfix:route53domains: Rename --end to --end-time to fix a bug relating
    to argparse prefix expansion. Alias --start to --start-time to maintain
    a consistent interface while keeping the old parameter.
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.11.1
  + bugfix:s3: Fix regression when downloading empty files.
- From 1.11.0
  + feature:snowball: Update snowball command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:s3: Port cp and rm to s3transfer. Improve progress for those
    commands, showing byte progress.
- Upstream version jump from 1.10.67 to 1.11.0
* Thu Nov 17 2016 dmueller@suse.com
- update to 1.10.67
  * more than 500 changes, have a look at
  https://github.com/aws/aws-cli/compare/1.10.38...1.10.67
* Tue Jun 21 2016 rjschwei@suse.com
- Update to version 1.10.38 (bsc#985858)
  + forward port hide_py_pckgmgmt.patch
  + feature:acm: Update acm command to latest version
  + feature:ses: Update ses command to latest version
  + feature:rds: Update rds command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.37
  + feature:s3: Update s3 command to latest version
- From 1.10.36
  + feature:dynamodbstreams: Update dynamodbstreams command to latest version
  + feature:machinelearning: Update machinelearning command to latest version
  + feature:iot: Update iot command to latest version
  + bugfix:Pagination: Fix regression with --no-paginate introduced in
    [#1958] (fixes #1993)
- From 1.10.35
  + feature:ec2: Update ec2 command to latest version
  + feature:application-autoscaling: Update application-autoscaling
    command to latest version
- From 1.10.34
  + feature:elasticache: Update elasticache command to latest version
- From 1.10.33
  + feature:rds: Update rds command to latest version
  + feature:ec2: Update ec2 command to latest version
  + bugfix:help: Write help content to stdout if less is not installed.
    Fixes #1957
- From 1.10.32
  + feature:firehose: Update firehose command to latest version
  + bugfix:Table: Fix rendering of tables with double-width characters.
  + feature:ec2: Update ec2 command to latest version
  + feature:ecs: Update ecs command to latest version
- From 1.10.31
  + feature:application-autoscaling: Adds support for Application Auto Scaling.
    Application Auto Scaling is a general purpose Auto Scaling service for
    supported elastic AWS resources. With Application Auto Scaling, you can
    automatically scale your AWS resources, with an experience similar to
    that of Auto Scaling.
- From 1.10.29
  + feature:dynamodb: Update dynamodb command to latest version
  + bugfix:Shorthand: Remove back-compat shorthand features from new services.
  + bugfix:Paginator: Print a better error when pagination params are
    supplied along with no-paginate.
  + bugfix:ec2: Sets MaxResults to default value of 1000.
  + feature:workspaces: Update workspaces command to latest version
  + feature:discovery: Update discovery command to latest version
- From 1.10.28
  + feature:ec2: Update ec2 command to latest version
  + feature:ssm: Update ssm command to latest version
  + feature:discovery: Update discovery command to latest version
  + feature:cloudformation: Update cloudformation command to latest version
- From 1.10.27
  + feature:storagegateway: Update storagegateway command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:emr: Update emr command to latest version
  + feature:sqs: Update sqs command to latest version
  + feature:iam: Update iam command to latest version
- From 1.10.26
  + feature:kms: Update kms command to latest version
  + feature:sts: Update sts command to latest version
  + feature:apigateway: Update apigateway command to latest version
  + feature:ecs: Update ecs command to latest version
  + feature:s3: Update s3 command to latest version
  + feature:cloudtrail: Update cloudtrail command to latest version
- From 1.10.25
  + feature:inspector: Update inspector command to latest version
  + feature:codepipeline: Update codepipeline command to latest version
  + bugfix:Configure: Fix issue causing prompts not to display on mintty.
    Fixes #1925
  + feature:elasticbeanstalk: Update elasticbeanstalk command to latest version
- From 1.10.24
  + feature:route53domains: Update route53domains command to latest version
  + feature:opsworks: Update opsworks command to latest version
- From 1.10.23
  + feature:ecr: Update ecr command to latest version
  + feature:acm: Update acm command to latest version
  + feature:ec2: Update ec2 command to latest version
  + feature:sts: Update sts command to latest version
  + feature:cognito-idp: Update cognito-idp command to latest version
- From 1.10.22
  + feature:emr: Add support for smart targeted resize feature
  + feature:iot: Add SQL RulesEngine version support
  + feature:acm: Add tagging support for ACM
- From 1.10.21
  + feature:aws ec2: Add support for two new EBS volume types
  + feature:aws cognito-idp: Add support for new service, aws cognito-idp
  + feature:aws kinesis: Update aws kinesis command to latest version
  + feature:aws elasticbeanstalk: Add support for automatic platform
    version upgrades with managed updates
  + feature:aws devicefarm: Update aws devicefarm command to latest version
  + feature:aws s3: Add support for Amazon S3 Transfer Acceleration
  + feature:aws firehose: Update firehose command to latest version
- From 1.10.20
  + feature:iot: Add commands for managing CA certificates.
  + bugfix:ec2 wait: Fix issues with waiting on incorrect error code.
  + bugfix:s3: Fix issue where multipart uploads were not being properly
    aborted after Cntrl-C. (issue 1905)
* Mon Apr 11 2016 rjschwei@suse.com
- Update to version 1.10.19 (bsc#974993)
  + forward port hide_py_pckgmgmt.patch
  + feature:lambda: Added support for setting the function runtime as
    nodejs4.3, as well as updating function configuration to set the runtime.
  + feature:ds: Added support for Directory Service Conditional Forwarder APIs.
  + feature:elasticbeanstalk: Adds support for three additional elements in
    AWS Elasticbeanstalk's DescribeInstancesHealthResponse: Deployment,
    AvailabilityZone, and InstanceType. Additionally adds support for
    increased EnvironmentName length from 23 to 40.
  + bugfix:Paginator: Allow non-specified input tokens in old starting token
    format.
- From 1.10.18
  + feature:apigateway: Added support for API Import
  + feature:route53: Added support for metric-based health checks and
    regional health checks.
  + feature:sts: Added support for GetCallerIdentity, which returns details
    about the credentials used to make the API call. The details include name
    and account, as well as the type of entity making the call, such as an
    IAM user vs. federated user.
  + feature:s3api: Added support for VersionId in PutObjectAcl (issue 856)
  + bugfix:s3api: Add validation to enforce S3 metadata only contains ASCII.
    (issue 861)
  + bugfix:Exceptions: Consistently parse errors with no body (issue 859)
  + bugfix:Config: Handle case where S3 config key is not a dict (issue 858)
- From 1.10.17
  + feature:acm: Update command to latest version
  + feature:cloudformation: Update command to latest version
  + feature:codedeploy: Update command to latest version
  + feature:dms: Update command to latest version
  + feature:elasticache: Update command to latest version
  + feature:elasticbeanstalk: Update command to latest version
  + feature:redshift: Update command to latest version
  + feature:waf: Update command to latest version
  + bugfix:Pagintor: Fix regression when providing a starting token for a
    paginated command (botocore issue 849)
  + bugfix:Response Parsing: Handle case when generic HTML error response
    is received (botocore issue 850)
  + bugfix:Request serialization: Handle case when non str values are
    provided for header values when using signature version 4
    (botocore issue 852)
  + bugfix:Retry: Retry HTTP responses with status code 502
    (botocore issue 853)
  + bugfix:ec2 run-instances: Fix issue when providing
  - -secondary-private-ip-address-count argument (issue 1874)
- From 1.10.16
  + feature:elasticache: Update command to latest version
  + feature:rds: Update command to latest version
  + feature:storagegateway: Update command to latest version
- from 1.10.15
  + feature:aws devicefarm: Add support to pay a flat monthly fee for
    unlimited testing of your Android and iOS apps with AWS Device Farm
    device slots
  + feature:aws rds: Add support for customizing the order in which Aurora
    Replicas are promoted to primary instance during a failover
- From 1.10.14
  + feature:meteringmarketplace: The AWS Marketplace Metering Service
    enables sellers to price their products along new pricing dimensions.
    After a integrating their product with the AWS Marketplace Metering
    Service, that product will emit an hourly record capturing the usage of
    any single pricing dimension. Buyers can easily subscribe to software
    priced by this new dimension on the AWS Marketplace website and only
    pay for what they use.
  + feature:s3api: Added support for delete marker and abort multipart
    upload lifecycle configuration.
  + feature:iot: Added support for Amazon Elasticsearch Service and
    Amazon Cloudwatch actions for the AWS IoT rules engine.
  + feature:cloudhsm: Added support for tagging resources.
- From 1.10.13
  + feature:DMS: Added support for AWS Database Migration Service
  + feature:SES: Added support for white-labeling
  + feature:CodeDeploy: Added support for BatchGetDeploymentGroups
  + feature:endpoints: Updated endpoints to latest version
  + bugfix:groff: Fix groff command which was causing issues on some systems
  + bugfix:shorthand: Allow # in keys in the shorthand parser
- From 1.10.12
  + feature:gamelift: Update command to latest version
  + feature:iam: Update command to latest version
  + feature:redshift: Update command to latest version
- From 1.10.11
  + feature:acm: Update acm command to latest version
  + feature:codecommit: Update codecommit model to latest version
  + feature:config: Update config command to latest version
  + feature:devicefarm: Update devicefarm command to latest version
  + feature:directconnect: Update directconnect command to latest version
  + feature:events: Update events command to latest version
  + bugfix:aws s3 cp: Add error checking when attempting recursive copies
    or syncs with streaming output (issue 1771)
- From 1.10.10
  + feature:aws ec2: Add support for VPC peering with security groups.
  + feature:aws ds: Add support for SNS event notifications.
  + bugfix:aws s3 rb: Fix issue where bucket is still attempted to be
    removed when the preceding delete requests failed. (issue 1827)
  + bugfix:aws storagegateway: Fix issue in aliasing required args.
    (issue 1790)
- From 1.10.9
  + bugfix:aws s3: Avoid MD5 checksumming if unavailable. (issue 1812)
  + feature:aws dynamodb: Add support for describing limits.
  + feature:aws apigateway: Add support for testing invoke authorizers
    and flushing stage authorizers cache.
  + feature:aws cloudsearchdomain: Add support for new stat fields.
- From 1.10.8
  + bugfix:aws s3: Disable use of MD5 when SHA256 checksum is already
    calculated for the body (botocore issue 804)
  + bugfix:FIPS: Handle case where MD5 cipher is not available on FIPS
    compliant systems (botocore issue 807)
  + feature:aws cloudformation: Update AWS CloudFormation command to the
    latest version
  + feature:aws logs: Update Amazon CloudWatch Logs command to the latest
    version
  + feature:aws ses: Update Amazon SES to the latest version
  + feature:aws autoscaling: Update Auto Scaling to the latest version
- From 1.10.7
  + bug:aws configure set: Fix issue when adding entries to an empty
    profile section (issue 1806)
  + feature:aws route53: Add suport for SNI health checks
- From 1.10.6
  + feature:aws storagegateway: Added support for user-supplied barcodes.
  + feature:aws codedeploy: Added support for setting up triggers for a
    deployment group.
  + bugfix:aws emr: Fix missing dns name issue with private clusters.
    (issue 1749)
  + bugfix:aws emr: Fix issue where impala args were not joined with commas.
    (issue 1802)
- From 1.10.5
  + feature:aws rds: Added support for Cross-account Encrypted (KMS) snapshot
    sharing.
  + feature:aws emr: Added support for adding EBS storage to EMR instances.
  + bugfix:pagination: Fixed a bug that was causing non-string service
    tokens to fail on serialization
- From 1.10.4
  + feature:aws lambda: Add support for accessing resources in your VPC.
  + feature:aws apigateway: Add support for custom request authorizers.
- From 1.10.3
  + feature:aws cloudfront: Add support for new ACMCertificateARN parameter
  + feature:aws marketplacecommerceanalytics generate-data-set: Add support
    for --customer-defined-values parameter
- From 1.10.2
  + feature:aws gamelift: Add support for AWS GameLift
  + bugfix:Assume Role: Fix issue where temporary credentials from assuming
    a role were not being properly cached (issue 1684)
- From 1.10.1
  + feature:aws waf: Add support for blocking, allowing, or monitoring
    (count) requests based on the content in HTTP request bodies.
  + bugfix:aws ssm: Remove constraint on Amazon EC2 instance id's.
    (issue 1729)
- From 1.10.0
  + feature:aws acm: adds support for AWS Certificate Manager
  + feature:aws cloudfront: adds support for AWS Certificate Manager
    certificates
  + feature:aws cloudfront create-distribution: Adds support for
  - -origin-domain-name and --default-root-object
  + feature:aws cloudfront update-distribution: Adds support for
  - -default-root-object
  + feature:aws iot: adds support for topic rules
  + feature:aws cloudformation: adds suport for ContinueUpdateRollback
- From 1.9.21
  + feature:aws sts: now returns RegionDisabledException instead of
    AccessDenied when a user sends an API request to an STS regional
    endpoint that is not activated for that AWS account. This enables
    customers to more easily decide how to respond, such as by trying to
    call a different region instead of simply failing the call.
  + feature:aws opsworks: adds support for new enums.
  + feature:aws devicefarm: adds support running Appium tests written in
    Python against your native, hybrid and browser-based apps on AWS Device
    Farm.
- From 1.9.20
  + bugfix:aws cloudfront: Fix regression in waiters.
- From 1.9.19
  + feature:aws events: Initial support for Amazon CloudWatch Events.
    CloudWatch Events allows you to track changes to your AWS resources
    with less overhead and greater efficiency.
  + feature:aws ec2: Adds support for purchasing reserved capacity for
    specific blocks of time on a one-time of recurring basis.
  + feature:aws cloudfront: Adds support for HTTPS-only connections, and
    control of edge-to-origin request headers.
  + bugfix:aws s3: Gracefully handle encoding errors when printing S3
    keys (issue 1719)
- From 1.9.18
  + feature:aws ec2: Enables support for DNS resolution of public hostnames
    to private IP addresses when queried over ClassicLink. Additionally, you
    can now access private hosted zones associated with your VPC from a
    linked EC2-Classic instance. ClassicLink DNS support makes it easier
    for EC2-Classic instances to communicate with VPC resources using public
    DNS hostnames.
  + feature:aws ec2: Add support for the new 63-bit EC2 Instance and
    Reservation IDs.
- From 1.9.17
  + bugfix:aws ssm: Documentation update.
- From 1.9.16
  + feature:aws ec2: Add new EC2 instance type: t2.nano
  + feature:aws datapipeline list-runs: Add support for output format
- From 1.9.15
  + feature:aws ecr: Add aws ecr commands
  + feature:aws emr: Update aws emr create-cluster to accept Amazon EC2
    security group
  + feature:aws ecs: Update ecs command to include a new deployment option
- From 1.9.14
  + feature:aws rds: Adds Enhanced Monitoring support so that you can
    monitor operating system metrics for your RDS DB instances
  + feature:aws configservice: Support for IAM resource types
  + feature:aws cloudtrail: Adds isMultiRegion to some of the commands
  + feature:aws cloudfront: Adds support for gzip
  + feature:aws ec2: Adds new commands for VPC Managed NAT
- From 1.9.13
  + feature:aws ec2 copy-image: Adds two optional parameters to support
    launching EC2 instances with EBS encrypted boot volumes.
  + bugfix:aws: Fix regression when using AWS_DATA_PATH environment
    variable (issue 736)
* Thu Dec 10 2015 rjschwei@suse.com
- Update to version 1.9.12 (bsc#958686)
  + feature:aws configure add-model: Added command for updating commands
    in the CLI and clients in boto3. (issue 1664)
  + feature:aws cloudfront create-invalidation: Add a new --paths option.
    (issue 1662)
  + feature:aws cloudfront sign: Add a new command to create a signed url.
    (issue 1668)
  + feature:aws autoscaling: Added support for protecting instances from
    scale-in events.
  + feature:aws rds: Added support for Aurora encryption at rest.
- From version 1.9.11
  + feature:aws rds: Added support for specifying port number.
  + feature:aws ds: Added support for Microsoft ActiveDirctory.
  + feature:aws route53: Added support for TrafficFlow, a new management
    and modeling layer for Route53.
  + feature:Timeouts: Added additonal options for configuring socket timeouts.
- From version 1.9.10
  + feature:aws config: Added support for dedicated hosts.
  + feature:aws s3: Added support for custom metadata in cp, mv, and sync.
- From version 1.9.9
  + feature:aws s3api: Added support for the aws-exec-read canned ACL on
    objects.
  + feature:aws elasticbeanstalk: Added support for composable web applications.
  + feature:aws ec2: Added support for EC2 dedicated hosts.
  + feature:aws ecs: Added support for task stopped reasons and task start
    and stop times.
- From version 1.9.8
  + feature:Read Timeouts: Add --cli-read-timeout to specify the number of
    seconds until a read times out.
  + bugfix:aws s3: Fix regression when downloading a restored Glacier object
    (issue 1650 <https://github.com/aws/aws-cli/pull/1650>__)
  + bugfix:aws s3: Fix issue when encountering "out of disk space" errors as
    well as permissions errors when downloading large files (issue 1645,
    issue 1442)
  + bugfix:aws opsworks register: Support --no-verify-ssl argument for the
    aws opsworks register command (issue 1632)
  + feature:s3: Add support for Server-Side Encryption with KMS and
    Server-Side Encryption with Customer-Provided Keys. (issue 1623)
- From version 1.9.7
  + feature:aws rds: Cross account snapshot sharing and Modify DB Instance
    Visibility features
  + bugfix:memory management: Resolve a potential memory leak when creating
    lots of clients on Python 2.6 and Linux 2.6
  + bugfix:presign url: Now generate_presigned_url() works correctly with
    different expiry time
- From version 1.9.6
  + bugfix:shorthand: Allow . as a valid key character. (issue 1628)
  + feature:aws apigateway: Support for stage variables to configure
    the different deployment stages
- From version 1.9.5
  + bugfix:aws help: Gracefully handle Ctrl-C interrupts. (issue 1619)
  + bugfix:aws datapipeline create-default-roles: Fix issue with error
    handling. (issue 1618)
  + bugfix:aws s3: Skip glacier objects when downloading from S3. (issue 1581)
  + feature:aws s3api: Auto-populate --copy-source-sse-customer-key-md5
    (botocore issue 709)
- From version 1.9.4
  + feature:aws datapipeline create-default-roles: Creates default IAM
    roles for creating EMR clusters. (issue 1616)
  + feature:aws devicefarm: Add commands for updating and deleting projects,
    device pools, uploads, and runs.
- From version 1.9.3
  + feature:aws iam: Add support for resource-level policy simulation
- From version 1.9.2
  + bugfix:aws s3: Fix some local path validation issues (issue 1575)
  + bugfix:aws storagegateway: Fix --tape-ar-ns, --volume-ar-ns, and
  - -vtl-device-ar-ns to --tape-arns, --volume-arns, and --vtl-device-arns,
    respectively. The old arguments are still supported for backwards
    compatibility, but are no longer documented. (issue 1599)
  + bugfix:aws configservice subscribe: Fix an issue when creating a new
    S3 bucket (issue 1593)
  + bugfix:aws apigateway put-integration: Fix issue with --uri and
  - -integration-http-method parameters (issue 1605)
- From version 1.9.1
  + feature:aws ssm: Add support for Amazon EC2 Run Command
  + feature:aws apigateway: Add support for Amazon API Gateway
- From version 1.9.0
  + feature:aws iam: Add policy simulator support
  + feature:aws autoscaling: Add support for launch configurations
    that include encrypted Amazon Elastic Block Store (EBS) volumes
  + feature:configure: Add support for ca_bundle config variable
  + feature:Assume Role: Add role_session_name config variable to control
    the RoleSessionName when assuming roles (issue 1389)
  + bug:Argument Parsing: Handle case when empty list parameter was
    specified with no value (issue 838)
- From version 1.8.13
  + feature:aws deploy: Compress zip files when using aws deploy push
    (issue 1534 <https://github.com/aws/aws-cli/pull/1534>--)
  + bugfix:Shorthand Parser: Fix issue when display error message for
    multiline shorthand syntax values (issue 1543)
  + bugfix:aws route53: Automatically retry Throttling and
    PriorRequestNotComplete errors (botocore issue 682)
  + feature:aws s3/s3api: Add support for changing the bucket addressing
    style (botocore issue 673)
  + bugfix:aws s3api: Add missing --server-side-encryption option to
    upload-part command
  + feature:aws kms: Add ability to delete customer master keys (CMKs)
* Sat Oct 10 2015 rjschwei@suse.com
- Update to version 1.8.12 (bsc#949877)
  + feature:aws iot: Add support for AWS IoT
  + feature:aws iot-data: Add support for AWS IoT Data Plane
  + feature:aws lambda: Add support for aliasing and function versioning
  + feature:aws ecs: Update commands
  + feature:aws marketplacecommerceanalytics: Add support for AWS
    Marketplace Commerce Analytics
  + feature:aws firehose: Add support for Amazon Kinesis Firehose
  + feature:aws inspector: Add support for Amazon Inspector
  + feature:aws kinesis: Add support for updating stream retention periods
  + feature:aws configservice: Add support for config rules
  + feature:aws waf: Add support for AWS WAF
  + feature:aws ec2: Add support for spot blocks
  + feature:aws cloudfront: Add support for adding Web ACLs to CloudFront
    distributions
  + feature:aws es: Adds support for the new Amazon Elasticsearch
  + feature:aws cloudtrail: Adds support for log file integrity validation,
    log encryption with AWS KMS-Managed Keys (SSE-KMS), and trail tagging.
  + feature:aws rds create-db-instance: --db-instance-class has a new value
    as db.t2.large
  + feature:aws workspaces: Adds support for volume encryption in Amazon
    WorkSpaces.
  + feature:aws ses: Adds 17 new operations for accepting incoming emails.
  + feature:aws cloudformation describe-account-limits: This is a new API.
  + feature:aws ec2 modify-spot-fleet-request: This is a new API.
  + bugfix:aws elasticbeanstalk: Documentation update.
  + feature:aws cognito-sync: Update API to latest version
  + feature:aws cognito-identity: Update API to latest version
  + bugfix:Assume Role Provider: Fix issue where profile does not exist
    errors were not being propogated back to the user (issue 1515)
  + bugfix:Shorthand Syntax: Fix parser regression when a key name has an
    underscore character (issue 1510)
  + feature:aws s3: Add support for STANDARD_IA storage class to the aws s3
    commands (issue 1511)
  + feature:aws logs: Add support for create-export-task, cancel-export-task,
    and describe-export-tasks.
  + bugfix:Output: Only omit printing response to stdout if the response is
    an empty dictionary (issue 1496)
  + feature:aws s3/s3api: Update Amazon S3 commands to the latest version
  + feature:aws ec2 request-spot-fleet: Add new Diversified bidding strategy
    parameter
  + feature:aws ec2 describe-snapshots: Add new dataEncryptionKeyId and
    StateMessage parameters
  + feature:aws efs describe-mount-targets: Add new optional MountTargetId
    parameter
  + feature:aws route53: Add calculated health checks and latency health checks
  + bugfix:StreamingBody: File-like object for HTTP response can now be
    properly closed
  + feature:aws iam: Add two new APIs that enable programmatic access to
    the IAM policy simulator
  + feature:aws importexport: Documentation update
  + bugfix:aws machinelearning: Remove a constraint
  + feature:aws kinesis get-records: Add a timestamp field to all Records
  + bugfix:aws cloudfront: Add paginators and waiters
  + feature:aws storagegateway: Add support for resource tagging.
  + feature:aws ec2 request-spot-fleet: Add support for new request config
    parameters
  + bugfix:Shorthand Parser: Fix regression where '-' character was not
    accepted as a key name in a shorthand value (issue 1470)
  + bugfix:Shorthand Parser: Fix regression where spaces in unquoted
    values were not being accepted (issue 1471)
  + feature:aws configservice: Add support for listing discovered resources
  + bugfix:aws emr create-default-roles: Fix the issue where the command
    would fail to honor an existing AWS_CA_BUNDLE environment setting and
    end up with "SSLError: object has no attribute" (issue 1468)
  + feature:Shorthand Syntax: Add support for nested hashes when using
    shorthand syntax (issue 1444)
  + feature:aws codepipeline: Add support for specification of an encryption
    key to use with the artifact bucket, when creating and updating a pipeline
  + feature:aws s3: Add support for event notification filters
  + bugfix:aws iam create-virtual-mfa-device: Fix issue when an error
    response is received from the create-virtual-mfa-device command (issue 1447)
  + feature:aws elasticbeanstalk: Add support for enhanced health reporting
    in aws elasticbeanstalk commands
  + feature:Shared Credentials File: Add support for changing the shared
    credentials file from the default location of ~/.aws/credentials
    by setting the AWS_SHARED_CREDENTIALS_FILE environment variable
    (botocore issue 623)
  + feature:Waiters: Add aws iam wait instance-profile-exists and aws
    iam wait user-exists commands (botocore issue)
  + feature:aws swf: Add support for Added support for invoking AWS
    Lambda tasks from an Amazon SWF workflow.
  + feature:aws devicefarm: Add support for testing iOS applications
    with AWS Device Farm.
* Fri Jul 31 2015 ms@suse.com
- update to version 1.7.42 (fate#318337)
  - feature:``aws opsworks``: Add support for managing Amazon ECS
  - feature:``aws rds``: Add support for Amazon Aurora
  - feature:``aws s3api``: Add support for more types of event notifications.
  - feature:``aws s3api``: Add support for GET/HEAD storage class response
  - feature:``aws logs``: Add destination API support.
  - feature:``aws glacier``: Add support for Vault Lock.
  - feature:``aws emr``: Add support for release-based clusters.
  - feature:``aws ecs``: Update API
* Mon Jun  1 2015 rjschwei@suse.com
- update to version 1.7.31 (bnc#905354)
  - Follow up to previous update to address API compatibility issues
    with botocore
  - Improved lambda support
  - Add support for uploading code using Amazon S3
  - Preview services are now documented
    and will also show up in the list of available services
  + From 1.7.30
  - Add support for ``aws efs``
  - Add paginators and waiters for ``aws ecs``
* Tue May 26 2015 rjschwei@suse.com
- update to version 1.7.29 (bnc#905354)
  + Follow up to previous update to address compatibility with latest
    amazon-ecs-agent
  + From 1.7.28
  - feature:aws ec2: Add support for Spot Fleet.
  - feature:aws opsworks: Add support for custom AutoScaling.
  - feature:aws elasticbeanstalk: Update model to latest version.
  + From 1.7.27
  - feature:aws ds: Add support for AWS Directory Service.
  - feature:aws ec2: Add support for VPC endpoints for Amazon S3.
  - feature:aws ec2: Add support for EIP Migration.
  - feature:aws logs: Add support for filtering log events.
  + From 1.7.26
  - feature:aws glacier: Add support for vault policies.
  - bugfix:aws iam create-open-id-connect-provider: Fix issue where the
  - -url parameter would try to retrieve the contents from the url instead
    of use the url as its value. (issue 1317)
  - bugfix:aws workspaces: Fix issue where throttling errors were not
    being retried (botocore issue 529)
  + From 1.7.25
  - feature:aws dynamodb query: Add support for KeyConditonExpression.
  + From 1.7.24
  - feature:aws help topics: Add support for listing available help topics.
  - feature:aws help config-vars: Add help topic for configuration variables.
  - feature:aws help return-codes: Add help topic for return codes.
  - feature:aws help s3-config: Add help topic for configuration of s3
    commands.
  - bugfix:aws lambda create-function/update-function-code: Improve
    error message when invalid --zip-file values are provided (issue 1296)
  - feature:aws ec2: Add support for new VM Import APIs, including
    import-image. The new APIs provide support for importing multi-volume
    VMs to Amazon EC2 and other enhancements.
  - feature:aws iam: Update AWS IAM command to latest version
  + From 1.7.23
  - feature:aws cognito-sync: Add support for Amazon Cognito Events.
  - bugfix:Parsing: Treat empty XML nodes in a response as an empty
    string instead of None if the underlying structure member is a string.
    This fixes the broken password-data-available Amazon EC2 waiter. Note:
    this changes the output of the CLI and may affect filtering with the
  - -query parameter. (issue 1252, botocore issue 506)
  + From 1.7.22
  - bugfix:aws ecs: Minor documentation fixes.
  + From 1.7.21
  - feature:aws workspaces: Add support for Amazon WorkSpaces.
  - feature:aws machinelearning: Add support for Amazon Machine Learning.
  - feature:aws s3api: Add support for specifying Lambda bucket
    notifications without needing to specify an invocation role.
  - feature:aws lambda: Update to latest api.
  - feature:aws ecs: Add support for Amazon ECS Service scheduler.
  + From 1.7.20
  - feature:aws datapipeline: Add support for deactivating pipelines.
  - feature:aws elasticbeanstalk: Add support for cancelling in-progress
    environment updates or application version deployment.
  + From 1.7.19
  - feature:aws codedeploy: Add register, deregister, install, and
    uninstall commands and update to the latest AWS CodeDeploy API.
  - feature:aws rds: Add support for describe-certificates.
  - feature:aws elastictranscoder: Add support for PlayReady DRM.
  - feature:aws ec2: Add support for D2 instances.
  + From 1.7.18
  - bugfix:Pagination: Fix issue where disabling pagination did not work
    when shadowing arguments. Affects commands such as aws route53
    list-resource-record-sets.
  - feature:aws elastictranscoder: Add support for job timing and
    input/output metadata
  - feature:aws iam: Add NamedPolicy to GetAccountAuthorization details
  - feature:aws opsworks: Allow for BlockDeviceMapping on EC2 instances
    launched through OpsWorks
  + From 1.7.17
  - feature:aws emr: Adds support for Amazon S3 client-side encryption
    in Amazon EMR and setting configuration values for several variables
    in the create-cluster and ssh commands. Also, the create-default-roles
    command will now auto-populate the Service Role and Instance Profile
    variables in the configuration file with the default roles after they
    are created.
  + From 1.7.16
  - feature:aws ec2 wait image-available: Add support for polling until
    an EC2 image is available (issue 1105)
  - feature:aws ec2 wait: Add support for additional EC2 waiters including
    instance-status-ok, password-data-available,
    spot-instance-request-fulfilled, and system-status-ok
  - feature:aws s3api: Add support for Amazon S3 cross region replication
  - feature:aws s3api: Add support for Amazon S3 requester pays (issue 797)
  - bugfix:Tab Completion: Fix issue where tab completion could not handle
    an LC_CTYPE of UTF-8 (issue 1233)
  - bugfix:aws s3api put-bucket-notification: Fix issue where an empty
    notification configuration could not be specified (botocore issue 495)
  - bugfix:aws cloudfront: Fix issue when calling cloudfront commands
    (issue 1234)
  - bugfix:aws ec2 copy-snapshot: Fix issue with the aws ec2 copy-snapshot
    command not correctly generating the presigned url argument
    (botocore issue 498)
  + From 1.7.15
  - feature:aws elastictranscoder: Add support for Applied Color
    SpaceConversion.
  - bugfix:aws --profile: Fix issue where explicitly specifying profile
    did not override credential environment variables. (botocore issue 486)
  - bugfix:aws datapipeline list-runs: Fix issue with --schedule-interval
    parameter. (issue 1225)
  - bugfix:aws configservice subscribe: Fix issue where users could not
    subscribe to a s3 bucket that they had no HeadBucket permissions to.
    (issue 1223)
  - bugfix:aws cloudtrail create-subscription: Fix issue where command
    would try to fetch the contents at a url using the contents of the
    custom policy as the url. (issue 1216)
  + From 1.7.14
  - feature:aws logs: Update aws logs command to the latest model.
  - feature:aws ec2: Add paginators for the describe-snapshots sub-command.
  - feature:aws cloudtrail: Add support for the new lookup-events
    sub-command.
  - bugfix:aws configure set: Fix issue when setting nested configuration
    values
  - feature:aws s3: Add support for --metadata-directive that allows
    metadata to be copied or replaced for single part copies. (issue 1188)
  + From 1.7.13
  - feature:aws cloudsearch: Update aws cloudsearch command to the latest
    model
  - feature:aws cognito-sync: Update aws cognito-sync command to allow
    customers to receive near-realtime updates as their data changes as
    well as exporting historical data. Customers configure an Amazon
    Kinesis stream to receive the data which can then be processed and
    exported to other data stores such as Amazon Redshift.
  - bugfix:aws opsworks: Fix issue with platform detection on linux
    systems with python3.3 and higher (issue 1199)
  - feature:Help Paging: Support paging through more when running help
    commands on windows (issue 1195)
  - bugfix:aws s3: Fix issue where read timeouts were not retried.
    (issue 1191)
  - feature:aws cloudtrail: Add support for regionalized policy templates
    for the create-subscription and update-subscription commands.
    (issue 1167)
  - bugfix:parsing: Fix issue where if there is a square bracket inside
    one of the values of a list, the end character would get removed.
    (issue 1183)
  + From 1.7.12
  - feature:aws datapipeline: Add support for tagging.
  - feature:aws route53: Add support for listing hosted zones by name
    and getting the hosted zone count.
  - bugfix:aws s3 sync: Remove --recursive parameter. The sync command is
    always a recursive operation meaning the inclusion or exclusion of
  - -recursive had no effect on the sync command. (issue 1171)
  - bugfix:aws s3: Fix issue where --endpoint-url was being ignored
    (issue 1142)
  + From 1.7.11
  - bugfix:aws sts: Allow calling assume-role-with-saml without credentials.
  - bugfix:aws sts: Allow users to make regionalized STS calls by
    specifying the STS endpoint with --endpoint-url and the region with
  - -region. (botocore issue 464)
  + From 1.7.10
  - bugfix:aws sts: Fix regression where if a region was not activated
    for STS it would raise an error if call was made to that region.
  + From 1.7.9
  - feature:aws cloudfront: Update to latest API
  - feature:aws sts: Add support for STS regionalized calls
  - feature:aws ssm: Add support for Amazon Simple Systems Management
    Service (SSM)
  + From 1.7.8
  - bugfix:aws s3: Fix auth errors when uploading large files to the
    eu-central-1 and cn-north-1 regions (botocore issue 462)
  + From 1.7.7
  - bugfix:aws ec2 revoke-security-group-ingress: Fix parsing of a
  - -port value of ICMP echo request (issue 1075)
  - feature:aws iam: Add support for managed policies
  - feature:aws elasticache: Add support for tagging
  - feature:aws route53domains: Add support for tagging of domains
  + From 1.7.6
  - feature:aws dynamodb: Add support for index scan
  - bugfix:aws s3: Fix issue where literal value for --website-redirect
    was not being used. (issue 1137)
  - bugfix:aws sqs purge-queue: Fix issue with the processing of the
  - -queue-url parameter (issue 1126)
  - feature:aws s3: Add support for config variable for changing S3 runtime
    values (issue 1122)
  - bugfix:Proxies: Fix issue with SSL certificate validation when using
    proxies and python 2.7.9 (botocore issue 451)
  + From 1.7.5
  - bugfix:aws datapipeline list-runs: Fix issue where --status values
    where not being serialized correctly (issue 1110)
  - bugfix:Output Formatting: Handle broken pipe errors when piping the
    output to another program (issue 1113)
  - bugfix:HTTP Proxy: Fix issue where aws s3/s3api commands would hang
    when using an HTTP proxy (issue 1116)
  - feature:aws elasticache wait: Add waiters for the aws elasticache
    wait (botocore issue 443)
  - bugfix:Locale Settings: Fix issue when Mac OS X has an LC_CTYPE value
    of UTF-8 (issue 945)
  + From 1.7.4
  - feature:aws dynamodb: Add support for online indexing.
  - feature:aws importexport get-shipping-label: Add support for
    get-shipping-label.
  - feature:aws s3 ls: Add --human-readable and --summarize options
    (issue 1103)
  - bugfix:aws kinesis put-records: Fix issue with base64 encoding for
    blob types (botocore issue 413)
  + From 1.7.3
  - feature:aws emr: Add support for security groups.
  - feature:aws cognitio-identity: Enhance authentication flow by beingi
    able to save associations of IAM roles with identity pools.
  + From 1.7.2
  - feature:aws autoscaling: Add ClassicLink support.
  - bugfix:aws s3: Fix issue where mtime was set before file was finished
    downloading. (issue 1102)
* Sun Jan 18 2015 rschweikert@suse.com
- Update to version 1.7.1 (bnc#905354)
  + bugfix:``aws s3 cp``: Fix issue with parts of a file being
    downloaded more than once when streaming to stdout
    (`issue 1087 <https://github.com/aws/aws-cli/pull/1087>`__)
  + bugfix:``--no-sign-request``: Fix issue where requests were still trying to
    be signed even though user used the ``--no-sign-request`` flag.
    (`botocore issue 433 <https://github.com/boto/botocore/pull/433>`__)
  + bugfix:``aws cloudsearchdomain search``: Fix invalid signatures when
    using the ``aws cloudsearchdomain search`` command
    (`issue 976 <https://github.com/aws/aws-cli/issues/976>`__)
  + feature:``aws cloudhsm``: Add support for AWS CloudHSM.
  + feature:``aws ecs``: Add support for ``aws ecs``, the Amazon EC2
    Container Service (ECS)
  + feature:``aws rds``: Add Encryption at Rest and CloudHSM Support.
  + feature:``aws ec2``: Add Classic Link support
  + feature:``aws cloudsearch``: Update ``aws cloudsearch`` command
    to latest version
  + bugfix:``aws cloudfront wait``: Fix issue where wait commands did not
    stop waiting when a success state was reached.
    (`botocore issue 426 <https://github.com/boto/botocore/pull/426>`_)
  + bugfix:``aws ec2 run-instances``: Allow binary files to be passed to
    ``--user-data``
    (`botocore issue 416 <https://github.com/boto/botocore/pull/416>`_)
  + bugfix:``aws cloudsearchdomain suggest``: Add ``--suggest-query``
    option to fix the argument being shadowed by the top level
    ``--query`` option.
    (`issue 1068 <https://github.com/aws/aws-cli/pull/1068>`__)
  + bugfix:``aws emr``: Fix issue with endpoints for ``eu-central-1`` and
    ``cn-north-1``
    (`botocore issue 423 <https://github.com/boto/botocore/pull/423>`__)
  + bugfix:``aws s3``: Fix issue where empty XML nodes are now parsed
    as an empty string ``""`` instead of ``null``, which allows for
    round tripping ``aws s3 get/put-bucket-lifecycle``
    (`issue 1076 <https://github.com/aws/aws-cli/issues/1076>`__)
  + bugfix:AssumeRole: Fix issue with cache filenames when assuming a role
    on Windows
    (`issue 1063 <https://github.com/aws/aws-cli/issues/1063>`__)
  + bugfix:``aws s3 ls``: Fix issue when listing Amazon S3 objects containing
    non-ascii characters in eu-central-1
    (`issue 1046 <https://github.com/aws/aws-cli/issues/1046>`__)
  + feature:``aws storagegateway``: Update the ``aws storagegateway`` command
    to the latest version
  + feature:``aws emr``: Update the ``aws emr`` command to the latest
    version
  + bugfix:``aws emr create-cluster``: Fix script runnner jar to the current
    region location when ``--enable-debugging`` is specified in the
    ``aws emr create-cluster`` command
  + bugfix:``aws datapipeline get-pipeline-definition``: Rename operation
    parameter ``--version`` to ``--pipeline-version`` to avoid shadowing
    a built in parameter
    (`issue 1058 <https://github.com/aws/aws-cli/pull/1058>`__)
  + bugfix:pip installation: Fix issue where pip installations would cause
    an error due to the system's python configuration
    (`issue 1051 <https://github.com/aws/aws-cli/issues/1051>`__)
  + feature:``aws elastictranscoder``: Update the ``aws elastictranscoder``
    command to the latest version
  + bugfix:Non-ascii chars: Fix issue where escape sequences were being printed
    instead of the non-ascii chars
    (`issue 1048 <https://github.com/aws/aws-cli/issues/1048>`__)
  + bugfix:``aws iam create-virtual-mfa-device``:  Fix issue with ``--outfile``
    not supporting relative paths
    (`issue 1002 <https://github.com/aws/aws-cli/pull/1002>`__)
  + feature:``aws sqs``: Add support for Amazon Simple Queue Service purge queue
    which allows users to delete the messages in their queue.
  + feature:``aws opsworks``: Add AWS OpsWorks support for registering and
    assigning existing Amazon EC2 instances and on-premises servers.
  + feature:``aws opsworks register``: Registers an EC2 instance or machine with
    AWS OpsWorks. Registering a machine using this command will install the
    AWS OpsWorks agent on the target machine and register it with an existing
    OpsWorks stack.
  + bugfix:``aws s3``: Fix issue with expired signatures when retrying
    failed requests
    (`botocore issue 399 <https://github.com/boto/botocore/pull/399>`__)
  + bugfix:``aws cloudformation get-template``: Fix error message when
    template does not exist
    (`issue 1044 <https://github.com/aws/aws-cli/issues/1044>`__)
  + feature:``aws kinesis put-records``: Add support for PutRecord operation. It
    writes multiple data records from a producer into an Amazon Kinesis
    stream in a single call
  + feature:``aws iam get-account-authorization-details``: Add support for
    GetAccountAuthorizationDetails operation. It retrieves information about
    all IAM users, groups, and roles in your account, including their
    relationships to one another and their attached policies.
  + feature:``aws route53 update-hosted-zone-comment``: Add support for updating
    the comment of a hosted zone.
  + bugfix:Timestamp Arguments: Fix issue where certain timestamps were not
    being accepted as valid input
    (`botocore issue 389 <https://github.com/boto/botocore/pull/389>`__)
  + bugfix:``aws s3``: Skip files whose names cannot be properly decoded
    (`issue 1038 <https://github.com/aws/aws-cli/pull/1038>`__)
  + bugfix:``aws kinesis put-record``: Fix issue where ``--data`` argument
    was not being base64 encoded
    (`issue 1033 <https://github.com/aws/aws-cli/issues/1033>`__)
  + bugfix:``aws cloudwatch put-metric-data``: Fix issue where the
    values for ``--statistic-values`` were not being parsed properly
    (`issue 1036 <https://github.com/aws/aws-cli/issues/1036>`__)
  + feature:``aws datapipeline``: Add support for using AWS Data Pipeline
    templates to create pipelines and bind values to parameters in the pipeline
  + feature:``aws elastictranscoder``: Add support for encryption of files in
    Amazon S3
  + bugfix:``aws s3``: Fix issue where requests were not being
    resigned correctly when using Signature Version 4
    (`botocore issue 388 <https://github.com/boto/botocore/pull/388>`__)
  + bugfix:``aws s3``: Fix issue where KMS encrypted objects could not be
    downloaded
    (`issue 1026 <https://github.com/aws/aws-cli/pull/1026>`__)
  + bugfix:``aws s3``: Fix issue where datetime's were not being
    parsed properly when a profile was specified
    (`issue 1020 <https://github.com/aws/aws-cli/issues/1020>`__)
  + bugfix:Assume Role Credential Provider: Fix issue with parsing
    expiry time from assume role credential provider
    (`botocore issue 387 <https://github.com/boto/botocore/pull/387>`__)
  + feature:``aws redshift``: Add support for integration with KMS
  + bugfix:``aws cloudtrail create-subscription``: Set a bucket config
    location constraint on buckets created outside of us-east-1.
    (`issue 1013 <https://github.com/aws/aws-cli/pull/1013>`__)
  + bugfix:``aws deploy push``: Fix s3 multipart uploads
  + bugfix:``aws s3 ls``: Fix return codes for non existing objects
    (`issue 1008 <https://github.com/aws/aws-cli/pull/1008>`__)
  + bugfix:Retrying Signed Requests: Fix issue where requests using
    Signature Version 4 signed with temporary credentials were not
    being retried properly, resulting in auth errors
    (`botocore issue 379 <https://github.com/boto/botocore/pull/379>`__)
  + bugfix:``aws s3api get-bucket-location``: Fix issue where getting the
    bucket location for a bucket in eu-central-1 required specifying
    ``--region eu-central-1``
    (`botocore issue 380 <https://github.com/boto/botocore/pull/380>`__)
  + bugfix:Timestamp Input: Fix regression where timestamps without any timezone
    information were not being handled properly
    (`issue 982 <https://github.com/aws/aws-cli/issues/982>`__)
  + bugfix:Signature Version 4: You can enable Signature Version 4 for Amazon S3
    commands by running ``aws configure set default.s3.signature_version s3v4``
    (`issue 1006 <https://github.com/aws/aws-cli/issues/1006>`__,
    `botocore issue 382 <https://github.com/boto/botocore/pull/382>`__)
  + bugfix:``aws emr``: Fix issue where ``--ssh``, ``--get``, ``--put``
    would not work when the cluster was in a waiting state
    (`issue 1007 <https://github.com/aws/aws-cli/issues/1007>`__)
  + feature:Binary File Input: Add support for reading file contents as binary
    by prepending the filename with ``fileb://``
    (`issue 1010 <https://github.com/aws/aws-cli/pull/1010>`__)
  + bugfix:Streaming Output File: Fix issue when streaming a response to a file
    and an error response is returned
    (`issue 1012 <https://github.com/aws/aws-cli/pull/1012>`__)
  + bugfix:Binary Output: Fix regression where binary output was no longer
    being base64 encoded
    (`issue 1001 <https://github.com/aws/aws-cli/pull/1001>`__,
    `issue 970 <https://github.com/aws/aws-cli/pull/970>`__)
  + feature:``aws lambda``: Add support for Amazon Lambda
  + feature:``aws s3``: Add support for S3 notifications
  + bugfix:``aws configservice get-status``: Fix connecting to endpoint without
    using ssl.
    (`issue 998 <https://github.com/aws/aws-cli/pull/998>`__)
  + bugfix:``aws deploy push``: Fix some python compatibility issues
    (`issue 1000 <https://github.com/aws/aws-cli/pull/1000>`__)
  + feature:``aws deploy``: Adds support for AWS CodeDeploy
  + feature:``aws configservice``: Adds support for AWS Config
  + feature:``aws kms``: Adds support AWS Key Management Service
  + feature:``aws s3api``: Adds support for S3 server-side encryption using
    KMS
  + feature:``aws ec2``: Adds support for EBS encryption using KMS
  + feature:``aws cloudtrail``: Adds support for CloudWatch Logs delivery
  + feature:``aws cloudformation``: Adds support for template summary.
  + feature:AssumeRole Credential Provider: Add support for assuming a role
    by configuring a ``role_arn`` and a ``source_profile`` in the AWS
    config file
    (`issue 991 <https://github.com/aws/aws-cli/pull/991>`__,
    `issue 990 <https://github.com/aws/aws-cli/pull/990>`__)
  + feature:Waiters: Add a ``wait`` subcommand that allows for a command
    to block until an AWS resource reaches a given state
    (`issue 992 <https://github.com/aws/aws-cli/pull/992>`__,
    `issue 985 <https://github.com/aws/aws-cli/pull/985>`__)
  + bugfix:``aws s3``: Fix issue where request was not properly signed
    on retried requests for ``aws s3``
    (`issue 986 <https://github.com/aws/aws-cli/issues/986>`__,
    `botocore issue 375 <https://github.com/boto/botocore/pull/375>`__)
  + bugfix:``aws s3``: Fix issue where ``--exclude`` and ``--include`` were
    not being properly applied when a s3 prefix was provided.
    (`issue 993 <https://github.com/aws/aws-cli/pull/993>`__)
  + feature:``aws cloudfront``: Adds support for wildcard cookie names and
    options caching.
  + feature:``aws route53``: Add further support for private dns and sigv4.
  + feature:``aws cognito-sync``: Add support for push sync.
  + bugfix:Pagination: Only display ``--page-size`` when an operation can be
    paginated
    (`issue 956 <https://github.com/aws/aws-cli/pull/956>`__)
  + feature:``--generate-cli-skeleton``: Generates a JSON skeleton to fill out
    and be used as input to ``--cli-input-json``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``--cli-input-json``: Runs an operation using a global JSON file
    that supplies all of the operation's arguments. This JSON file can
    be generated by ``--generate-cli-skeleton``.
    (`issue 963 <https://github.com/aws/aws-cli/pull/963>`_)
  + feature:``aws s3/s3api``: Show hint about using the correct region when
    the corresponding error occurs
    (`issue 968 <https://github.com/aws/aws-cli/pull/968>`__)
* Thu Oct 23 2014 rschweikert@suse.com
- Update to version 1.5.3  (bnc#902598)
  + feature:aws ec2 describe-volumes: Add support for optional pagination.
  + feature:aws route53domains: Add support for auto-renew domains.
  + feature:aws cognito-identity: Add for Open-ID Connect.
  + feature:aws sts: Add support for Open-ID Connect
  + feature:aws iam: Add support for Open-ID Connect
  + bugfix:aws s3 sync: Fix issue when uploading with
  - -exact-timestamps (issue 964)
  + bugfix:Retry: Fix issue where certain error codes were not being
    retried (botocore issue 361)
  + bugfix:aws emr ssh: Fix issue when using waiter interface to wait on
    the cluster state (issue 954)
  + feature:aws cloudsearch: Add support for advance Japanese language
    processing.
  + feature:aws rds: Add support for gp2 which provides faster access than
    disk-based storage.
  + bugfix:aws s3 mv: Delete multi-part objects when transferring objects
    across regions using --source-region (issue 938)
  + bugfix:aws emr ssh: Fix issue with waiter configuration not being
    found (issue 937)
  + feature:aws dynamodb: Update aws dynamodb command to support storing
    and retrieving documents with full support for document models. New
    data types are fully compatible with the JSON standard and allow you
    to nest document elements within one another.
  + bugfix:aws configure: Fix bug where aws configure was not properly
    writing out to the shared credentials file
  + bugfix:S3 Response Parsing: Fix regression for parsing S3 responses
    containing a status code of 200 with an error response body (botocore
    issue 342)
  + bugfix:Shorthand Error Message: Ensure the error message for shorthand
    parsing always contains the CLI argument name (issue 935)
  + bugfix:Response Parsing: Fix response parsing so that leading and
    trailing spaces are preserved
  + feature:Shared Credentials File: The aws configure and aws configure set
    command now write out all credential variables to the shared
    credentials file ~/.aws/credentials (issue 847)
  + bugfix:aws s3: Write warnings and errors to standard error as opposed to
    standard output. (issue 919)
  + feature:aws s3: Add --only-show-errors option that displays errors and
    warnings but suppresses all other output.
  + feature:aws s3 cp: Added ability to upload local file streams from
    standard input to s3 and download s3 objects as local file streams to
    standard output. (issue 903)
  + feature:aws emr create-cluster: Add support for --emrfs.
  + feature:aws iam: Update aws iam command to latest version.
  + feature:aws cognito-sync: Update aws cognito-sync command to latest
    version.
  + feature:aws opsworks: Update aws opsworks command to latest version.
  + feature:aws elasticbeanstalk: Add support for bundling logs.
  + feature:aws kinesis: Add suport for tagging.
  + feature:Page Size: Add a --page-size option, that controls page size
    when perfoming an operation that uses pagination. (issue 889)
  + bugfix:aws s3: Added support for ignoring and warning about files that
    do not exist, user does not have read permissions, or are special
    files (i.e. sockets, FIFOs, character special devices, and block
    special devices) (issue 881)
  + feature:Parameter Shorthand: Added support for structure(list-scalar,
    scalar) parameter shorthand. (issue 882)
  + bugfix:aws s3: Fix bug when unknown options were passed to aws s3
    commands (issue 886)
  + bugfix:Endpoint URL: Provide a better error message when an invalid
  - -endpoint-url is provided (issue 899)
  + bugfix:aws s3: Fix issue when keys do not get properly url decoded when
    syncing from a bucket that requires pagination to a bucket that
    requires less pagination (issue 909)
  + feature:aws cloudsearchdomain: Added sigv4 support.
  + bugfix:Credentials: Raise an error if an incomplete profile is found
    (issue 690)
  + feature:Signing Requests: Add a --no-sign-request option that, when
    specified, will not sign any requests.
  + bugfix:aws s3: Added -source-region argument to allow transfer between
    non DNS compatible buckets that were located in different regions.
    (issue 872)
  + feature:aws elb: Add support for AWS Elastic Load Balancing tagging
  + feature: aws emr: Move emr out of preview mode.
  + bugfix: aws s3api: Fix serialization of several s3 api commands.
    (issue botocore 193)
  + bugfix: aws s3 sync: Fix issue for unnecessarily resyncing files on
    windows machines. (issue 843)
  + bugfix: aws s3 sync: Fix issue where keys were being decoded twice when
    syncing between buckets. (issue 862)
  + bugfix:aws ec2 describe-network-interface-attribute: Fix issue where
    the model for the aws ec2 describe-network-interface-attribute was
    incorrect (issue 558)
  + bugfix:aws s3: Add option to not follow symlinks via
  - -[no]-follow-symlinks. Note that the default behavior of following
    symlinks is left unchanged. (issue 854, issue 453, issue 781)
  + bugfix:aws route53 change-tags-for-resource: Fix serialization issue
    for aws route53 change-tags-for-resource (botocore issue 328)
  + bugfix:aws ec2 describe-network-interface-attribute: Update parameters
    to add the --attribute argument (botocore issue 327)
  + feature:aws autoscaling: Update command to the latest version
  + feature:aws elasticache: Update command to the latest version
  + feature:aws route53: Update command to the latest version
  + feature:aws route53domains: Add support for Amazon Route53 Domains
  + feature:aws elasticloadbalancing: Update to the latest service model.
  + bugfix:aws swf poll-for-decision-task: Fix issue where the default
    paginated response is missing output response keys (issue botocore 324)
  + bugfix:Connections: Fix issue where connections were hanging when
    network issues occurred issue botocore 325)
  + bugfix:aws s3/s3api: Fix issue where Deprecations were being written
    to stderr in Python 3.4.1 issue botocore 319)
  + feature:aws support: Update aws support command to the latest version
  + feature:aws iam: Update aws iam command to the latest version
  + feature:aws emr: Add --hive-site option to aws emr create-cluster and
    aws emr install-application commands
  + feature:aws s3 sync: Add an --exact-timestamps option to the aws s3
    sync command (issue 824)
  + bugfix:aws ec2 copy-snapshot: Fix bug when spaces in the description
    caused the copy request to fail (issue botocore 321)
  + feature:aws cwlogs: Add support for Amazon CloudWatch Logs
  + feature:aws cognito-sync: Add support for Amazon Cognito Service
  + feature:aws cognito-identity: Add support for Amazon Cognito Identity
    Service
  + feature:aws route53: Update aws route53 command to the latest version
  + feature:aws ec2: Update aws ec2 command to the latest version
  + bugfix:aws s3/s3api: Fix issue where --endpoint-url wasn't being used
    for aws s3/s3api commands (issue 549)
  + bugfix:aws s3 mv: Fix bug where using the aws s3 mv command to move a
    large file onto itself results in the file being deleted (issue 831)
  + bugfix:aws s3: Fix issue where parts in a multipart upload are stil being
    uploaded when a part has failed (issue 834)
  + bugfix:Windows: Fix issue where python.exe is on a path that contains
    spaces (issue 825)
  + feature:aws opsworks: Update the aws opsworks command to the latest version
  + bugfix:Shorthand JSON: Fix bug where shorthand lists with a single
    item (e.g. --arg Param=[item]) were not parsed correctly. (issue 830)
  + bugfix:Text output: Fix bug when rendering only scalars that are
    numbers in text output (issue 829)
  + bugfix:aws cloudsearchdomain: Fix bug where --endpoint-url is required
    even for help subcommands (issue 828)
  + feature:aws cloudsearchdomain: Add support for the Amazon CloudSearch
    Domain command.
  + feature:aws cloudfront: Update the Amazon CloudFront command to the
    latest version
  + feature:aws ses: Add support for delivery notifications
  + bugfix:Region Config: Fix issue for cn-north-1 region (issue botocore 314)
  + bugfix:Amazon EC2 Credential File: Fix regression for parsing EC2
    credential file (issue botocore 315)
  + bugfix:Signature Version 2: Fix timestamp format when calculating
    signature version 2 signatures (issue botocore 308)
  + feature:aws configure: Add support for setting nested attributes
    (issue 817)
  + bugfix:aws s3: Fix issue when uploading large files to newly created
    buckets in a non-standard region (issue 634)
  + feature:aws dynamodb: Add support for a local region for dynamodb
    (aws dynamodb --region local ...) (issue 608)
  + feature:aws elasticbeanstalk: Update aws elasticbeanstalk model to the
    latest version
  + feature:Documentation Examples: Add more documentatoin examples for
    many AWS CLI commands
  + feature:aws emr: Update model to the latest version
  + feature:aws elastictranscoder: Update model to the latest version
  + feature:aws s3api: Add support for server-side encryption with a
    customer-supplied encryption key.
  + feature:aws sns: Support for message attributes.
  + feature:aws redshift: Support for renaming clusters.
  + bugfix:aws s3: Fix bug related to retrying requests when 500 status
    codes are received (issue botocore 302)
  + bugfix:aws s3: Fix when when using S3 in the cn-north-1 region
    (issue botocore 301)
  + bugfix:aws kinesis: Fix pagination bug when using the get-records
    operation (issue botocore 304)
  + bugfix:Python 3.4.1: Add support for python 3.4.1 (issue 800)
  + feature:aws emr: Update preview commands for Amazon Elastic MapReduce
  + bugfix:aws s3: Add filename to error message when we're unable to stat
    local filename (issue 795)
  + bugfix:aws s3api get-bucket-policy: Fix response parsing for the aws
    s3api get-bucket-policy command (issue 678)
  + bugfix:Shared Credentials: Fix bug when specifying profiles that don't
    exist in the CLI config file (issue botocore 294)
  + bugfix:aws s3: Handle Amazon S3 error responses that have a 200 OK
    status code (issue botocore 298)
  + feature:aws sts: Update the aws sts command to the latest version
  + feature:aws cloudsearch: Update the aws cloudsearch command to the
    latest version
  + feature:Shorthand: Add support for surrounding list parameters with []
    chars in shorthand syntax (issue 788)
  + feature:Shared credential file: Add support for the ~/.aws/credentials file
  + feature:aws ec2: Add support for Amazon EBS encryption
  + bugfix:aws s3: Fix issue when --delete and --exclude filters are used
    together (issue 778)
  + feature:aws route53: Update aws route53 to the latest model
  + bugfix:aws emr: Fix issue with aws emr retry logic not being applied
    correctly (botocore issue 285)
  + feature:aws cloudtrail: Add support for eu-west-1, ap-southeast-2
  + bugfix:aws ec2: Fix issue when specifying user data from a file
    containing non-ascii characters (issue 765)
  + bugfix:aws cloudtrail: Fix a bug with python3 when creating a
    subscription (issue 773)
  + bugfix:Shorthand: Fix issue where certain shorthand parameters were
    not parsing to the correct types (issue 776)
  + bugfix:aws cloudformation: Fix issue with parameter casing for the
    NotificationARNs parameter (botocore issue 283)
  + feature:aws cloudformation: Add support for updated API
  + feature:aws sqs: Add support for message attributes
  + bugfix:aws s3api: Fix issue when setting metadata on an S3 object
    (issue 356)
  + feature:aws autoscaling: Add support for launching Dedicated Instances
    in Amazon Virtual Private Cloud
  + feature:aws elasticache: Add support to backup and restore for Redis
    clusters
  + feature:aws dynamodb: Update aws dynamodb command to the latest API
  + bugfix:Output Format: Fix issue with encoding errors when using text
    and table output and redirecting to a pipe or file (issue 742)
  + bugfix:aws s3: Fix issue with sync re-uploading certain files (issue 749)
  + bugfix:Text Output: Fix issue with inconsistent text output based on
    order (issue 751)
  + bugfix:aws datapipeline: Fix issue for aggregating keys into a list
    when calling aws datapipeline get-pipeline-definition (issue 750)
  + bugfix:aws s3: Fix issue when running out of disk space during aws s3
    transfers (issue 739)
  + feature:aws s3 sync: Add --size-only param to the aws s3 sync command
    (issue 472, issue 719)
  + bugfix:aws cloudtrail: Fix issue when using create-subscription
    command (issue botocore 268)
  + feature:aws cloudsearch: Amazon CloudSearch has moved out of preview
    (issue 730)
  + bugfix:aws s3 website: Fix issue where --error-document was being
    ignored in certain cases (issue 714)
  + feature:aws opsworks: Update aws opsworks model to the latest version
  + bugfix:Pagination: Fix issue with --max-items with aws route53, aws iam,
    and aws ses (issue 729)
  + bugfix:aws s3: Fix issue with fips-us-gov-west-1 endpoint (issue
    botocore 265)
  + bugfix:Table Output: Fix issue when displaying unicode characters in
    table output (issue 721)
  + bugfix:aws s3: Fix regression when syncing files with whitespace
    (issue 706, issue 718)
  + bugfix:aws ec2: Fix issue with EC2 model resulting in responses not
    being parsed.
  + feature:aws ec2: Add support for Amazon VPC peering
  + feature:aws redshift: Add support for the latest Amazon Redshift API
  + feature:aws cloudsearch: Add support for the latest Amazon CloudSearch API
  + bugfix:aws cloudformation: Documentation updates
  + bugfix:Argument Parsing: Fix issue when list arguments were not being
    decoded to unicode properly (issue 711)
  + bugfix:Output: Fix issue when invalid output type was provided in a
    config file or environment variable (issue 600)
  + bugfix:aws datapipeline: Fix issue when serializing pipeline definitions
    containing list elements (issue 705)
  + bugfix:aws s3: Fix issue when recursively removing keys containing
    control characters (issue 675)
  + bugfix:aws s3: Honor --no-verify-ssl in high level aws s3 commands
    (issue 696)
  + bugfix:Parameters: Fix issue parsing with CLI parameters of type long
    (issue 693)
  + bugfix:Pagination: Fix issue where --max-items in pagination was always
    assumed to be an integer (issue 689)
  + feature:aws elb: Add support for AccessLog
  + bugfix:Bundled Installer: Allow creation of bundled installer with pip
    1.5 (issue 691)
  + bugfix:aws s3: Fix issue when copying objects using aws s3 cp with key
    names containing + characters (issue #614)
  + bugfix:ec2 create-snapshot: Remove Tags key from output response
    (issue 247)
  + bugfix:aws s3: aws s3 commands should not be requiring regions (issue 681)
  + bugfix:CLI Arguments: Fix issue where unicode command line arguments
    were not being handled correctly (issue 679)
  + bugfix:aws s3: Fix issue where S3 downloads would hang in certain cases
    and could not be interrupted (issue 650, issue 657)
  + bugfix:aws s3: Support missing canned ACLs when using the --acl
    parameter (issue 663)
  + bugfix:aws rds describe-engine-default-parameters: Fix pagination issue
    when calling aws rds describe-engine-default-parameters (issue 607)
  + bugfix:aws cloudtrail: Merge existing SNS topic policy with the
    existing AWS CloudTrail policy instead of overwriting the default
    topic policy
  + bugfix:aws s3: Fix issue where streams were not being rewound when
    encountering 307 redirects with multipart uploads (issue 544)
  + bugfix:aws elb: Fix issue with documentation errors in aws elb help
    (issue 622)
  + bugfix:JSON Parameters: Add a more clear error message when parsing
    invalid JSON parameters (issue 639)
  + bugfix:aws s3api: Properly handle null inputs (issue 637)
  + bugfix:Argument Parsing: Handle files containing JSON with leading
    and trailing spaces (issue 640)
* Thu Feb 27 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #315990)
* Wed Feb 26 2014 rschweikert@suse.com
- update to version 1.2.13
  + feature:aws route53: Update aws route53 command to support string-match
    health checks and the UPSERT action for the aws route53
    change-resource-record-sets command
  + bugfix:Command Completion: Don't show tracebacks on SIGINT (issue 628)
  + bugfix:Docs: Don't duplicate enum values in reference docs (issue 632)
  + bugfix:aws s3: Don't require s3:// prefix (issue 626)
  + feature:aws configure: Add support for configure get and configure set
    command which allow you to set and get configuration values from the AWS
    config file (`issue 602 <https://github.com/aws/aws-cli/issues/602`__)
  + bugfix:aws s3: Fix issue with Amazon S3 downloads on certain OSes
    (`issue 619 <https://github.com/aws/aws-cli/issues/619`__)
  + Add support for the --recursive option in the aws s3 ls command
    (issue 465 <https://github.com/aws/aws-cli/issues/465)
  + Add support for the AWS_CA_BUNDLE environment variable so that users
    can specify an alternate path to a cert bundle (issue 586)
  + Add metadata_service_timeout and metadata_service_num_attempts config
    parameters to control behavior when retrieving credentials using an
    IAM role (issue 597)
  + Retry intermittent aws s3 download failures including socket timeouts
    and content length mismatches (issue 594)
  + Fix response parsing of aws s3api get-bucket-location (issue 345)
  + Fix response parsing of the aws elastictranscoder command (issue 207)
  + Update aws elasticache command to not require certain parameters
* Sat Jan 18 2014 rschweikert@suse.com
- Initial build
